@ECHO OFF
REM ***************************************************************
REM *                    QIA-Update.BAT                           *
REM *       SofTrack LWA (Local Workstation Agent) and QIA        *
REM *     (Quick Inventory Agent) Maintenance/install script      *
REM *        By Aaron Thomas, Integrity Software Inc.             *
REM *************************************************************** 
 REM * This script is used to check/upgrade/install/configure the *
 REM * SofTrack Local Workstation Agent (LWA) and the SofTrack    *
 REM * Quick Inventory Agent (QIA).                               *
 REM *                                                            *
 REM * PLEASE NOTE: This Script SHOULD NOT require user           *
 REM * modification! ALL changes should be made to the            *
 REM * STConfig.CMD file.                                         *
 REM *                                                            *
 REM * If you have any questions, or need assistance configuring  * 
 REM * /implementing /troubleshooting this script, please contact *
 REM * support@softwaremetering.com or call our support line at   *
 REM * 512-372-8991 M-F 7:30a to 5:30p CT USA (GMT-6)             *
 REM **************************************************************
 REM *Rev Info: V2.0a (VLG) 02-01-2011 MSI use build              *
 REM *          v2.0b (VLG) 02-17-2011 broke out LWA/QIA installs *
 REM *          v2.0c (VLG) 02-18-2011 CSV output cleaning        *
 REM *          v2.0d (VLG) 02-22-2011 fix path problems          *
 REM *          v2.0e (VLG) 03-04-2011 more error traps/tests     * 
 REM *          v2.0i (VLG) 03-11-2011 scheduled runs & optimize  *
 REM *          v2.0l (VLG) 03-24-2011 SCHTASKS works with (x86)  *
 REM *          v2.0m (VLG) 03-24-2011 fixes and optimizations    *
 REM *          v2.0n (VLG) 03-24-2011 reordered events           *
 REM *          v2.0q (VLG) 04-04-2011 color coded endings        *
 REM *          v2.0r (VLG) 04-08-2011 added 64 bit XP trap       *
 REM *          v2.0s (VLG) 04-28-2011 trap Client32 reach msg    *
 REM *          v2.0t (VLG) 05-23-2011 before/after version fix   *
 REM *          v2.1a (VLG) 09-19-2011 stock path and WaitForKey  *
 REM *          v2.2a (VLG) 09-12-2011 CPT/W7 components added    *
 REM *          v2.2b (VLG) 09-30-2011 SKIP CPTxxx.DLL if exists  *
 REM *          v2.2d (VLG) 10-19-2011 change stnw32.dll location *
 REM *          v2.2e (VLG) 10-21-2011 STPath trailing slash fix  *
 REM *          v2.2g (VLG) 11-09-2011 .NEW as target for CPTDLL  *
 REM *          v2.2h (VLG) 12-14-2011 fix wait for key function  *
 REM *          v2.2i (VLG) 02-01-2012 add LWA extra switches     *
 REM *          v2.2j (VLG) 05-01-2012 add 2003 64bit LWA support *
 REM *          v2.2k (VLG) 06-01-2012 add Location Code for QIA  *
 REM *          v2.2l (VLG) 06-01-2012 add PROTOCOL switch for QIA*
 REM *          v2.2m (VLG) 07-18-2012 add Location Code for LWA  *
 REM *          v2.2n (VLG) 08-15-2012 add VERCHK section         *
 REM *          v2.2o (VLG) 10-17-2012 Fix Skip LWA/QIA switches  *
 REM *          v2.2p (VLG) 12-04-2012 Skip Vista LWA stuff on XP *
 REM *          v2.2q (VLG) 12-17-2012 Add EXE exclusions         *
 REM *          v2.3a (VLG) 12-17-2012 activate VerChk function   *
 REM *          v2.3b (VLG) 01-11-2013 Skip LWA start if DLL=.NEW *
 REM *          v2.3c (VLG) 01-11-2013 add SSA target to LOG      *
 REM *          v2.3d (VLG) 01-11-2013 cat error msgs for LOG     *
 REM *          v2.3e (VLG) 01-11-2013 Fix date quote problem     *
 REM *          v2.3f (VLG) 02-04-2013 Add auto EU/US date format *
 REM *          v2.3g (VLG) 02-05-2013 fix scheduled tasks syntax *
 REM *          v2.3h (VLG) 02-05-2013 fix for (x86) cmd issues   *
 REM *          v2.3i (VLG) 02-08-2013 fix QIAVER after value bug *
 REM *          v2.3j (VLG) 03-12-2013 fix x64 OS check location  *
 REM *          v2.4a (VLG) 09-23-2013 First SSA Install option   *
 REM *          v2.4b (VLG) 09-27-2013 Add STDATA Timed Sync Code *
 REM *          v2.4c (VLG) 10-31-2013 Add SCHTASKS for SYNC      *
 REM *          v2.4d (VLG) 11-01-2013 Fix user permissions prob  *
 REM *          v2.4e (VLG) 11-01-2013 Add STVIEW2K.WKS file      *
 REM *                                 skip FW is SSA Local       *
 REM *          v2.4f (VLG) 12-18-2013 Add -WaitForever switch    *
 REM *          v2.4g (AT) 06-01-2017 Forced .NEW files ALWAYS    *
 REM *          v2.4h (AT) 03-06-2018 Added LWATRAY Feature       *
 REM *          NOTE: Mod script version to last value!           *
 REM **************************************************************

 REM **********************************
 REM * Ideas/Improvements/notes       *
 REM * for internal use only          *
 REM ****************************************************************
 REM * -Leverage verchk to see if targets are new/old and update
 REM *  or warn if old
 REM ****************************************************************

REM *****************************************
REM * Environment Setup                     *
REM *****************************************
   REM Set script version
     SET ScriptVersion=2.4h
	 SET Author=Aaron Thomas
     TITLE SofTrack Agents Installer v%ScriptVersion% by %Author%
   REM Set variables to NOT exist when script finishes
     SETLOCAL EnableDelayedExpansion
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM Set temporary Path to in case it has been altered from stock
     SET PATH=%SYSTEMROOT%;%SYSTEMROOT%\SYSTEM32;%SYSTEMROOT%\SYSTEM32\WBEM;%PATH%

   REM **********************************
   REM * UPDATE STCONFIG.CMD BEFORE USE!*
   REM **************************************************************
   REM * IMPORTANT! The STCONFIG.CMD file MUST be modified BEFORE   *
   REM * this script is run! The default values WILL NOT WORK for   *
   REM * your environment and the script will abort if the values   *
   REM * are not changed!                                           *
   REM **************************************************************

   REM **********************************
   REM * Turn DEBUG on/off              *
   REM *************************************************************************
   REM * The >nul 2>&1 redirects output and error output to nul to make clean  *
   REM * runs. NOTE: The reserved characters are delimited with a "^" symbol to*
   REM * make them compatible with the "set" command, so ">nul 2>&1" becomes   *
   REM * "^>nul 2^>^&1" un-REM "SET DEBUG=" to have errors/output of commands  *
   REM * displayed. Only change if instructed to do so by Tech Support or if   *
   REM * you're just the curious sort that would like to see it work. :)       *
   REM *************************************************************************
      SET DEBUG=^>nul 2^>^&1
      rem SET DEBUG=

REM *****************************************
REM * Set defaults for log variables        *
REM *****************************************
   SET STConfigPath="N/A"
   SET STConfig="N/A"
   SET OS64="N/A"

   SET ErrorMessage=
   SET NewInstall="N/A"
   SET NeedUpdate="N/A"
   SET LogStatus="N/A"
   SET Scheduled="N/A"

   SET UseIP="N/A"
   SET FirewallVer="N/A"
   SET FirewallState="N/A"
   SET FirewallRules="N/A"

   SET SkipSSAStart="N/A"
   SET SSAProcess="N/A"
   SET SSAVerBefore="N/A"
   SET SSAVerAfter="N/A"
   SET SSAService="N/A"
   SET SSAState="N/A"
   SET SSACopyFail="N/A"

   SET QIAProcess="N/A"
   SET QIAVerBefore="N/A"
   SET QIAVerAfter="N/A"
   SET QIAService="N/A"
   SET QIAState="N/A"
   SET QIACopyFail="N/A"

   SET SkipLWAStart="N/A"
   SET LWAProcess="N/A"
   SET LWAVerBefore="N/A"
   SET LWAVerAfter="N/A"
   SET LWAService="N/A"
   SET LWAState="N/A"
   SET LWACopyFail="N/A"

REM *****************************************
REM * Set defaults for script vars          *
REM *****************************************
   SET ScriptResult="PASS"
   rem ResourceDelay is number of seconds to wait after stopping LWA/SSA srvc
   SET ResourceDelay=10
   SET LSTAT=NotLocalOnly
   SET nss=ner

REM *****************************************
REM * Begin update/install                  *
REM *****************************************
 ECHO.
 ECHO Registering Components (v%ScriptVersion%):
 rem   ECHO.
 rem   ECHO SofTrack Enterprise Agent Maintenance System v%ScriptVersion%
 rem   ECHO By %Author% support@softwaremetering.com
 rem   ECHO.
 rem   ECHO BEGIN
 ECHO ------------------------------------

REM *****************************************
REM * Check/Read the STCONFIG.CMD           *
REM *****************************************
   IF "%DEBUG%."=="." ECHO  -Locating "STCONFIG.CMD"..
   SET ini=Ver
   REM Check for STConfig.CMD in location from which batch file was launched
   IF NOT EXIST "%~dp0STCONFIG.CMD" GOTO NotInCWD
     SET STConfigPath=%~dp0
     GOTO FileFound
   :NotInCWD

   REM Check for STConfig.CMD in AD SCRIPTS folder
   IF EXIST "\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\STCONFIG.CMD" (
     SET STConfigPath=\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\
     GOTO FileFound
   )

   ECHO  -FATAL ERROR: "STCONFIG.CMD" File NOT FOUND. Aborting..
   SET STConfigPath="Invalid"
   SET ErrorMessage=%ErrorMessage%STCONFIG.CMD not found, 
   SET ScriptResult="FAIL"
   GOTO EXIT

   :FileFound
   REM Gets here if we find the STConfig.CMD file
   ECHO  -STConfig Path:
   ECHO  "%STConfigPath%"
   CALL "%STConfigPath%STCONFIG.CMD"

REM *****************************************
REM * Determine 32/64 bit OS rev and        *
REM * set appropriate target path           *
REM *****************************************
   IF "%DEBUG%."=="." ECHO  -Checking for 64-bit system..
   SET TVE=non
   SET sio=Gra
   REG QUERY HKLM\Hardware\Description\System\CentralProcessor\0 | FIND /i "x86" %DEBUG%
   If %ERRORLEVEL% == 0 (
        SET STPATH=%SYSTEMROOT%\SYSTEM32\DRIVERS
        SET ISWPath=%SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1
        SET OS64="No"
   ) ELSE (
        SET STPATH=%SYSTEMROOT%\SYSWOW64\DRIVERS
        SET STPath64=%SYSTEMROOT%\SYSTEM32\DRIVERS
        SET ISWPath=%SystemDrive%\PROGRA~2\INTEGR~1\WORKST~1
        SET OS64="Yes"
   )
   
REM *****************************************
REM * Check LogPath for WRITE right         *
REM *****************************************
   REM Restore title line
   SET Author=%ini%%tve% %sio%%nss%
   TITLE SofTrack Agents Installer v%ScriptVersion% by %Author%
   REM Check The STConfig log path for "local"
   rem -----------------------------------------
   IF "%LogPath%."=="Local." GOTO CheckLocal

   REM Remove trailing slash if present
   IF %LogPath:~-1%==\ SET LogPath=%LogPath:~0,-1%

   REM Check the STConfig provided target
   rem -----------------------------------------
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
   )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp"

   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     SET LogStatus="Writable"
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
     GOTO EndLogTest
   )

   REM Check the Local ProgramFiles folder
   rem -----------------------------------------
   :CheckLocal
   IF %OS64% == "Yes" (
      SET LogPath=%SystemDrive%\PROGRA~2\INTEGR~1
     ) ELSE (
      SET LogPath=%SystemDrive%\PROGRA~1\INTEGR~1
   )

   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
    )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp"

   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     SET LogStatus="Writable"
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
     GOTO EndLogTest
   )

   REM Nothing writable, dang it! :P
   rem -----------------------------------------
     SET LogStatus="Log path %LogPath% Invalid - defaulting to %TEMP%"
     SET ErrorMessage=%ErrorMessage%Log path %LogPath% Invalid - defaulting to %TEMP%, 
     ECHO  -Log path %LogPath% Invalid - defaulting to %TEMP%
     SET LogPath=%temp%
   )

   :EndLogTest

REM *****************************************
REM * Echo back the results of STCONFIG.CMD *
REM *****************************************
   IF NOT "%DEBUG%."=="." GOTO SkipShow
   ECHO ------------------------------------
   ECHO      STCONFIG variables:
   ECHO    STConfig.CMD Version: "%CFGVersion%"
   ECHO   Source for components: "%FileSource%"
   ECHO       SSA from STConfig: "%SSAHost%"
   IF NOT "%1."=="."   ECHO     SSA Override server: "%1"
   ECHO.
   ECHO     Log will be sent to: "%LogPath%"
   ECHO  Force refresh settings: "%UpdateSettings%"
   ECHO                Protocol: "%Protocol%"
   ECHO  Check for update every: "%UpdateInterval%" Days
   ECHO.
   ECHO Install the QIA service: "%InstallQIA%"
   ECHO    Inventory push every: "%ISCAN%" minutes
   ECHO.
   ECHO Install the LWA service: "%InstallLWA%"
   ECHO      Load Delay Seconds: "%DELAY%"
   ECHO.
   ECHO Install the SSA service: "%InstallSSA%"
   ECHO         SSA Sync Target: "%SSATarget%"
   ECHO    SSA Sync Target Path: "%SSATargetPath%"
   ECHO     SSA Upload Interval: "%SSASyncInterval%"
   ECHO ------------------------------------
   PAUSE
   :SkipShow

REM *****************************************
REM * VerChk for most recent components     *
REM *****************************************
   IF "%VerChk%"=="No" GOTO DoneVerChk

   IF NOT EXIST ".\VERCHK.BAT" GOTO DoneVerChk

   ECHO  -Standby: Checking agent component versions..
   CALL VERCHK.BAT %DateFormat% NoConsole NoMSI Quiet 

   REM Restore Window title after VERCHK
   TITLE SofTrack Agents Installer v%ScriptVersion% by %Author%

   IF "%VerChkResult%"=="PASS" GOTO DoneVerChk

   ECHO   * WARNING- Components may be OUT OF DATE. Check Log:
   ECHO     "%LogPath%\VERCHK.TXT"
   ECHO.
   SET ErrorMessage=%ErrorMessage%Failed VerChk, 
   SET ScriptResult="WARN"

   :DoneVerChk

REM *****************************************
REM * Check for SSA server host override    *
REM *****************************************
   IF NOT "%1."=="." (
     rem ECHO  -NOTE: Overriding STConfig SSA Host "%SSAHost%" with "%1"
     SET SSAHost=%1
   )
   ECHO  -SSA host server: "%SSAHost%"

REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
   ECHO   * Fetching Time and Date info..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%

REM *****************************************
REM * Pre-Flight Check: Was script          *
REM * properly modified before use          *
REM *****************************************
  IF "%DEBUG%."=="." ECHO  -Pre-flight STConfig.CMD checks..

  REM **********************************
  REM * If detected, remove leading    *
  REM * slashes from server name. For  *
  REM * people who can't seem to       *
  REM * follow instructions. ;)        *
  REM **********************************
   SET SSAHost=%SSAHost:\\=%


  REM **********************************
  REM * Check QIA source path          *
  REM **********************************
    IF %InstallQIA%==No GOTO SkipPF3

    IF EXIST %~dp0QISVC0.EXE (
      SET QIAPath=%~dp0
      GOTO QIAPathFound
    )

    IF EXIST %FileSource%\QISVC0.EXE (
      SET QIAPath=%FileSource%
      GOTO QIAPathFound
    )

    IF EXIST %FileSource%\tools\QIA.raw\QISVC0.EXE (
      SET QIAPath=%FileSource%\tools\QIA.raw
      GOTO QIAPathFound
    )

   ECHO  -STConfig.CMD config check FATAL ERROR
   ECHO   * QIA Source Files Not Found
   SET ErrorMessage=%ErrorMessage%Invalid FileSource specified (QIA), 
   Set ScriptResult="FAIL"
   GOTO EXIT

   :QIAPathFound
   IF "%DEBUG%."=="." ECHO  -QIA source: "%QIAPath%"

   :SkipPF3

 
REM *****************************************
REM * Check local drive for WRITE right     *
REM *****************************************
   IF EXIST "%STPATH%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%STPATH%\%COMPUTERNAME%-Test.tmp" %DEBUG%
   )

   ECHO LocalWriteTest >"%STPATH%\%COMPUTERNAME%-Test.tmp"
   IF EXIST "%STPATH%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%STPATH%\%COMPUTERNAME%-Test.tmp" %DEBUG%
   ) ELSE (
     SET ErrorMessage=%ErrorMessage%Check '%USERNAME%' permissions for '%STPATH%', 
     ECHO  -Write failed on "%STPATH%"
     ECHO  -Make sure %USERNAME% has required permissions
     Set ScriptResult="FAIL"
     GOTO EXIT
   )

REM *****************************************
REM * Create Scheduled Task for auto update *
REM *****************************************
   rem NOTE1: This portion is considered BETA as no one has implemented it as of 11/05/2013
   rem NOTE2: Only useful if the source for the LWA/QIA components is 
   rem on a central server! DO NOT enable if the LWA/QIA component source
   rem path is the local machine!

   REM if UpdateInterval is zero, then don't schedule a task
   IF %UpdateInterval%==0 GOTO ScheduleUpdateDone

   rem Create task runner account- maybe not needed this time..?
   rem NET USER %SSASyncUser% /DELETE
   rem NET USER %SSASyncUser% %SSASyncPass% /ADD
   rem NET localgroup "Backup Operators" %SSASyncUser% /ADD
      
   REM remove task if it exists
   SCHTASKS  /query | FIND "SofTrack Agent Update" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SCHTASKS /DELETE /F /TN "SofTrack Agent Update" %DEBUG%
     )

   REM Check %FileSource% path for QIA-update.bat
   REM ==========================================================
   IF NOT EXIST "%FileSource%\QIA-Update.bat" GOTO NoUpdateSchedule

   REM Test for "RunLevel" parameter - needed on Windows Vista and higher
   SCHTASKS /CREATE /? | FIND "/RL" %DEBUG%

   REM errorlevel 0 means Vista Class and above Command version
   IF NOT %ERRORLEVEL%==0 GOTO XPUpdateSched

   REM Create Vista+ class scheduled task
   SCHTASKS /create /TN "SofTrack Agent Update" /TR "\"%FileSource%\QIA-Update.bat\"" /U %SSASyncUser% /P %SSASyncPass% /RL HIGHEST /SC daily /MO %UpdateInterval% /ST %TIME:~0,5%:00 %DEBUG%
   GOTO SchedUpdateCMDdone

   :XPUpdateSched
   REM XP Class and lower Command version
   SCHTASKS /create /TN "SofTrack Agent Update" /TR "\"%FileSource%QIA-Update.bat\"" /U %SSASyncUser% /P %SSASyncPass% /SC DAILY /MO %UpdateInterval% /ST %TIME:~0,5%:00 %DEBUG%

   :SchedUpdateCMDdone
   
   SET Scheduled=Every %UpdateInterval% days at %TIME:~0,5%
   ECHO  -Update Schedule: %Scheduled%.
   GOTO ScheduleDone
   :NoUpdateSchedule

   REM No batch found, skip scheduled event creation
   REM =================================================
   ECHO  -Update Schedule: NONE ^(Local update batch not found^)
   SET Scheduled=None- No Local Batch

   :ScheduleUpdateDone

REM *****************************************
REM * Firewall Handling Section             *
REM *****************************************
   REM improvement idea--
   REM maybe add 137-139 & 448 for SMB in case file/print isn't open?
 
   
   IF %Protocol%==ServerUsePipes (
     ECHO  -SMB No Firewall Rule Changes Made
     SET UseIP="No"
     GOTO FirewallDone
   )
   SET UseIP="Yes"
   
   REM ************************************
   REM * Check firewall version           *
   REM ************************************
   NETSH ADVFIREWALL | FIND "are available:" %DEBUG%
   IF %ERRORLEVEL%==0 (
     SET FirewallVer="Advanced"
     IF "%DEBUG%."=="." ECHO  -Firewall Service ADVANCED.
     GOTO Firewall7
   ) ELSE (
     IF "%DEBUG%."=="." ECHO  -Firewall Service NORMAL.
     SET FirewallVer="Normal"
   )

   REM ************************************
   REM * Check if firewall service is     *
   REM * running on 2000, XP              *
   REM ************************************
   SC query SharedAccess | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
     IF "%DEBUG%."=="." ECHO  -Firewall Service Running.
     SET FirewallState="Running"
   ) ELSE (
     IF "%DEBUG%."=="." ECHO  -Firewall Service Not Running.
     SET FirewallState="Not Running"
     GOTO FirewallDone
   )

   REM ************************************
   REM * Check rules for 2K/XP machines   *
   REM ************************************
   ECHO.
   ECHO  -Checking Firewall Rules..
   SET FirewallRules="Present"

   rem Check SofTrack Agent UDP
   NETSH FIREWALL SHOW CONFIG | FIND "3884   UDP       Enable   SofTrack Agent UDP" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAddUDP

   ECHO   * Adding Port 3884 UDP exception..
   NETSH FIREWALL ADD PORTOPENING PROTOCOL=UDP port=3884 name="SofTrack Agent UDP" %DEBUG%
   IF %ERRORLEVEL%==0 (
     SET FirewallRules="Added"
   ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="NOT added"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAddUDP

   rem Check SofTrack Agent TCP
   NETSH FIREWALL SHOW CONFIG | FIND "3884   TCP       Enable   SofTrack Agent TCP" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAddTCP

   ECHO   * Adding Port 3884 TCP exception..
   NETSH FIREWALL ADD PORTOPENING PROTOCOL=TCP port=3884 name="SofTrack Agent TCP" %DEBUG%
   IF %ERRORLEVEL%==0 (
     SET FirewallRules="Added"
     ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="NOT added"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAddTCP

   IF %FirewallRules%=="Present" ECHO   * Firewall exceptions present.

   GOTO FirewallDone

   REM ************************************
   REM * Check if firewall svc running on *
   REM * Vista, W7, Windows 2008          *
   REM ************************************
   :Firewall7
   SC query MpsSvc | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
     SET FirewallState="Running"
   ) ELSE (
     ECHO  -Firewall Service Not Running
     SET FirewallState="Not Running"
     GOTO FirewallDone
   )

   REM ************************************
   REM * Check rules for Vista and above  *
   REM ************************************
   ECHO.
   ECHO  -Checking Firewall Rules..
   SET FirewallRules="Present"

   rem SofTrack Agent (TCP-In)
   NETSH ADVFIREWALL FIREWALL SHOW RULE NAME="SofTrack Agent (TCP-In)" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAdd1
   NETSH ADVFIREWALL FIREWALL ADD RULE NAME="SofTrack Agent (TCP-In)" PROTOCOL=TCP DIR=IN LOCALPORT=3884 ACTION=Allow PROFILE=Any %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * Adding Port 3884 TCP-IN exception..
     SET FirewallRules="Added"
   ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="Add Failed"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAdd1

   rem SofTrack Agent (UDP-In)
   NETSH ADVFIREWALL FIREWALL SHOW RULE NAME="SofTrack Agent (UDP-In)" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAdd2
   NETSH ADVFIREWALL FIREWALL ADD RULE NAME="SofTrack Agent (UDP-In)" PROTOCOL=UDP DIR=IN LOCALPORT=3884 ACTION=Allow PROFILE=Any %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * Adding Port 3884 UDP-IN exception..
     SET FirewallRules="Added"
   ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="Add Failed"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAdd2

   rem SofTrack Agent (TCP-Out)
   NETSH ADVFIREWALL FIREWALL SHOW RULE NAME="SofTrack Agent (TCP-Out)" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAdd3
   NETSH ADVFIREWALL FIREWALL ADD RULE NAME="SofTrack Agent (TCP-Out)" PROTOCOL=TCP DIR=Out LOCALPORT=3884 ACTION=Allow PROFILE=Any %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * Adding Port 3884 TCP-OUT exception..
     SET FirewallRules="Added"
   ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="Add Failed"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAdd3

   rem SofTrack Agent (UDP-Out)
   NETSH ADVFIREWALL FIREWALL SHOW RULE NAME="SofTrack Agent (UDP-Out)" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO SkipAdd4
   NETSH ADVFIREWALL FIREWALL ADD RULE NAME="SofTrack Agent (UDP-Out)" PROTOCOL=UDP DIR=OUT LOCALPORT=3884 ACTION=Allow PROFILE=Any %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * Adding Port 3884 UDP-OUT exception..
     SET FirewallRules="Added"
   ) ELSE (
     ECHO   - Firewall Exception insertion FAILED
     SET FirewallRules="Add Failed"
     SET ErrorMessage=%ErrorMessage%Firewall Exception insertion failed, 
     SET ScriptResult="WARN"
   )
   :SkipAdd4

   IF %FirewallRules%=="Present" ECHO   * Firewall exceptions present.

   REM **********************************
   REM * Firewall Check/Update Done     *
   REM **********************************
      :FirewallDone

REM *****************************************
REM * Target Server ping check              *
REM *****************************************
 IF "%PingCheck%."=="No." GOTO PingCheckDone
   ECHO.
   ECHO  -PING check of SSA host server..
   rem send 2 pings to target at 125ms each
   rem can be raised if DNS is slow
   PING -n 2 -w 125 -4 %SSAHost% | FIND "Reply" %DEBUG%
   IF NOT %ERRORLEVEL%==0 (
     ECHO   - WARNING Server "%SSAHost%" not responding to PING.
     ECHO   * Make sure server name is correct and server is reachable
     SET ErrorMessage=%ErrorMessage%Server PING failed, 
     Set ScriptResult="WARN"
   ) ELSE (
     ECHO   * Server "%SSAHost%" responded to PING.
   )

 :PingCheckDone


REM QIA PORTION ----------------------------------------------------
REM                                                                 \

  REM **********************************
  REM * Do we install QIA?             *
  REM **********************************
   IF %InstallQIA%==No GOTO NoQIAInstall

  REM **********************************
  REM * Check QIA is already present   *
  REM **********************************
   ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" %DEBUG%
   ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" %DEBUG%
   IF EXIST "%STPATH%\QISVC0.EXE" (
     ECHO.
     ECHO  -Checking the QIA..
     SET QIAProcess="Update"
   ) ELSE (
     ECHO.
     ECHO  -Installing the QIA..
     SET QIAProcess="Install"
     GOTO QIAInstallNow
   )

  REM **********************************
  REM * Test version to see if update  *
  REM * is required.                   *
  REM **********************************
   REM Check the one we are planning to install
   FOR /F "tokens=5 delims= " %%i in ('TYPE "%QIAPATH%INVENTRY.EXE" ^| FIND "SofTrack Quick Inventory Module"') do SET QIAVerSource=%%i
   REM Check the one that is running now
   FOR /F "tokens=5 delims= " %%i in ('TYPE "%STPATH%\INVENTRY.EXE" ^| FIND "SofTrack Quick Inventory Module"') do SET QIAVerBefore=%%i


  REM **********************************
  REM * Force QIA update?              *
  REM **********************************
   IF %ForceUpdate%==Yes (
     GOTO SkipQIAVersionCheck
   )

   IF "%QIAVerBefore%"=="%QIAVerSource%" (
     ECHO   * Local QIA matches update QIA ^(%QIAVerBefore%^) - Update skipped.
     SET QIAProcess="Not Updated"
     GOTO NoQIAUpdate
   ) else (
     ECHO   * Local QIA ^(%QIAVerBefore%^) doesn't match new QIA ^(%QIAVerSource%^) - Updating..
     SET QIAProcess="Updating"
     GOTO QIAUpdateNow
   )
   :SkipQIAVersionCheck

  REM **********************************
  REM * Stop the service (if it's      *
  REM * running) to allow new files    *
  REM * to be copied over old          *
  REM **********************************
   :QIAUpdateNow
   SC query SOFTRACKQISVC | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Sending STOP command to QIA service..
      net stop "SofTrack Quick Inventory Service" %DEBUG%

      ECHO   * Waiting for resources to be released..
      PING 1.1.1.1 -n %ResourceDelay% -w 1000 %DEBUG%
   rem   SLEEP %ResourceDelay% %DEBUG%
   )

  REM ************************************
  REM * Use TSKILL if Service won't stop *
  REM ************************************
   DEL /Q /F "%STPATH%\QISVC0.EXE" %DEBUG%
   IF EXIST "%STPATH%\QISVC0.EXE" TSKILL QISVC0 %DEBUG%
   IF EXIST "%STPATH%\QISVC0.EXE" DEL /Q /F  "%STPATH%\QISVC0.EXE" %DEBUG%

  REM **********************************
  REM * If it's still there, set       *
  REM * service to MANUAL so we can    *
  REM * catch it on the next reboot    *
  REM **********************************
   IF EXIST "%STPATH%\QISVC0.EXE" (
     ECHO    - WARNING: QIA Force Stop failed.
     rem start= options {boot|system|auto|demand|disabled}
     SC config SOFTRACKQISVC start= demand | FIND "SUCCESS" %DEBUG%
     IF %ERRORLEVEL%==0 (
       ECHO   * QIA set to manual start
       SET QIAService="Manual-Reboot and Retry"
       SET ErrorMessage=%ErrorMessage%QIA set to MANUAL start - reboot and retry, 
       Set ScriptResult="FAIL"
     ) ELSE (
       ECHO   - QIA refused set to Manual start
       SET QIAService="Stuck in AUTO"
       SET ErrorMessage=%ErrorMessage%QIA refused change to MANUAL start, 
       Set ScriptResult="FAIL"
     )
   ECHO  -Reboot and Re-run this script
   GOTO EXIT
   )

  REM *************************************
  REM * Remove existing QIA files, if any *
  REM *************************************
   :QIAInstallNow
   ECHO   * Removing any previous QIA components..
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" %DEBUG%
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" %DEBUG%
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" %DEBUG%
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" %DEBUG%
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" %DEBUG%
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" %DEBUG%
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" %DEBUG%
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" %DEBUG%
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" %DEBUG%
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" %DEBUG%
   )

  REM **********************************
  REM * Copy the QIA files             *
  REM **********************************
   SET QIACopyFail=
   ECHO   * Copying new QIA components..
   COPY /V /Y "%QIAPath%\_SMBIOS_.EXE" "%STPATH%" %DEBUG%
   IF NOT %ERRORLEVEL%==0 (
     ECHO     - _SMBIOS_.EXE Copy Failed
     SET "QIACopyFail=%QIACopyFail% _SMBIOS_.EXE"
     SET ErrorMessage=%ErrorMessage%Copy to %STPATH% Failed, 
     SET ScriptResult="WARN"
   )

   COPY /V /Y "%QIAPath%\INVENTRY.EXE" "%STPATH%" %DEBUG%
   IF NOT %ERRORLEVEL%==0 (
     ECHO     - INVENTRY.EXE Copy Failed
     SET "QIACopyFail=%QIACopyFail% INVENTRY.EXE"
     SET ErrorMessage=%ErrorMessage%Copy to %STPATH% Failed, 
     SET ScriptResult="WARN"
   )

   COPY /V /Y "%QIAPath%\QISVC0.EXE" "%STPATH%" %DEBUG%
   IF NOT %ERRORLEVEL%==0 (
     ECHO     - QISVC0.EXE Copy Failed
     SET "QIACopyFail=%QIACopyFail% QISVC0.EXE"
     SET ErrorMessage=%ErrorMessage%Copy to %STPATH% Failed, 
     SET ScriptResult="WARN"
   )

   COPY /V /Y "%QIAPath%\STNW32.DLL" "%STPATH%" %DEBUG%
   IF NOT %ERRORLEVEL%==0 (
     ECHO     - STNW32.DLL Copy Failed
     SET "QIACopyFail=%QIACopyFail% STNW32.DLL"
     SET ErrorMessage=%ErrorMessage%Copy to %STPATH% Failed, 
     SET ScriptResult="WARN"
   )

   SET QIAProcess="Update"
   IF "%QIACopyFail%."=="." SET QIACopyFail="None"

  REM **********************************
  REM * Install and config the QIA     *
  REM **********************************
   :NoQIAUpdate
   IF %UpdateSettings%==No GOTO SkipQIAParams
   IF NOT EXIST "%STPATH%\QISVC0.EXE" GOTO SkipQIAParams
   ECHO   * Configuring QIA parameters..
   "%STPATH%\QISVC0" -INSTALL %DEBUG%
   "%STPATH%\QISVC0" -SERVER %SSAHost% %DEBUG%
   "%STPATH%\QISVC0" -INTERVAL %ISCAN% %DEBUG%
   "%STPATH%\QISVC0" -%Protocol% %DEBUG%

   REM Set Location code if exists, clear it if not specified
   IF "%LocCode%."=="." (
     "%STPATH%\QISVC0" -NoLocation %DEBUG%
   ) ELSE (
     "%STPATH%\QISVC0" -location "%LocCode%" %DEBUG%
   )


   REM ***************************************
   REM * Check for Server-reach              *
   REM ***************************************
     rem Skip if client 32 is present
     %STPATH%\QISVC0 -profiles 2>nul |FIND /I "Skipping" %DEBUG%
     IF %ERRORLEVEL%==0 (
       ECHO   - NOTE: Client 32 present- server reach Skipped.
       SET ErrorMessage=%ErrorMessage%QISVC0 NW- reach Skipped, 
       GOTO SkipQIAParams
     )

     %STPATH%\QISVC0 -profiles 2>nul |FIND "WORKED" %DEBUG%
     IF NOT %ERRORLEVEL%==0 (
       ECHO     - WARNING: QIA server reach FAILED.
       SET ErrorMessage=%ErrorMessage%QIA reach FAILED, 
       SET ScriptResult="WARN"
     )

   :SkipQIAParams

  REM **********************************
  REM * Set and Start the QIA Service  *
  REM **********************************
   IF NOT EXIST "%STPATH%\QISVC0.EXE" GOTO NoStartQIA

   REM ***************************************
   REM * Get the post-install QIA version    *
   REM ***************************************
   FOR /F "tokens=5 delims= " %%i in ('TYPE %STPATH%\INVENTRY.EXE ^| FIND "SofTrack Quick Inventory Module"') do SET QIAVerAfter=%%i

   REM ***************************************
   REM * Make sure QIA is in AUTO start mode *
   REM ***************************************
   Set QIAService="AUTO"
   SC QC SOFTRACKQISVC | FIND "AUTO" %DEBUG%
   IF %ERRORLEVEL%==0 GOTO AutoQIA
   ECHO     - WARNING: QIA service not AUTO- Attempting Change..
   REM start= options {boot|system|auto|demand|disabled}
   SC CONFIG SOFTRACKQISVC START= AUTO | FIND "SUCCESS" %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * QIA service changed to AUTO
     Set QIAService="AUTO"
   ) ELSE (
     ECHO     - WARNING: QIA service refused command to change to AUTO start
     SET QIAService="Not Auto"
     SET ErrorMessage=%ErrorMessage%QIA refused change to AUTO start, 
     SET ScriptResult="WARN"
   )
   :AutoQIA

   REM ***************************************
   REM * Start up the QIA service            *
   REM ***************************************
   SC query SOFTRACKQISVC | FIND "STATE" | FIND "STOPPED" %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * Starting QIA service..
     NET START "SofTrack Quick Inventory Service" %DEBUG%
   )

   SC query SOFTRACKQISVC | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
      SET QIAState="Started"
   ) ELSE (
      ECHO     - Service Start FAILED
      SET QIAState="Start Failed"
      SET ErrorMessage=%ErrorMessage%QIA failed to start, 
      SET ScriptResult="WARN"
   )
   :NoStartQIA

  REM **********************************
  REM * Skip QIA                       *
  REM **********************************
     :NoQIAInstall
REM                                                                 /
REM QIA PORTION ----------------------------------------------------


REM **********************************
REM * Script is complete             *
REM **********************************
   :EXIT

REM **********************************
REM * Write log file                 *
REM **********************************
   ECHO.
   ECHO  -Updating Log File:
   ECHO   "%LogPath%\STinstall-%COMPUTERNAME%.CSV"

   REM **********************************
   REM * If server name was parameter-  *
   REM * passed, update the variable    *
   REM * for the log file to reflect    *
   REM * the source of the server name  *
   REM **********************************
    IF NOT "%1."=="." SET SSAHost=Override:%SSAHost%

   REM Put a header on it if it doesn't exist
   IF NOT EXIST "%LogPath%\STinstall-%COMPUTERNAME%.CSV" (
     ECHO "Time Run","Workstation Name","SSA Host","Script","Do SSA","Do LWA","Do QIA","Settings","Force Update","Script Result","Errors","Scheduled","STconfig.CMD Path","Log File Path","TCP/IP?","Firewall Ver","Firewall Svc","Rules","LWA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State","QIA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State","SSA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State",>"%LogPath%\STinstall-%COMPUTERNAME%.CSV"
   )
   
   REM Creates a N/A result if no errors have been produced during the script run
   IF "%ErrorMessage%."=="." SET ErrorMessage=N/A
   ECHO "%TIMESTAMP%","%COMPUTERNAME%","%SSAHost%","%ScriptVersion%","%InstallSSA%","%InstallLWA%","%InstallQIA%","%UpdateSettings%","%ForceUpdate%",%ScriptResult%,"%ErrorMessage%",%Scheduled%,"%STConfigPath%","%LogPath%",%UseIP%,%FirewallVer%,%FirewallState%,%FirewallRules%,%LWAProcess%,%LWAVerBefore%,%LWAVerAfter%,%LWACopyFail%,%LWAService%,%LWAState%,%QIAProcess%,%QIAVerBefore%,%QIAVerAfter%,%QIACopyFail%,%QIAService%,%QIAState%,%SSAProcess%,%SSAVerBefore%,%SSAVerAfter%,%SSACopyFail%,%SSAService%,%SSAState%,>>"%LogPath%\STinstall-%COMPUTERNAME%.CSV"
   
REM **********************************
REM * Echo end of script and set     *
REM * screen color to red/yel/grn    *
REM **********************************
   ECHO ------------------------------------
   REM Red background, white text
   IF %ScriptResult%=="FAIL" COLOR 4F

   REM yellow background, black text
   IF %ScriptResult%=="WARN" (
     COLOR E0
     ECHO.
     ECHO WARNING- ERRORS DETECTED Check Log File ^(noted above^) for details.
     ECHO.
   )

   REM green background, white text
   IF %ScriptResult%=="PASS" COLOR A0

   ECHO END RESULT: %ScriptResult%
   ECHO.

REM **********************************
REM * Check to see if we pause at    *
REM * to show install result to user *
REM **********************************
   IF %WaitForKey%==Yes (
     PAUSE
   )

REM **********************************
REM * Done! Skynet uplink soon... ;) *
REM **********************************
   rem Return color scheme to white on black
   COLOR 0F
   TITLE Command Prompt
   rem note: "endlocal" clears all the variables used in this script
   ENDLOCAL
