@ECHO OFF
REM **************************************************************
REM * Removes SofTrack LWA & QIA from Windows NT/2K/XP/Vista/W7  *
REM *       By Vern Graner SSE, Integrity Software Inc.          *
REM *        questions to support@softwaremetering.com           *
REM **************************************************************
 REM * Used for removing the LWA & QIA from a workstation as you  *
 REM * develop or test an install script. NOTE: This script       *
 REM * WILL NOT Remove the LWA/QIA from a Windows 9x/ME box!      *
 REM **************************************************************
 REM * Rev Info:                                                  *
 REM * V1.0  (VLG) 09-05-03 First Build - test OK                 *
 REM * v1.1  (VLG) 03-30-04 Check/correct "-h" attribute          *
 REM * v1.2  (VLG) 06-15-05 Added registry key removal            *
 REM * v1.3  (VLG) 11-15-06 Added -REMOVEALL for newer STLWA_NT   *
 REM * V1.4  (VLG) 11-16-09 Added remove for QI SVC and BW pieces *   
 REM * v1.5  (VLG) 04-01-10 Added support for Win7 and 64bit      *
 REM * v1.6  (VLG) 06-28-10 Added support SYSWOW64/drivers path   *
 REM * v1.7  (VLG) 08-11-10 Change registry key permissions       *
 REM * v1.8  (VLG) 09-30-11 Remove new components                 *
 REM * v1.9  (VLG) 03-12-13 Invoked on exit of MSI                *
 REM * v2.2e (VLG) 03-14-13 Enable REGISTRY kill+ routines        *
 REM * v2.2f (VLG) 05-20-13 Remove scheduled tasks if it exits    *
 REM * v2.2f (VLG) 05-20-13 Remove scheduled tasks if it exits    *
 REM * v2.2g (VLG) 05-31-13 Remove STCONFIG read add CWD for LOG  *
 REM * v2.2h (VLG) 06-11-13 Fold in AGENTKEY and AGENTPER files   *
 REM * v2.2i (VLG) 06-12-13 Fix Paren in log file path error      *
 REM * v2.3b (VLG) 09-24-13 Remove SSA components                 *
 REM **************************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set varibales to NOT exist when script finishes
     SETLOCAL EnableDelayedExpansion
   REM Set script version
     SET ScriptVersion=2.3b
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM Set temporary Path to in case it has been altered from stock
     SET PATH=%SYSTEMROOT%;%SYSTEMROOT%\SYSTEM32;%SYSTEMROOT%\SYSTEM32\WBEM
   TITLE Components Removal v%ScriptVersion%

   REM **********************************
   REM * Turn DEBUG on/off              *
   REM *************************************************************************
   REM * The >nul 2>&1 redirects output and error output to nul to make clean  *
   REM * runs. NOTE: The reserved characters are delimted with a "^" symbol to *
   REM * make them compatible with the "set" command, so ">nul 2>&1" becomes   *
   REM * "^>nul 2^>^&1" un-REM "SET DEBUG=" to have errors/output of commands  *
   REM * dispayed. Only change if instructed to do so by Tech Support or if    *
   REM * you're just the curious sort that would like to see it work. :)       *
   REM *************************************************************************
    SET DEBUG=^>nul 2^>^&1
    rem SET DEBUG=

REM **********************************
REM * Workaround-9-24-2013-VLG       *
REM **********************************
REM * Kill install bat to avoid issue*
REM * with MSI wrongly calling the   *
REM * install on an uninstall        *
REM **********************************
   DEL /Q LWA-QIA-update.bat %DEBUG%
   
REM **********************************
REM * Set defaults for script vars   *
REM **********************************
   SET ScriptResult="PASS"
   REM ResourceDelay is number of seconds to wait after stopping LWA/SSA srvc
   SET ResourceDelay=10
   SET WaitForKey=No
   IF "%USERNAME%."=="." (
     SET SSAHost=AGENTRM by SYSTEM
   ) ELSE (
     SET SSAHost=AGENTRM by %USERNAME%
   )

REM **********************************
REM * Set defaults for log variables *
REM **********************************
   SET STConfigPath=N/A
   SET STConfig="N/A"
   SET OS64="N/A"

   SET ErrorMessage=
   SET LogStatus=N/A
   SET NewInstall="N/A"
   SET NeedUpdate="N/A"
   SET Scheduled="N/A"

   SET UseIP="N/A"
   SET FirewallVer="N/A"
   SET FirewallState="N/A"
   SET FirewallRules="N/A"

   SET SkipSSAStart="N/A"
   SET SSAProcess="N/A"
   SET SSAVerBefore="N/A"
   SET SSAVerAfter="N/A"
   SET SSAService="N/A"
   SET SSAState="N/A"
   SET SSACopyFail="N/A"

   SET SkipLWAStart="N/A"
   SET LWAProcess="N/A"
   SET LWAVerBefore="N/A"
   SET LWAVerAfter="N/A"
   SET LWAService="N/A"
   SET LWAState="N/A"
   SET LWACopyFail="N/A"

   SET QIAProcess="N/A"
   SET QIAVerBefore="N/A"
   SET QIAVerAfter="N/A"
   SET QIAService="N/A"
   SET QIAState="N/A"
   SET QIACopyFail="N/A"
   
   SET CFGVersion=N/A
   SET InstallSSA=REMOVE
   SET InstallLWA=REMOVE
   SET InstallQIA=REMOVE
   SET UpdateSettings=N/A
   SET ForceUpdate=N/A
  
REM **********************************
REM * Main                           *
REM **********************************
   ECHO De-registering Components (v%ScriptVersion%):
   ECHO.
   ECHO Preparing Uninstall system:
   ECHO.
   ECHO WARNING! This script will remove all SofTrack Components
   ECHO from this machine! 
   ECHO.
   ECHO CTRL-C to abort or
   PAUSE

REM *****************************************
REM * Check/Read the STCONFIG.CMD           *
REM *****************************************
   IF "%DEBUG%."=="." ECHO  -Locating "STCONFIG.CMD"..
   REM Check for STConfig.CMD in location from which batch file was launched
   IF NOT EXIST "%~dp0STCONFIG.CMD" GOTO NotInCWD
     SET STConfigPath=%~dp0
     GOTO FileFound
   :NotInCWD

   REM Check for STConfig.CMD in AD SCRIPTS folder
   IF EXIST "\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\STCONFIG.CMD" (
     SET STConfigPath=\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\
     GOTO FileFound
   )

   ECHO  - ERROR: "STCONFIG.CMD" File not found.
   SET STConfigPath="Invalid"
   SET ErrorMessage=%ErrorMessage%STCONFIG.CMD not found, 
   SET ScriptResult="WARN"
   GOTO STConfigCheckDone

   :FileFound
   REM Gets here if we find the STConfig.CMD file
   ECHO  -STConfig Path:
   ECHO  "%STConfigPath%"
   CALL "%STConfigPath%STCONFIG.CMD"
   
   :STConfigCheckDone

REM **********************************
REM * Determine 32/64 bit OS rev and *
REM * set appropriate target path    *
REM **********************************
   IF "%DEBUG%."=="." ECHO  -Checking for 64-bit system..
   REG QUERY HKLM\Hardware\Description\System\CentralProcessor\0 | FIND /i "x86" %DEBUG%
   If %ERRORLEVEL% == 0 (
        SET STPATH=%SYSTEMROOT%\SYSTEM32\DRIVERS
        SET OS64="No"
   ) ELSE (
        SET STPATH=%SYSTEMROOT%\SYSWOW64\DRIVERS
        SET STPath64=%SYSTEMROOT%\SYSTEM32\DRIVERS
        SET OS64="Yes"
   )
   
REM **********************************
REM * Check LogPath for WRITE right  *
REM **********************************

   REM Check the Local ProgramFiles folder
   rem -----------------------------------------

   IF %OS64% == "Yes" (
      SET LogPath=%SystemDrive%\PROGRA~2\INTEGR~1\WORKST~1
   ) ELSE (
      SET LogPath=%SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1
   )
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
    )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp"

   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
     SET LogStatus=Writable
     ECHO  - Log path "%LogPath%" [!LogStatus!]
     GOTO EndLogTest
   )

   REM Check the Current Working Directory
   rem -----------------------------------------
   SET LogPath=%~dp0
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
    )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp"
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     SET LogStatus=Writable
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
     ECHO  - Log path "%LogPath%" [!LogStatus!]
     GOTO EndLogTest
   )
   
   REM Nothing user-writable - default to 
   rem -----------------------------------------
     SET LogStatus="Log path %LogPath% Invalid - defaulting to %TEMP%"
     SET "ErrorMessage=%ErrorMessage%Log path %LogPath% Invalid - defaulting to %TEMP%, "
     SET LogStatus=Writable
     SET LogPath=%temp%
     ECHO  - Log path "%LogPath%" [!LogStatus!]
   )

   :EndLogTest
  
REM **********************************
REM * Fetch and Format Date/Time     *
REM **********************************
   ECHO  - Fetching Time and Date info..
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%

REM **********************************
REM * Remove scheduled update task   *
REM * if it exists                   *
REM **********************************
   REM remove task if it exists
   SCHTASKS  /query | FIND "SofTrack Agent Update" %DEBUG%
   IF %ERRORLEVEL%==0 (
       SCHTASKS /DELETE /F /TN "SofTrack Agent Update" %DEBUG%
   )

REM **********************************
REM * Uninstall the LWA service      *
REM ****************************************************************
REM
   ECHO.
   ECHO Processing LWA service:

   REM **********************************
   REM * Check for service              *
   REM **********************************
   SC query SofTrackLocalAgentService | FIND /i "does not exist" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Service already removed.
      GOTO SkipLWAServiceCommands
   )

   REM **********************************
   REM * Set service to DISABLED start  *
   REM **********************************
   rem start= options {boot|system|auto|demand|disabled}
   SC config SofTrackLocalAgentService  start= disabled | FIND "SUCCESS" %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * LWA set to disabled
     SET LWAService="Set to DISABLED"
   ) ELSE (
     ECHO   ! LWA failed set to DISABLED
     SET LWAService="Set to DISABLED failed"
     SET "ErrorMessage=%ErrorMessage%LWA Set to DISABLED failed, "
     Set ScriptResult="WARN"
   )

   REM **********************************
   REM * STOP service if running        *
   REM **********************************
   SC query SofTrackLocalAgentService | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Sending STOP command to LWA service..
      NET STOP "SofTrack Local Metering Agent Service" %DEBUG%

      ECHO   * Waiting for resources to be released..
      PING 1.1.1.1 -n %ResourceDelay% -w 1000 %DEBUG%
   )

   REM **********************************
   REM * Use TSKILL if LWA won't stop   *
   REM * rare but possible on older LWA *
   REM **********************************
   DEL /Q /F "%STPATH%\STLWA_NT.EXE" %DEBUG%
   IF EXIST "%STPATH%\STLWA_NT.EXE" TSKILL STLWA_NT %DEBUG%
   IF EXIST "%STPATH%\STLWA_NT.EXE" DEL /Q /F "%STPATH%\STLWA_NT.EXE" %DEBUG%

   REM *************************************
   REM * Uninstall the LWA service         *
   REM *************************************
   ECHO     -Removing service
   REM for 32 bit LWA
   IF EXIST %SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT -REMOVE %DEBUG%
   IF EXIST %SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT -REMOVEALL %DEBUG%

   REM for 64 bit LWA
   IF EXIST %SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT -REMOVE %DEBUG%
   IF EXIST %SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT -REMOVEALL %DEBUG%

   IF EXIST %SYSTEMROOT%\SYSWOW64\STLWA_NT.EXE %SYSTEMROOT%\SYSWOW64\STLWA_NT -REMOVE %DEBUG%
   IF EXIST %SYSTEMROOT%\SYSWOW64\STLWA_NT.EXE %SYSTEMROOT%\SYSWOW64\STLWA_NT -REMOVEALL %DEBUG%
   
   rem Uninstall Service Complete
   :SkipLWAServiceCommands
   
   SET LWAState="Removed"

   REM *************************************
   REM * Remove existing LWA files, if any *
   REM *************************************
   ECHO     -Removing LWA components..
   <nul (set/p NOCRLF=      )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\CPT_X64A.exe" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\CPT_X64A.exe" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\CPT_X64A.exe" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\CPT_X64A.exe" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\CPT_X64A.exe" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\CPT_X64A.exe" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa32.dll" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa32.dll" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa32.dll" %DEBUG%
     rem <nul (set/p NOCRLF=*)
	 rem dont echo on these as they are in use
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa32.dll" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa32.dll" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa32.dll" %DEBUG%
     rem <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa64.dll" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa64.dll" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\cptlwa64.dll" %DEBUG%
     rem <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa64.dll" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa64.dll" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\cptlwa64.dll" %DEBUG%
     rem <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.OLD" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.OLD" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.OLD" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.OLD" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.OLD" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.OLD" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\NWLWA32.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\NWLWA32.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\NWLWA32.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\NWLWA32.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\NWLWA32.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\NWLWA32.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K32.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K32.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K32.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K32.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K32.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K32.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STBW_K64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STBW_K64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWMON.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWMON.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STLWMON.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWMON.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWMON.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STLWMON.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVISTA.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVISTA.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVISTA.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVISTA.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVISTA.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVISTA.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
REM                                                                 /
REM ****************************************************************

REM **********************************
REM * Uninstall the QIA service      *
REM ****************************************************************
REM                                                                 \
   ECHO.
   Echo Processing QIA service:
   
   REM **********************************
   REM * Check for service              *
   REM **********************************
   SC query SOFTRACKQISVC | FIND /i "does not exist" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Service not present.
      GOTO SkipQIAServiceCommands
   )

   REM **********************************
   REM * Set service to DISABLED start  *
   REM **********************************
   rem start= options {boot|system|auto|demand|disabled}
   SC config SOFTRACKQISVC start= disabled | FIND "SUCCESS" %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * QIA set to disabled
     SET QIAService="Set to DISABLED"
   ) ELSE (
     ECHO   ! QIA failed set to DISABLED
     SET QIAService="Set to DISABLED failed"
     SET "ErrorMessage=%ErrorMessage%QIA Set to DISABLED failed, "
     Set ScriptResult="WARN"
   )
   
   REM **********************************
   REM * STOP service if running        *
   REM **********************************
   SC query SOFTRACKQISVC | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Sending STOP command to QIA service..
      NET STOP "SofTrack Quick Inventory Service" %DEBUG%

      ECHO   * Waiting for resources to be released..
      PING 1.1.1.1 -n %ResourceDelay% -w 1000 %DEBUG%
   )

   REM **********************************
   REM * Use TSKILL if LWA won't stop   *
   REM **********************************
   DEL /Q /F "%STPATH%\QISVC0.EXE" %DEBUG%
   IF EXIST "%STPATH%\QISVC0.EXE" TSKILL QISVC0 %DEBUG%
   IF EXIST "%STPATH%\QISVC0.EXE" DEL /Q /F  "%STPATH%\QISVC0.EXE" %DEBUG%

   REM **********************************
   REM * Remove the service             *
   REM **********************************
   ECHO     -Removing Service
   REM for 32 bit LWA
   IF EXIST %SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE %SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE -REMOVE %DEBUG%

   REM for 64 bit LWA
   IF EXIST %SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE %SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE -REMOVE %DEBUG%
   rem Just in case the file is in the wrong place..
   IF EXIST %SYSTEMROOT%\SYSWOW64\QISVC0.EXE %SYSTEMROOT%\SYSWOW64\QISVC0.EXE -REMOVE %DEBUG%

   REM QIA service remove complete
   :SkipQIAServiceCommands
   SET QIAState="Removed"
   
   REM *************************************
   REM * Remove existing QIA files, if any *
   REM *************************************
   ECHO     -Removing QIA components..
   <nul (set/p NOCRLF=      )
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\_SMBIOS_.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\INVENTRY.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\INVENTRY.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\QISVC0.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\QISVC0.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\WINV.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\WINV.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STNW32.DLL" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STNW32.DLL" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   ECHO.
REM                                                                 /
REM ****************************************************************

REM **********************************
REM * Uninstall the SSA service      *
REM ****************************************************************
REM                                                                 \
   SET SSAstate="Not Found"
   IF "%InstallSSA%."=="No." GOTO NoUninstallSSA
   rem   IF NOT EXIST "%STPATH%\STSRVC.EXE" GOTO NoUninstallSSA

   ECHO Processing SSA service..

   REM **********************************
   REM * Check for service              *
   REM **********************************
   SC query SofTrackService | FIND /i "does not exist" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO     -SSA Service not found
      GOTO SkipSSAServiceCommands
   )

   REM **********************************
   REM * Set service to DISABLED start  *
   REM **********************************
   rem start= options {boot|system|auto|demand|disabled}
   SC config SofTrackService  start= disabled | FIND "SUCCESS" %DEBUG%
   IF %ERRORLEVEL%==0 (
     ECHO   * SSA set to disabled
     SET SSAService="Set to DISABLED"
   ) ELSE (
     ECHO   ! SSA failed set to DISABLED
     SET SSAService="Set to DISABLED failed"
     SET "ErrorMessage=%ErrorMessage%SSA Set to DISABLED failed, "
     Set ScriptResult="WARN"
   )

   REM **********************************
   REM * STOP service if running        *
   REM **********************************
   SC query SofTrackService | FIND "STATE" | FIND "RUNNING" %DEBUG%
   IF %ERRORLEVEL%==0 (
      ECHO   * Sending STOP command to SSA service..
      NET STOP "SofTrack Service" %DEBUG%

      ECHO   * Waiting for resources to be released..
      PING 1.1.1.1 -n %ResourceDelay% -w 1000 %DEBUG%
   )

   REM **********************************
   REM * Uninstall the SSA              *
   REM **********************************
      ECHO   * Removing SSA service..
      "%STPATH%\STSRVC" -REMOVE %DEBUG%

   REM *************************************
   REM * DEBUG stop for "hung" service     *
   REM *************************************
   REM for 32 bit SSA
   rem IF EXIST %SYSTEMROOT%\SYSTEM32\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSTEM32\DRIVERS\STSRVC -DEBUGSTOP %DEBUG%

   REM for 64 bit SSA
   rem  IF EXIST %SYSTEMROOT%\SYSWOW64\DRIVERS\STLWA_NT.EXE %SYSTEMROOT%\SYSWOW64\DRIVERS\STSRVC -DEBUGSTOP %DEBUG%
   
   REM **********************************
   REM * Use TSKILL if SSA won't stop   *
   REM **********************************
   DEL /Q /F "%STPATH%\STSRVC.EXE" %DEBUG%
   IF EXIST "%STPATH%\STSRVC.EXE" TSKILL STSRVC %DEBUG%
   IF EXIST "%STPATH%\STSRVC.EXE" DEL /Q /F "%STPATH%\STSRVC.EXE" %DEBUG%

   REM SSA service remove complete
   :SkipSSAServiceCommands
   SET SSAState="Removed"

   REM *************************************
   REM * Remove existing SSA files, if any *
   REM *************************************
   ECHO     -Removing SSA components..
   <nul (set/p NOCRLF=      )
   
   rem SSASYNC.BAT
   IF EXIST "%SYSTEMROOT%\SYSTEM32\SSASYNC.BAT" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\SSASYNC.BAT" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\SSASYNC.BAT" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\SSASYNC.BAT" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\SSASYNC.BAT" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\SSASYNC.BAT" %DEBUG%
     <nul (set/p NOCRLF=*)
   )


   rem STSRVC.EXE
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STSRVC.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STSRVC.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STSRVC.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STSRVC.EXE" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STSRVC.EXE" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STSRVC.EXE" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   rem STAD0.DLL
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STAD0.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STAD0.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STAD0.DLL" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STAD0.DLL" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STAD0.DLL" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STAD0.DLL" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   REM STVIEW2K.SYS
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW2K.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW2K.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW2K.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW2K.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW2K.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW2K.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   REM STVIEW64.SYS
   IF EXIST "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSTEM32\DRIVERS\STVIEW64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )
   IF EXIST "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW64.SYS" (
     ATTRIB -H -S -R "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW64.SYS" %DEBUG%
     DEL /Q /F "%SYSTEMROOT%\SYSWOW64\DRIVERS\STVIEW64.SYS" %DEBUG%
     <nul (set/p NOCRLF=*)
   )

   REM *************************************
   REM * Remove Scheduled task if it exists*
   REM *************************************
     SCHTASKS  /query | FIND "SofTrack Agent Update" %DEBUG%
     IF %ERRORLEVEL%==0 (
       ECHO     -Deleting SSASync Scheduled Task..
       SCHTASKS /DELETE /F /TN "SofTrack Agent Update" %DEBUG%
     )

   REM *************************************
   REM * Remove the scheduler user account *
   REM *************************************
     IF "%SSASyncUser%."=="." GOTO NoDelUser
	 ECHO     -Deleting Scheduled Task User..
     NET USER %SSASyncUser% /DELETE %DEUBG%
	 :NoDelUser
   
   REM *************************************
   REM * Delete STDATA share, folder       * 
   REM * and ALL contents!                 *
   REM *************************************
     ECHO     -Deleting STDATA share
     NET SHARE STDATA$ /DELETE %DEBUG%
     RMDIR /S /Q %LogPath%\STDATA %DEBUG%

  :NoUninstallSSA
REM                                                                 /
REM ****************************************************************


REM *************************************
REM * Creating AGENTPER.DAT file        *
REM *************************************
   ECHO HKEY_CURRENT_USER\Software\SofTrackUser [1 5 7 17] >%TEMP%\AgentPer.dat
   ECHO HKEY_CURRENT_USER\Software\SofTrackQuickInventory [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_CURRENT_USER\Software\Integrity Software, Inc. [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\MenuOrder\Start Menu\Programs\SofTrack [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SofTrackService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet000\Services\SofTrackService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Services\SofTrackService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Services\SofTrackService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet003\Services\SofTrackService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STVIEW [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STVIEW2K [1 5 7 17] >>%TEMP%\AgentPer.dat 
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SofTrackLocalAgentService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STLWMON [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STBW_K32 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STLWA_64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\services\STBW_K64\Enum [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SOFTRACKQISVC [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SOFTRACKQISVC\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISVC [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISVC\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON\0000\LogConf [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISVC [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISVC\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON\0000\LogConf [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISV [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISV\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISV\0000\COntrol [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\services\STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISVC [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISVC\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64\Control [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV\0000 [1 5 7 17] >>%TEMP%\AgentPer.dat
   ECHO HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV\0000\Control [1 5 7 17] >>%TEMP%\AgentPer.dat

REM *************************************
REM * Creating AGENTKEY.DAT file        *
REM *************************************
   ECHO Windows Registry Editor Version 5.00 >%TEMP%\AgentKey.dat
   ECHO [-HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\MenuOrder\Start Menu\Programs\SofTrack] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_CURRENT_USER\Software\SofTrackUser] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SOFTWARE\Integrity Software, Inc.] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SOFTWARE\SofTrackAlert] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet000\Services\SofTrackService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SofTrackLocalAgentService\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SofTrackLocalAgentService\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKLOCALAGENTSERVICE] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISVC\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISVC\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_SOFTRACKQISVC] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K32] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWA_64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STLWMON] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Enum\Root\LEGACY_STVIEW2K] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Services\SofTrackService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STBW_K32] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STLWA_64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STLWMON] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STVIEW2K] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\services\STVISTA] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SofTrackLocalAgentService\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SofTrackLocalAgentService\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SofTrackLocalAgentService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_SOFTRACKQISV] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K32] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWA_64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Enum\Root\LEGACY_STLWMON] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\Services\SofTrackService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet002\services\STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SofTrackLocalAgentService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_SOFTRACKQISV] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K32] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWA_64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON\0000\Control] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON\0000] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Enum\Root\LEGACY_STLWMON] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SofTrackLocalAgentService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SOFTRACKQISVC] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\SofTrackService] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STBW_K32] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\services\STBW_K64\Enum] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STBW_K64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STLWA_64] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STLWMON] >>%TEMP%\AgentKey.dat   
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STVIEW2K] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STVISTA] >>%TEMP%\AgentKey.dat
   ECHO [-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\STVIEW] >>%TEMP%\AgentKey.dat

REM *************************************
REM * Set permissions on Keys           *
REM *************************************
  ECHO.
  ECHO Finalizing Uninstall..   

   IF EXIST "%TEMP%\AGENTPER.DAT" (
     ECHO     -Resetting Key Permissions
     REGINI %TEMP%\AGENTPER.DAT %DEBUG%
   ) ELSE (
     ECHO   ! AGENTPER.DAT File NOT FOUND
     SET "ErrorMessage=%ErrorMessage%AGENTPER.DAT not found, "
     Set ScriptResult="WARN"
   )

REM *************************************
REM * Remove registry keys              *
REM *************************************
   IF EXIST "%TEMP%\AGENTKEY.DAT" (
    ECHO     -Removing Legacy Keys
     REGEDIT /S %TEMP%\AGENTKEY.DAT %DEBUG%
   ) ELSE (
     ECHO   ! AGENTKEY.DAT File NOT FOUND
     SET "ErrorMessage=%ErrorMessage%AGENTKEY.DAT not found, "
     Set ScriptResult="WARN"
   )

REM *************************************
REM    Removing Firewall Rules
REM *************************************
 
   REM ************************************
   REM * Check firewall version           *
   REM ************************************
   NETSH ADVFIREWALL | FIND "are available:" %DEBUG%
   IF %ERRORLEVEL%==0 (
     IF "%DEBUG%."=="." ECHO  -Firewall Service ADVANCED.
     SET FirewallVer="Advanced"
   ) ELSE (
     IF "%DEBUG%."=="." ECHO  -Firewall Service NORMAL.
     SET FirewallVer="Normal"
   )

   REM ************************************
   REM * Choose syntax for FW version     *
   REM ************************************
   ECHO     -Removing Firewall Rules
   IF %FirewallVer%=="Normal" (
     NETSH FIREWALL DELETE PORTOPENING PROTOCOL=ALL PROFILE=ALL port=3884
   ) ELSE (
     NETSH ADVFIREWALL FIREWALL DELETE RULE NAME="SofTrack Agent (TCP-In)"
     NETSH ADVFIREWALL FIREWALL DELETE RULE NAME="SofTrack Agent (TCP-Out)"
   )
   
REM *************************************
REM * Erasing Local files               *
REM *************************************
   ECHO     -Erasing temp cached files..
   IF NOT EXIST "%LogPath%\STinstall-%COMPUTERNAME%.CSV" GOTO NoErase
     
     IF EXIST %LogPath%\AGENTRM.TXT (
        DEL /Q %LogPath%\AGENTRM.TXT %DEBUG%
        <nul (set/p NOCRLF=*)
     )

    IF EXIST %LogPath%\BARCODE.EXE (
       DEL /Q %LogPath%\BARCODE.EXE %DEBUG%
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %LogPath%\BUILD.TXT (
       DEL /Q %LogPath%\BUILD.TXT %DEBUG%
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %LogPath%\CPTLWA32.DLL (  
       DEL /Q %LogPath%\CPTLWA32.DLL %DEBUG%
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %LogPath%\CPTLWA64.DLL (  
       DEL /Q %LogPath%\CPTLWA64.DLL %DEBUG%
       <nul (set/p NOCRLF=*)
    )

    If EXIST %LogPath%\CPT_X64A.EXE (  
       DEL /Q %LogPath%\CPT_X64A.EXE %DEBUG%
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %LogPath%\EXEIgnore.dat ( 
       DEL /Q %LogPath%\EXEIgnore.dat %DEBUG%
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %LogPath%\INVENTRY.EXE ( 
       DEL /Q %LogPath%\INVENTRY.EXE %DEBUG%
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\ISW.DAT (  
       DEL /Q %LogPath%\ISW.DAT %DEBUG%
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\launcher.vbs (      
       DEL /Q %LogPath%\launcher.vbs %DEBUG%
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\LWA-QIA-update.bat (  
       DEL /Q %LogPath%\LWA-QIA-update.bat %DEBUG%
       <nul (set/p NOCRLF=*)
    )   
    
    IF EXIST %LogPath%\NWLWA32.EXE (
     DEL /Q %LogPath%\NWLWA32.EXE %DEBUG%
     <nul (set/p NOCRLF=*)
    )
    
    IF EXIST %LogPath%\QISVC0.EXE (
     DEL /Q %LogPath%\QISVC0.EXE %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\README.TXT (
     DEL /Q %LogPath%\README.TXT %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\stad0.dll (
     DEL /Q %LogPath%\stad0.dll %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STBW_K32.SYS (
     DEL /Q %LogPath%\STBW_K32.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STBW_K64.SYS (
     DEL /Q %LogPath%\STBW_K64.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )
    
    IF EXIST %LogPath%\STConfig.cmd (
     DEL /Q %LogPath%\STConfig.cmd %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STLWA_64.SYS (
     DEL /Q %LogPath%\STLWA_64.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STLWA_NT.EXE (
     DEL /Q %LogPath%\STLWA_NT.EXE %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STLWMON.SYS (
     DEL /Q %LogPath%\STLWMON.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STNW32.DLL (
     DEL /Q %LogPath%\STNW32.DLL %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STSRVC.EXE (
     DEL /Q %LogPath%\STSRVC.EXE %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STVIEW.SYS (
     DEL /Q %LogPath%\STVIEW.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STVIEW2K.SYS (
     DEL /Q %LogPath%\STVIEW2K.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\stview64.sys (
     DEL /Q %LogPath%\stview64.sys %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\STVISTA.SYS (
     DEL /Q %LogPath%\STVISTA.SYS %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\VERCHK.BAT (
     DEL /Q %LogPath%\VERCHK.BAT %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\VerChk.TXT (
     DEL /Q %LogPath%\VerChk.TXT %DEBUG%
     <nul (set/p NOCRLF=*)
    )

    IF EXIST %LogPath%\_SMBIOS_.EXE (
     DEL /Q %LogPath%\_SMBIOS_.EXE %DEBUG%
     <nul (set/p NOCRLF=*)
    ) 

    IF EXIST %LogPath%\SSASYNC.BAT (
     DEL /Q %LogPath%\SSASYNC.BAT %DEBUG%
     <nul (set/p NOCRLF=*)
    ) 

    IF EXIST %LogPath%\QuietSync.vbs (
     DEL /Q %LogPath%\QuietSync.vbs %DEBUG%
     <nul (set/p NOCRLF=*)
    )
   
    IF EXIST %LogPath%\QuietLaunch.vbs (
     DEL /Q %LogPath%\QuietLaunch.vbs %DEBUG%
     <nul (set/p NOCRLF=*)
    )
      
   :NoErase

REM *************************************
REM * Write log file                    *
REM *************************************
   ECHO.
   ECHO Updating Log File:
   ECHO "%LogPath%\STinstall-%COMPUTERNAME%.CSV"

   REM Put a header on it if it doesn't exist
   IF NOT EXIST "%LogPath%\STinstall-%COMPUTERNAME%.CSV" (
     ECHO "Time Run","Workstation Name","SSA Host","Script","Do SSA","Do LWA","Do QIA","Settings","Force Update","Script Result","Errors","Scheduled","STconfig.CMD Path","Log File Path","TCP/IP?","Firewall Ver","Firewall Svc","Rules","LWA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State","QIA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State","SSA","Ver Before","Ver After","Copy Fail(s)","Svc Mode","Svc State",>"%LogPath%\STinstall-%COMPUTERNAME%.CSV"
   )
   
   REM Creates a N/A result if no errors have been produced during the script run
   IF "%ErrorMessage%."=="." SET ErrorMessage=N/A

   REM Append data to the log file
   ECHO "%TIMESTAMP%","%COMPUTERNAME%","%SSAHost%","%ScriptVersion%","%InstallSSA%","%InstallLWA%","%InstallQIA%","%UpdateSettings%","%ForceUpdate%",%ScriptResult%,"%ErrorMessage%",%Scheduled%,"%STConfigPath%","%LogPath%",%UseIP%,%FirewallVer%,%FirewallState%,%FirewallRules%,%LWAProcess%,%LWAVerBefore%,%LWAVerAfter%,%LWACopyFail%,%LWAService%,%LWAState%,%QIAProcess%,%QIAVerBefore%,%QIAVerAfter%,%QIACopyFail%,%QIAService%,%QIAState%,%SSAProcess%,%SSAVerBefore%,%SSAVerAfter%,%SSACopyFail%,%SSAService%,%SSAState%,>>"%LogPath%\STinstall-%COMPUTERNAME%.CSV"

REM *************************************
REM * Echo end of script and Set screen *
REM * color to red/yel/grn              *
REM *************************************
   ECHO --------------------------------------------------------
   REM Red background, white text
   IF %ScriptResult%=="FAIL" (
     COLOR 4F
     SET WaitForKey%=Yes
     ECHO.
     ECHO FATAL ERRORS DETECTED! Check Log File ^(noted above^) for details.
     ECHO.
   )

   REM yellow background, black text
   IF %ScriptResult%=="WARN" (
     COLOR E0
     SET WaitForKey%=Yes
     ECHO.
     ECHO WARNING- ERRORS DETECTED! Check Log File ^(noted above^) for details.
     ECHO.
   )

   REM green background, white text
   IF %ScriptResult%=="PASS" COLOR A0

   ECHO END RESULT: %ScriptResult%
   ECHO.
   ECHO You MUST REBOOT for the uninstall process to complete!
   ECHO.

REM *************************************
REM * Clean up temp files               *
REM *************************************
   DEL /Q %TEMP%\AgentKey.dat
   DEL /Q %TEMP%\AgentPer.dat
   
REM **********************************
REM * Check to see if we pause at    *
REM * to show install result to user *
REM **********************************
   IF "%WaitForKey%."=="Yes." (
     PAUSE
   )

REM **********************************
REM * Done! Skynet uplink soon... ;) *
REM **********************************
   rem Return color scheme to white on black
   COLOR 0F
   TITLE Command Prompt
   rem note: "endlocal" clears all the variables used in this script
   ENDLOCAL
