@ECHO OFF
REM **************************************************************
REM *                      _AuditSum.BAT                         *
REM *       By Vern Graner SSE, Integrity Software Inc.          *
REM **************************************************************
REM * Concatenates all the audit logs into a single file to      *       
REM * facilitate ease of import. Creates a log file that shows   *
REM * the results of each run.                                   *
REM *                                                            *
REM * Output file name is configurable in the settings (below)   *
REM *                                                            *
REM * If you have any questions, or need assistance configuring  *
REM * /implementing /troubleshooting this script, please contact *
REM * vgraner@softwaremetering.com or call our support line at   *
REM * 512-372-8991 M-F 7:30a to 5:30p CT USA (GMT-6)             *
REM **************************************************************
REM * Created 09/27/13 - 1.0a VLG First Build                    *
REM * Updated 09/30/13 - 1.0b VLG Added error trap for fail copy *
REM * Updated 10/02/13 - 1.0c VLG added remove compiled log src  *
REM * Updated 10/21/13 - 1.0d VLG Added CSVFix file validation   *
REM * Updated 10/25/13 - 1.0e VLG Updated logging add DeDupe     *
REM **************************************************************
REM * NOTE: This batch file MUST be run from                     *
REM * within the AUDIT FOLDER!                                   *
REM **************************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set variables to NOT exist when script finishes
   REM and enable delayed variable expansion
     SetLocal EnableDelayedExpansion
   REM Set script version
     SET ScriptVersion=1.0e
	 SET ScriptName=AuditSum
     TITLE %ScriptName% v%ScriptVersion% by Vern Graner
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM set default state for end result
   SET FailedLogs=0
   
REM *****************************************
REM * Set flags to control what the script  *
REM * should do. Valid answers are "Yes"    *
REM * and "No" - Case SeNsItIvE!            *
REM *****************************************
   SET OutputFileName=AllLogs.csv
   SET LOG_PATH=BACKUP.LOGS
   SET IncludeArchives=Yes
   SET CreateExceptionsReport=Yes
   SET RemoveSourceLogs=Yes
   SET DupeDetect=Yes

REM *****************************************
REM * Create / Display Header               *
REM *****************************************
   ECHO. >%TEMP%\%ScriptName%-Header.tmp
   ECHO      %ScriptName% script version %Scriptversion% by Vern Graner>>%TEMP%\%ScriptName%-Header.tmp
   ECHO ===========================================================>>%TEMP%\%ScriptName%-Header.tmp
   ECHO. >>%TEMP%\%ScriptName%-Header.tmp
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp

REM **********************************
REM * Add paths for helper apps      *
REM **********************************
   SET PATH=%PATH%;%ProgramFiles%\GnuWin32\bin
   SET PATH=%PATH%;%ProgramFiles(x86)%\GnuWin32\bin
   SET PATH=%PATH%;%ProgramFiles%\CSVfix
   SET PATH=%PATH%;%ProgramFiles(x86)%\CSVfix

REM **********************************
REM * Turn DEBUG on/off              *
REM *****************************************************************************
rem * The >nul 2>&1 redirects output and error output to nul to make clean runs *
rem * NOTE: The reserved characters are delimited with a "^" symbol to make them*
rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"  *
rem * un-REM "SET DEBUG=" to have errors/output of commands displayed           *
REM *****************************************************************************
  SET DEBUG=^>nul 2^>^&1
  rem SET DEBUG=

REM *****************************************
REM * Clean up leftover files               *
REM *****************************************
   DEL /Q *.CPY %DEBUG%
   DEL /Q *.VAL %DEBUG%
   
REM *****************************************
REM * Set up defaults for logging           *
REM *****************************************
   SET BackupLogFileName=N/A
   SET CurrentLog=N/A
   SET CopyFails=N/A
   
REM *****************************************
REM * Format Date/Time "MM/DD/YYYY HH:MM AP"*
REM *****************************************
   ECHO  -Script Start Time: Fetching..
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStampStart=%MyTime% %MyDate%
   SET NOW=%FileDate%
   SET FileStamp=%FileDate%_%FileTime%

REM **********************************
REM * Check for helper utilities     *
REM **********************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO  -Script Start Time: %TimeStampStart% >>%TEMP%\%ScriptName%-Header.tmp
   ECHO  - Helper App Check: Checking-

   REM CSVFix from google code base
   REM http://code.google.com/p/csvfix/
   REM Required to detect/remove non-compliant records in audit trails
   CSVFix help %DEBUG%
   If %ERRORLEVEL% == 9009 (
      ECHO                      * CSVfix:  NOT FOUND
	  ECHO Download from http://code.google.com/p/csvfix then retry
      SET HelpAppCheck=%HelpAppCheck%Missing CSVFix, 
	  SET ScriptResult=WARN
      SET Errors=%Errors%Missing CSVFix,  
      SET CSVfix=Not Found
   ) ELSE (
      ECHO                      * CSVfix:  FOUND
      SET CSVfix=Found
      REM Create the template for CSVfix use
      ECHO required    1,2,3,4,5,6,7,8 >"%TEMP%\%ScriptName%-CSVTemplate.txt"
      ECHO fields      * 8:8 >>"%TEMP%\%ScriptName%-CSVTemplate.txt"
   )

   REM UNIQ from GNUWIN32 project
   REM http://gnuwin32.sourceforge.net/packages/coreutils.htm
   REM Required to detect/remove duplicate records
   UNIQ --HELP %DEBUG%
   If %ERRORLEVEL% == 9009 (
      ECHO                      * UNIQ:   NOT FOUND
      SET HelpAppCheck=%HelpAppCheck%,Missing UNIQ
      SET Errors=%Errors%Missing UNIQ, 
      SET DeDUPE=No
	  SET ScriptResult=WARN
   ) ELSE (
      ECHO                      * UNIQ:   FOUND
      SET DeDUPE=Yes
   )
   
   If "%HelpAppCheck%."=="." (SET HelpAppCheck=OK)
   ECHO  - Helper App Check: %HelpAppCheck% >>%TEMP%\%ScriptName%-Header.tmp
   
REM *****************************************
REM * Show Archive log status               *
REM *****************************************
   ECHO  - Include Archived: %IncludeArchives% >>%TEMP%\%ScriptName%-Header.tmp
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   rem Pre-fill displayed variable if archives are NOT included in CAT
   SET ArchiveLogs=0
   rem Pre fill name for log file
   SET BackupLogFileName=%LOG_PATH%\AllLogs-%FileStamp%.csv
   
REM *****************************************
REM * Show other switch settings            *
REM *****************************************
   ECHO  -   Remove Sources: %RemoveSourceLogs% >>%TEMP%\%ScriptName%-Header.tmp
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp

   
REM *****************************************
REM * Create a list of all files in         *
REM * the directory                         *
REM *****************************************
   ECHO  -   Audit Log List: Compiling..
   REM Uses Regular Expressions to remove any files with extensions i.e. ".XXX"
   DIR /b /A-d | FINDSTR /V "\...." >%TEMP%\%ScriptName%_OnlyComputerLogs.txt

   REM Counts the files and sets variable
   REM =========================================================
   dir /b /A-d | FINDSTR /V "\...." | find "" /v /n /c >%TEMP%\%ScriptName%_logs.tmp
   set /p ActiveLogs= <%TEMP%\%ScriptName%_logs.tmp
   del /q %TEMP%\%ScriptName%_logs.tmp %DEBUG%

   REM If selected, add archived logs to the list
   IF %IncludeArchives%==No GOTO SkipArchives

     rem append files that end in ".0XX"
     DIR /b /A-d | FINDSTR "\.0..">> %TEMP%\%ScriptName%_OnlyComputerLogs.txt

     rem append files that end in ".CPY"
     DIR /b /A-d | FINDSTR "\.CPY">> %TEMP%\%ScriptName%_OnlyComputerLogs.txt

     REM Counts additional files and sets a variable
     REM =========================================================
     dir /b /A-d | FINDSTR "\.0.." | find "" /v /n /c >%TEMP%\%ScriptName%_logs.tmp
     set /p ArchiveLogs= <%TEMP%\%ScriptName%_logs.tmp
	 
	      REM Counts additional files and sets a variable
     REM =========================================================
     dir /b /A-d | FINDSTR "\.CPY" | find "" /v /n /c >%TEMP%\%ScriptName%_logs.tmp
     set /p CPYLogs= <%TEMP%\%ScriptName%_logs.tmp

     Set /a ArchiveLogs=ArchiveLogs+CPYLogs
	 
     del %TEMP%\%ScriptName%_logs.tmp

   :SkipArchives
     Set /a TotalLogs=ActiveLogs+ArchiveLogs

   ECHO  -   Audit Log List: Compiled %TotalLogs% logs [%ActiveLogs% Active + %ArchiveLogs% Archived]>>%TEMP%\%ScriptName%-Header.tmp

   Rem Trap for NO audit logs found
   
   IF "%TotalLogs%"=="0" (
     SET Errors=%Errors%No Audit Logs Found, 
	 SET BackupLogFileName=N/A
	 SET OutputFileName=N/A
	 GOTO WriteLogExit
   )
   
REM **********************************
REM * Check LOG_PATH for WRITE right *
REM **********************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO  -Log Path Location: Verifying..

   IF NOT EXIST %LOG_PATH% MD %LOG_PATH%

   ECHO Test File >"%LOG_PATH%\STTest.tmp"
   IF EXIST "%LOG_PATH%\STTest.tmp" (
     SET LogPath="Writable"
     DEL /q "%LOG_PATH%\STTest.tmp"
   ) ELSE (
     SET LogPath="%LOG_PATH% Read Only!- default to TEMP"
     ECHO  -Write failed on "%LOG_PATH%" -using "%temp%"
     SET LOG_PATH=%temp%
   )

   ECHO  -Log Path Location: Verified [%LOG_PATH%]>>%TEMP%\%ScriptName%-Header.tmp

REM ***************************
REM * Process each audit log  *
REM ***************************
    CLS
    TYPE %TEMP%\%ScriptName%-Header.tmp

    FOR /F "delims=; eol=#" %%I IN (%TEMP%\%ScriptName%_OnlyComputerLogs.txt) DO (
   
REM **********************
REM * Main Loop Begin    *
REM ******************************************************************************
REM                                                                              *
       SET /a CurrentLog=CurrentLog+1
       CLS
       TYPE %TEMP%\%ScriptName%-Header.tmp
       ECHO  -       Processing: Machine Audit Log !CurrentLog! of %TotalLogs% [%%I]

       REM ****************************
       REM * Concatenate logs section *
       REM *******************************************************************
       REM                                                                    \

       REM Rename the file so nothing is missed during the copy process
       IF "%DEBUG%."=="." ECHO    * Renaming "%%I" to "%%I.CPY"..
       REM Make SURE there are no leftovers!
       IF EXIST %%I.CPY DEL /Q %%I.CPY
	   REN "%%I" "%%I.CPY"

       REM ****************************
       REM * CSVFix section           *
       REM *******************************************************************
       REM                                                                    \
       IF %CSVFix%==Found (
       
          REM Use CSVFix to detect/remove any damaged or non compliant records
		  REM and remove the trailing comma
          ECHO    * Checking for record exceptions..
          IF "%DEBUG%."=="." ECHO     - CSV validate +truncate to %%I.VAL..
          CSVFix validate -vf "%TEMP%\%ScriptName%-CSVTemplate.txt" -om pass %%I.CPY | CSVFix truncate -n 7 -o %%I.VAL

          IF %CreateExceptionsReport%==Yes (
            REM Use CSVFix to create failed record report
            ECHO    * Creating report ["%LOG_PATH%\%FileStamp%-exceptions.txt"]
            IF "%DEBUG%."=="." ECHO     - CSV validate fail to %LOG_PATH%\%FileStamp%-exceptions.txt..
 	        ECHO Errors in %%I:>>"%LOG_PATH%\%FileStamp%-exceptions.txt"
			CSVFix validate -vf "%TEMP%\%ScriptName%-CSVTemplate.txt" -om fail %%I.CPY >>"%LOG_PATH%\%FileStamp%-exceptions.txt"
			rem SORT "%LOG_PATH%\AuditFails.csv" | UNIQ >"%LOG_PATH%\AuditFails.uni"
		  )
  	   ) ELSE (
	     rem If CSVFix is missing continue with standard CAT
	     REN %%I.CPY %%I.VAL
	   )
       REM                                                                    /
       REM *******************************************************************

       REM If this is not the first record, then concatenate
       IF EXIST "%LOG_PATH%\AllLogs-%FileStamp%.csv" (
         ECHO    * Concatenating "%%I.VAL" to "AllLogs-%FileStamp%.csv"
         COPY /B /V /Y "%LOG_PATH%\AllLogs-%FileStamp%.csv"+"%%I.VAL" "%LOG_PATH%\AllLogs-%FileStamp%.csv" %DEBUG%
		 IF !ERRORLEVEL!==0 (
           IF "%RemoveSourceLogs%."=="Yes." (DEL /Q %%I.CPY %DEBUG%)
           DEL /Q "%%I.VAL" %DEBUG%
         ) ELSE (
		   SET CopyFails=!CopyFails! %%I,
		   SET /a FailedLogs=FailedLogs+1
		 )
	   ) ELSE (
           REM This is the first record so simply copy
           ECHO    * Copying "%%I.VAL" to AllLogs-%FileStamp%.csv
           COPY /B /V /Y "%%I.VAL" "%LOG_PATH%\AllLogs-%FileStamp%.csv" %DEBUG%
           IF !ERRORLEVEL!==0 (
             IF "%RemoveSourceLogs%."=="Yes." (DEL /Q %%I.CPY %DEBUG%)
			 DEL /Q "%%I.VAL" %DEBUG%
		   ) ELSE (
		     SET CopyFails=!CopyFails! %%I,
			 SET /a FailedLogs=FailedLogs+1
		   )
       )  

       REM Rename the CPY file back or merge if something came in while processing
	   REM and if we are NOT removing source files
	   IF "%RemoveSourceLogs%."=="No." (
		   If EXIST %%I (
		     COPY /B %%I+%%I.CPY %%I
             DEL /Q "%%I.CPY" %DEBUG%
		   ) ELSE (
		     REN %%I.CPY %%I
           )		   
	   )	   

	   rem                                                                    /
       REM *******************************************************************
       REM * Concatenate logs section *
       REM ****************************

REM                                                                              *
REM ******************************************************************************
REM * Main Loop End      *
REM **********************
     )

   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO  -       Processing: !CurrentLog! Copied !FailedLogs! Failed >>%TEMP%\%ScriptName%-Header.tmp


REM *****************************************
REM * Show the Archive File                 *
REM *****************************************
   ECHO  -     Archive file: %LOG_PATH%\AllLogs-%FileStamp%.csv >>%TEMP%\%ScriptName%-Header.tmp
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   
REM *****************************
REM * Optional dupe removal     *
rem *******************************************************************
   If %DeDupe%==Yes (
     CLS
     TYPE %TEMP%\%ScriptName%-Header.tmp
     ECHO  -Duplicates Detect: Checking..
     SORT %LOG_PATH%\AllLogs-%FileStamp%.csv| UNIQ -i >%LOG_PATH%\AllLogs-%FileStamp%.UNIQ
	 COPY /Y /V %LOG_PATH%\AllLogs-%FileStamp%.UNIQ %LOG_PATH%\AllLogs-%FileStamp%.csv
     rem test to see if the copy worked
     IF %ERRORLEVEL%==0 (
       DEL /Q %LOG_PATH%\AllLogs-%FileStamp%.UNIQ %DEBUG%
       ECHO  -Duplicates Detect: Complete.>>%TEMP%\%ScriptName%-Header.tmp
     ) ELSE (
       SET Errors=%Errors%Failed %OutputFileName% create!
       ECHO  -Duplicates Detect: FAILED!>>%TEMP%\%ScriptName%-Header.tmp
     )
   )
REM *****************************
REM * Create the master file    *
rem *******************************************************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO  -     Summary file: Creating Final file..
   COPY /Y /V %LOG_PATH%\AllLogs-%FileStamp%.csv %OutputFileName%
   rem test to see if the copy worked
   IF %ERRORLEVEL%==0 (
     ECHO  -     Summary file: %OutputFileName% >>%TEMP%\%ScriptName%-Header.tmp
   ) ELSE (
     SET Errors=%Errors%Failed %OutputFileName% create!
     ECHO  -     Summary file: Copy FAILED!>>%TEMP%\%ScriptName%-Header.tmp
   )
   
REM *****************************************
REM * Set the end time                      *
REM *****************************************
   :WriteLogExit
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStampFinish=%MyTime% %MyDate%
   
REM **********************************
REM * Write log entry                *
REM **********************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp

   ECHO  -         Log File: Updating..
   rem Check for file, if not there make one with header
   IF NOT EXIST %LOG_PATH%\_SumLog.csv (
     ECHO not FOund
	 ECHO "Script Ver","Start Time","Finish Time","Include Archives","DEL Source Logs","Exceptions Report","Dupe Remove","Logs Processed","Copy Fails","Summary File","Backup File","Error Messages">%LOG_PATH%\_SumLog.csv
   ) ELSE (
    echo found
   )

   REM Replace the nul with a N/A if no errors detected
   IF "%Errors%."=="." SET Errors=N/A

   ECHO "%ScriptVersion%","%TimeStampStart%","%TimeStampFinish%","%IncludeArchives%","%RemoveSourceLogs%","%CreateExceptionsReport%","%DeDupe%","%CurrentLog%","!CopyFails!","%OutputFileName%","%BackupLogFileName%","!Errors!">>%LOG_PATH%\_SumLog.csv && SET LogResult=OK || SET LogResult=Log Create Failed
   IF %ERRORLEVEL%==0 (
     ECHO  -         Log File: %LOG_PATH%\_SumLog.csv.>>%TEMP%\%ScriptName%-Header.tmp
   ) ELSE (
     ECHO  -         Log File: Write FAILED to "%LOG_PATH%\_SumLog.csv.">>%TEMP%\%ScriptName%-Header.tmp
   )

REM *****************************************
REM * Tell user we're done                  *
REM *****************************************
   ECHO  -  Script End Time: %TimeStampFinish% >>%TEMP%\%ScriptName%-Header.tmp
   ECHO  -           Errors: !Errors! >>%TEMP%\%ScriptName%-Header.tmp

   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO.
   GOTO EXIT

REM *****************************************
REM * Script run is complete                *
REM *****************************************
  :EXIT

REM *****************************************
REM * clean-up/Remove temporary files       *
REM *****************************************
   REM Restore the CMD shell window title 
   TITLE Command Prompt
   DEL /Q %TEMP%\%ScriptName%_OnlyComputerLogs.txt %DEBUG%
   DEL /Q %TEMP%\%ScriptName%-Header.tmp %DEBUG%
   DEL /Q %TEMP%\%ScriptName%-CSVTemplate.txt %DEBUG%
   ENDLOCAL

REM *****************************************
REM * Pause may be remarked out if this     *
REM * script is to run automated            *
REM *****************************************
rem  PAUSE

