@ECHO OFF
REM **********************************************
REM *               SendReport.BAT               *
REM *   Send Email Batch (c) Vern Graner SSE     *
REM **********************************************
REM * Sends specified file to address designated *
REM * in the varibables                          *
REM **********************************************
REM * Created 04/04/08 - VLG                     *
REM * Updated 05/14/10 - VLG use GNU mailsend    *
REM * Updated 05/24/10 - VLG parameter pass %1   *
REM *                    for file to send        *
REM * Updated 02/09/11 - VLG add error checks    *
REM * Updated 05/28/13 - VLG add MailInfo.cmd    *
REM **********************************************

REM **********************************
REM * Turn DEBUG on/off              *
REM *****************************************************************************
rem * The >nul 2>&1 redirects output and error output to nul to make clean runs *
rem * NOTE: The reserved characters are delimted with a "^" symbol to make them *
rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"  *
rem * un-REM "SET DEBUG=" to have errors/output of commands dispayed            *
REM *****************************************************************************
   SET DEBUG=^>nul 2^>^&1
rem    SET DEBUG=

REM **********************************
REM * Call MailInfo to populate vars *
REM **********************************
   CALL MailInfo.CMD

REM **********************************
REM * Did they ask for help ?        *
REM **********************************
   IF %1x==?x (
     ECHO.
     ECHO Command Syntax: SendReport [file to send]
     ECHO.
     ECHO Please consult the sendreport-readme.txt file for help
     ECHO.
     GOTO HelpExit
   )

REM **********************************
REM * Begin script message            *
REM **********************************
   CLS
   ECHO.
   ECHO SendReport batch file begin:
     
REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
   ECHO  -Setting Time/Date format..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   Set NOW=%MyDate% %MyTime%

REM *****************************************
REM * Prep the log file                     *
REM *****************************************
   ECHO ------------- Send record for %now% ---------------- >>SendReport.log

REM *****************************************
REM * Preflight Check                       *
REM *****************************************

   REM test to see if a file was specified
   IF %1x==x (
     ECHO.
     ECHO  -ERROR: You MUST supply a file to send!
     ECHO.
     ECHO  -Command Syntax:
     ECHO   SendReport [file to send]
     ECHO  -Please consult the sendreport-readme.txt file for help
     ECHO ERROR! No valid file name passed! >>SendReport.log
     GOTO DONE
   ) 

   REM test to see specified file exists
   IF NOT EXIST "%1" (
     ECHO  -SendReport ERROR: File "%1" not found!
     ECHO  -Please consult the sendreport-readme.txt file for help
     ECHO ERROR! File "%1" not found! >>SendReport.log
     GOTO DONE
   )

REM ********************************************
REM * Detect mime type by parsing %1 extension *
REm * Future expansion                         *
REM ********************************************
    rem Source for MIME types to add here
    rem http://www.w3schools.com/media/media_mimeref.asp

    ECHO  -Checking Attachment type..

    REM Set to binary unless we find a different extension
    SET AttachType=%1,application/octet-stream,a

    DIR %1 2>NUL|FINDSTR /I ".zip" %DEBUG%
    IF %ERRORLEVEL%==0 (
      SET AttachType=%1,application/zip,a
      ECHO  -ZIP compressed file detected
    )
 
    DIR %1 2>NUL|FINDSTR /I ".txt" %DEBUG%
    IF %ERRORLEVEL%==0 (
      SET AttachType=%1,text/plain,a
      ECHO  -Text file detected
    )

    DIR %1 2>NUL|FINDSTR /I ".csv" %DEBUG%
    IF %ERRORLEVEL%==0 (
      SET AttachType=%1,text/plain,a
      ECHO  -CSV Text file detected
    )


REM ********************************************
REM * Send the mail message                    *
REM ********************************************
   IF "%DEBUG%x"=="x" (
     ECHO.
     ECHO Sending Report using the following syntax:
     ECHO %MAILER%
     ECHO          -f %FromAddress%
     ECHO          -d %MailServer%
     ECHO          -smtp %MailServerIP%
     ECHO          -t %ToAddress%
     ECHO          -sub %EmailSubject%
     ECHO          -M "Automated SofTrack report %NOW%."
     ECHO          -attach "%AttachType%"
     ECHO          -auth-login
     ECHO          -user %user%
     ECHO          -password %pass%
     ECHO.
   )

   ECHO  -Sending "%1" to "%ToAddress%"
   ECHO  -Sending "%1" to "%ToAddress%" >>SendReport.log
   %MAILER% -f %FromAddress% -d %MailServer% -smtp %MailServerIP% -t %ToAddress% -sub %EmailSubject% -M "Attached are the automated SofTrack report results from %NOW%." -attach "%1,text/plain,a" -auth-login -user %user% -password %pass% >>SendReport.log 2>&1
   ECHO  -Done! (Check SendReport.log for results)
   ECHO  -Done! >>SendReport.log

REM **********************************
REM * Batch Complete                 *
REM **********************************
   :Done
   ECHO. >>SendReport.log
   ECHO Complete.
   ECHO.
   PAUSE rem NOTE this pause can be removed for automated runs!
   :HelpExit
