@ECHO OFF
REM ******************************************************************
REM *          Quick Inventory Scanner using IP range                *
REM *       By Vern Graner SSE, Integrity Software Inc.              *
REM ******************************************************************
REM * This script "walks" throuh a range of IP adresses,             *
REM * performing an inventory collection on each IP in the range     *
REM *                                                                *
REM * NOTE 1: This script REQUIRES the microsoft utility PsEXEC      *
REM * which can be downloaded from this link:                        *
REM *                                                                *
REM * http://technet.microsoft.com/en-us/sysinternals/bb897553.aspx  *
REM *                                                                *
REM * NOTE 2: The IP address range to be used MUST be entered BEFORE *
REM * this scriptis run! Check the comments in the body of the       *
REM * script for details.                                            *
REM *                                                                *
REM * If you have any questions, or need assistance running this     *
REM * script, please contact support@softwaremetering.com or phone   *
REM * 512-372-8991 x611                                              *
REM ******************************************************************
REM *Revision Info: V1.0a (VLG:) 1-19-2013 First Build               *
REM *               V1.0b (VLG:) 2-04-2013 US/EU time format fix     *
REM ******************************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set script version
     SET ScriptVersion=1.0b
   REM Set varibales to NOT exist when script finishes
     SETLOCAL
   REM Set color to white text on black background
     COLOR 0F
     CLS

REM **********************************
REM * Mandatory Variable definitions *
REM *************************************************************************
REM * WARNING! The following variables MUST be changed BEFORE this script   *
REM * is run. The default variables will NOT work for your environment and  *
REM * the script will abort if they are not changed!                        *
REM * ----------------------------------------------------------------------*
REM * The following are the variables and their uses in the script:         *
REM *                                                                       *
REM * OCT1-------- (Octet 1) the first octet in the IP address              *
REM *                        i.e. 10.x.x.x                                  *
REM *                                                                       *
REM * OCT2_START-- (Octet 2) the first IP in the second octet of the IP     *
REM *                        address range (i.e. x.1.x.x)                   *
REM *                                                                       *
REM * OCT2_END---- (Octet 2) the last IP in the second octet of the IP      *
REM *                        address range (i.e. x.10.x.x)                  *
REM *                                                                       *
REM * OCT3_START-- (Octet 3) the first IP in the third octet of the IP      *
REM *                        address range (i.e. x.x.1.x)                   *
REM *                                                                       *
REM * OCT3_END---- (Octet 3) the last IP in the third octet of the IP       *
REM *                        address range (i.e. x.x.10.x)                  *
REM *                                                                       *
REM * OCT4_START-- (Octet 4) the first IP in the fourth octet of the IP     *
REM *                        address range (i.e. x.x.x.1)                   *
REM *                                                                       *
REM * OCT4_END---- (Octet 4) the last IP in the fourth octet of the IP      *
REM *                        address range (i.e. x.x.x.10)                  *
REM *                                                                       *
REM *  Example: To have this script test the first 100 machines in the      *
REM *           two subnets 192.168.100.x and 192.168.101.x, you would      *
REM *           use the following values:                                   *
REM *                                                                       *
REM *           set oct1=192                                                *
REM *                                                                       *
REM *           set oct2_start=168                                          *
REM *           set oct2_end=168                                            *
REM *                                                                       *
REM *           set oct3_start=100                                          *
REM *           set oct3_end=101                                            *
REM *                                                                       *
REM *           set oct4_start=1                                            *
REM *           set oct4_end=100                                            *
REM *                                                                       *
REM *************************************************************************

REM *****************************************
REM * Set flags to control what the script  *
REM *************************************************************
REM                                                             *

REM **********************************
REM * Set IP address Octets Here     *
REM **********************************
  set oct1=0

  set oct2_start=1
  set oct2_end=254

  set oct3_start=1
  set oct3_end=254

  set oct4_start=1
  set oct4_end=254

GOTO SkipTest
REM **********************************
REM * Integrity test addresses       *
REM **********************************
   set oct1=10

   set oct2_start=1
   set oct2_end=1

   set oct3_start=1
   set oct3_end=1

   set oct4_start=120
   set oct4_end=125
:SkipTest

REM ***********************************
REM * name of the server hosting the  *
REM * SofTrack SSA                    *
REM * May be IPv4 address or DNS name *
REM * i.e. INTEGRITY-2K               *
REM * Note: no preceding slashes!     *
REM ***********************************
  SET SSAHost=10.1.1.102

REM                                                             *
REM *************************************************************
REM * End flag set section                  *
REM *****************************************

REM **********************************
REM * Turn DEBUG on/off              *
REM **********************************
  rem The >nul 2>&1 redirects output and error output to nul to make clean runs
  rem NOTE: The reserved characters are delimted with a "^" symbol to make them
  rem compatible with the set command so ">nul 2>&1" becomes "^>nul 2^>^&1"
  rem un-REM "SET DEBUG=" to have errors/output of commands to be dispayed

  SET DEBUG=^>nul 2^>^&1
  rem  SET DEBUG=

REM **********************************
REM * Add path for PSTools           *
REM **********************************
   SET PATH=%PATH%;%ProgramFiles%\PsTools
   SET PATH=%PATH%;%ProgramFiles(x86)%\PsTools

REM *****************************************
REM * Print Header                          *
REM *****************************************
   DEL /Q %TEMP%\GetInv-Header1.tmp
   ECHO SofTrack Quick Inventory>>%TEMP%\GetInv-Header1.tmp
   ECHO Hardware/Software Collection via IP scan>>%TEMP%\GetInv-Header1.tmp
   ECHO Script version %ScriptVersion% by Vern Graner>>%TEMP%\GetInv-Header1.tmp
   ECHO.>>%TEMP%\GetInv-Header1.tmp
   ECHO Scan Info>>%TEMP%\GetInv-Header1.tmp
   ECHO +---------------+------------------------------------>>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM ************************************
REM * Pre-Flight Check 1: Was script   *
REM * properly modified before use?    *
REM ************************************
   IF %OCT1%==0 (
       SET ErrorMessage=IP range not entered
       SET ScriptResult=FAIL
       GOTO ErrorOut
   )

REM *****************************************
REM * Show IP Test Range for this run       *
REM *****************************************
   ECHO ^|    Test Range ^| %oct1%.%oct2_Start%.%oct3_start%.%oct4_start% to %oct1%.%oct2_end%.%oct3_end%.%oct4_end% >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Show SSA Target                       *
REM *****************************************
   ECHO ^|      SSA Host ^| %SSAHost%>>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM ************************************
REM * Pre-Flight Check 2: Are INVENTRY *
REM * files in place?                  *
REM ************************************
   SET AppCheck=

   CLS
   TYPE %TEMP%\GetInv-Header1.tmp
   ECHO ^|    Apps Check ^| _SMBIOS_.EXE..

   If NOT EXIST _SMBIOS_.EXE (
   ECHO ^|    Apps Check ^| NOT FOUND!
      SET AppCheck=SMBIOS
      SET ErrorMessage=Missing Required File: _SMBIOS_.EXE
      SET ScriptResult=FAIL
      GOTO ErrorOut
   ) ELSE (
      CLS
      TYPE %TEMP%\GetInv-Header1.tmp
   ECHO ^|    Apps Check ^| STNW32.DLL..
   )

   IF NOT EXIST STNW32.DLL (
   ECHO ^|    Apps Check ^| NOT FOUND
      SET AppCheck=%AppCheck%,STNW32
      SET ErrorMessage=Missing Required File: STNW32.DLL
      SET ScriptResult=FAIL
      GOTO ErrorOut
   ) ELSE (
      CLS
      TYPE %TEMP%\GetInv-Header1.tmp
   ECHO ^|    Apps Check ^| INVENTRY.EXE..
   )

   INVENTRY.EXE %DEBUG%
   If %ERRORLEVEL% == 9009 (
   ECHO ^|    Apps Check ^| NOT FOUND
      SET AppCheck=%AppCheck%,INVENTRY
      SET ErrorMessage=Missing Required File: INVENTRY.EXE
      SET ScriptResult=FAIL
      GOTO ErrorOut
   ) ELSE (
      CLS
      TYPE %TEMP%\GetInv-Header1.tmp
   ECHO ^|    Apps Check ^| PSEXEC.EXE..
   )

   PsExec.exe -? %DEBUG%
   If %ERRORLEVEL% == 9009 (
   ECHO ^|    Apps Check ^| NOT FOUND
      SET AppCheck=%AppCheck%,PSEXEC
      SET ErrorMessage=Missing Required File: PSEXEC.EXE
      SET ScriptResult=FAIL
      GOTO ErrorOut
   ) ELSE (
      CLS
      TYPE %TEMP%\GetInv-Header1.tmp
   ECHO ^|    Apps Check ^| COMPLETE!
   )

   If "%AppChecK%."=="." SET AppCheck=PASS

   ECHO ^|    Apps Check ^| %AppCheck% >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Testing INVENTRY.EXE                  *
REM *****************************************
   ECHO ^|  INVENTRY Ver ^| Checking Version Info..
   FOR /F "tokens=5 delims= " %%i in ('TYPE INVENTRY.EXE ^| FIND "SofTrack Quick Inventory Module"') do SET INVENTRY-VER=%%i
   ECHO ^|  INVENTRY Ver ^| %INVENTRY-VER% >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
   ECHO ^|  Script Start ^| Fetching time/date..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format
   rem details at http://www.robvanderwoude.com/datetimentparse.php
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%
   SET FileStamp=%FileDate%_%FileTime%

REM *****************************************
REM * Show START time on header             *
REM *****************************************
   SET TimeStampStart=%TimeStamp%
   ECHO ^|  Script Start ^| %TimeStampStart% >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Show Log file name for this run       *
REM *****************************************
   ECHO ^|      Log Name ^| "GetInv_%FileStamp%.csv" >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Show Log file path for this run       *
REM *****************************************
   ECHO ^|      Log Path ^| "%~dp0" >>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM *****************************************
REM * Put bottom on header                  *
REM *****************************************
   ECHO +---------------+------------------------------------>>%TEMP%\GetInv-Header1.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp

REM **********************************
REM * Setup variables for display    *
REM **********************************
   SET OCT1_Disp=%Oct1%
   SET OCT2_Disp=%OCT2_end%
   SET OCT3_Disp=%OCT3_end%
   SET OCT4_Disp=%OCT4_end%

REM **********************************
REM * Setup variables for use.       *
REM * NOTE: Should not be modified!  *
REM **********************************
  set /a OCT4_end=oct4_end+1
  set /a OCT3_end=oct3_end+1
  set /a OCT2_end=oct2_end+1
  set OCT4=%OCT4_START%
  set OCT3=%OCT3_START%
  set OCT2=%OCT2_START%

REM **********************************
REM * Everything here is done ONCE   ***********************************
REM * per IP address                 *                                 *
REM **********************************                                 *
:LBEG

REM *****************************************
REM * Reset Variables for each iteration    *
REM *****************************************
  SET IPTest=N/A
  SET DNSname=N/A
  SET ErrorMessage=N/A
  SET ScriptResult=OK

REM **********************************
REM * INIT loop header               *
REM **********************************
  ECHO.>%TEMP%\GetInv-Header2.tmp
  ECHO Current Target Info>>%TEMP%\GetInv-Header2.tmp
  ECHO +---------------+------------------------------------>>%TEMP%\GetInv-Header2.tmp

REM **********************************
REM * Show Target for this iteration *
REM **********************************
  ECHO ^|     Target IP ^| %oct1%.%oct2%.%oct3%.%oct4% >>%TEMP%\GetInv-Header2.tmp
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp

REM *****************************************
REM * Begin Ping test of target IP          *
REM *****************************************
  ECHO ^|          PING ^| Testing..

  PING -n 1 -w 10 %oct1%.%oct2%.%oct3%.%oct4% %DEBUG%
  IF %ERRORLEVEL%==1 (
    SET IPtest=Failed
    ECHO ^|          PING ^| No Response >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=PING failed
    SET ScriptResult=Skipped
    GOTO SkipTest
  ) ELSE (
    SET IPTest=Passed
    ECHO ^|          PING ^| Responded >>%TEMP%\GetInv-Header2.tmp
  )
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp

REM *****************************************
REM * Attempting to resolve host name       *
REM *****************************************
  ECHO ^| DNS Host Name ^| Looking up..
  FOR /F "tokens=2,3 delims= " %%A IN ('PING -a -n 1 -w 10 %oct1%.%oct2%.%oct3%.%oct4%') DO IF "%%B"=="[%oct1%.%oct2%.%oct3%.%oct4%]" SET DNSname=%%A
  IF "%DNSname%"=="N/A" (
    ECHO ^| DNS Host Name ^| N/A >>%TEMP%\GetInv-Header2.tmp
  ) ELSE (
    ECHO ^| DNS Host Name ^| %DNSname% >>%TEMP%\GetInv-Header2.tmp
  )
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp

REM *****************************************
REM * Begin C$ directory tests              *
REM *****************************************
  REM Read Check via DIR
  ECHO ^|     C$ Access ^| Read Check..
  DIR \\%oct1%.%oct2%.%oct3%.%oct4%\c$ %DEBUG%
  IF %ERRORLEVEL%==1 (
    CLS
    TYPE %TEMP%\GetInv-Header1.tmp
    TYPE %TEMP%\GetInv-Header2.tmp
    ECHO ^|     C$ Access ^| Read Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=C$ Read Access fail
    SET ScriptResult=Skipped
    GOTO SKIPTEST
  ) ELSE (
    CLS
    TYPE %TEMP%\GetInv-Header1.tmp
    TYPE %TEMP%\GetInv-Header2.tmp
    ECHO ^|     C$ Access ^| OK
  )

  REM Write check via temp file
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp
  ECHO ^|     C$ Access ^| Write Check..
  ECHO Test File >\\%oct1%.%oct2%.%oct3%.%oct4%\c$\testfile.txt
  IF %ERRORLEVEL%==1 (
    SET CDOLLAR=Write Failed
    CLS
    TYPE %TEMP%\GetInv-Header1.tmp
    TYPE %TEMP%\GetInv-Header2.tmp
    ECHO ^|     C$ Access ^| Write Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=C$ Write Access fail
    SET ScriptResult=Skipped
    GOTO SKIPTEST
  ) ELSE (
    SET CDOLLAR=%CDOLLAR%/Writeable
    CLS
    TYPE %TEMP%\GetInv-Header1.tmp
    TYPE %TEMP%\GetInv-Header2.tmp
    ECHO ^|     C$ Access ^| OK
    DEL /q \\%oct1%.%oct2%.%oct3%.%oct4%\c$\testfile.txt %DEBUG%
  )

  ECHO ^|     C$ Access ^| OK >>%TEMP%\GetInv-Header2.tmp
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp


REM *****************************************
REM * Copy the files to target              *
REM *****************************************
  ECHO ^|    Temp Files ^| Make Target Dir..
  MD \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP %DEBUG%

  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp
  ECHO ^|    Temp Files ^| Copying INVENTRY.EXE

  XCOPY /Y inventry.exe \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP %DEBUG%
  IF %ERRORLEVEL%==1 (
    ECHO ^|    Temp Files ^| Copy Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=INVENTRY.EXE copy failed
    SET ScriptResult=Skipped
    GOTO SKIPTEST
  )

  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp
  ECHO ^|    Temp Files ^| Copying _SMBIOS_.EXE

  XCOPY /Y _smbios_.exe \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP %DEBUG%
  IF %ERRORLEVEL%==1 (
    ECHO ^|    Temp Files ^| Copy Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=_SMBIOS_.EXE copy failed
    SET ScriptResult=Skipped
    GOTO SKIPTEST
  )

  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp
  ECHO ^|    Temp Files ^| Copying STNW32.DLL

  XCOPY /Y stnw32.dll \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP %DEBUG%
  IF %ERRORLEVEL%==1 (
    ECHO ^|    Temp Files ^| Copy Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=STNW32.DLL copy failed
    SET ScriptResult=Skipped
    GOTO SKIPTEST
  )

  ECHO ^|    Temp Files ^| Staged >>%TEMP%\GetInv-Header2.tmp

REM *****************************************
REM * INVOKE the inventory collection       *
REM *****************************************
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp
  ECHO ^|     Inventory ^| Collecting, standby.. ^(~20s^)

  PSEXEC \\%oct1%.%oct2%.%oct3%.%oct4% -h -s -accepteula C:\INV-TMP\INVENTRY.EXE %SSAHost% %DEBUG%
  IF %ERRORLEVEL%==0 (
    ECHO ^|     Inventory ^| Collected >>%TEMP%\GetInv-Header2.tmp
  ) ELSE (
    ECHO ^|     Inventory ^| PsExec Failed! >>%TEMP%\GetInv-Header2.tmp
    SET ErrorMessage=PsExec of INVENTRY failed
    SET ScriptResult=WARN
  )


REM *****************************************
REM * Remove temp files from target         *
REM *****************************************
  DEL /Q \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP\inventry.exe %DEBUG%
  DEL /Q \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP\_smbios_.exe %DEBUG%
  DEL /Q \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP\stnw32.dll %DEBUG%
  RD \\%oct1%.%oct2%.%oct3%.%oct4%\c$\INV-TMP %DEBUG%


REM *****************************************
REM * Jump to here if Failures detected     *
REM *****************************************
  :SkipTest
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp

REM *****************************************
REM * Write log file                        *
REM *****************************************
  ECHO ^|      Log File ^| Updating..

REM *****************************************
REM * Fetch and Format Date/Tim             *
REM *****************************************
REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
   ECHO ^|  Script Start ^| Fetching time/date..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format
   rem details at http://www.robvanderwoude.com/datetimentparse.php
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%

   REM Creates a N/A result if no errors have been produced during the script run
   IF "%ErrorMessage%."=="." SET ErrorMessage=N/A

   REM If this is a new log, start it with a header
   IF NOT EXIST "%~dp0GetInv_%FileStamp%.csv" (
    ECHO "Run time","Target IP","DNS Name","INVENTRY ver","SSA Host","Result","Errors">"%~dp0GetInv_%FileStamp%.csv"
   )

  ECHO "%TimeStamp%","%oct1%.%oct2%.%oct3%.%oct4%","%DNSname%","%INVENTRY-VER%","%SSAHost%","%ScriptResult%","%ErrorMessage%" >>"%~dp0GetInv_%FileStamp%.csv"

  ECHO ^|      Log File ^| Updated >>%TEMP%\GetInv-Header2.tmp
  CLS
  TYPE %TEMP%\GetInv-Header1.tmp
  TYPE %TEMP%\GetInv-Header2.tmp


REM **********************************     *
REM * END of Once per IP iteration   *******
REM **********************************


REM **********************************
REM * IP address increment loop      *
REM * BEGIN                          *
REM **********************************

rem OCT4 loop
  set /a oct4=oct4+1
  IF NOT %OCT4%==%OCT4_END% GOTO LBEG
SET OCT4=%OCT4_START%


rem OCT3 loop
  set /a oct3=oct3+1
  IF NOT %OCT3%==%OCT3_END% GOTO LBEG
SET OCT3=%OCT3_START%


rem OCT2 loop
  set /a oct2=oct2+1
  IF NOT %OCT2%==%OCT2_END% GOTO LBEG
SET OCT2=%OCT2_START%

REM **********************************
REM * IP address increment loop      *
REM * END                            *
REM **********************************
   ECHO +---------------+------------------------------------>>%TEMP%\GetInv-Header2.tmp
   CLS
   TYPE %TEMP%\GetInv-Header1.tmp
   TYPE %TEMP%\GetInv-Header2.tmp
   GOTO EXIT

REM **********************************
REM * Loop Error trap section        *
REM * Handles known errors           *
REM **********************************
   :ErrorOut
   ECHO +---------------+------------------------------------
   ECHO ^| WARNING! Script failed!
   ECHO ^| Error Message: "%ErrorMessage%"
   ECHO +----------------------------------------------------
   GOTO EXIT

REM **********************************
REM * Done                           *
REM **********************************
   :EXIT
   DEL /Q %TEMP%\GetInv-Header1.tmp %DEBUG%
   DEL /Q %TEMP%\GetInv-Header2.tmp %DEBUG%

REM **********************************
REM * Echo end of script and Set     *
REM * screen color to red/yel/grn    *
REM **********************************

   REM Red background, white text
   IF "%ScriptResult%."=="FAIL." COLOR 4F

   REM yellow background, black text
   IF "%ScriptResult%."=="WARN." (
     COLOR E0
   )

   REM green background, white text
   IF "%ScriptResult%."=="PASS." COLOR A0
   ECHO.
   PAUSE
   ECHO.
   ECHO Script Exit

   COLOR 0F
