@ECHO OFF
REM ***************************************************************
REM *                      SSASync.BAT                            *
REM *               SSA Data Synchronizer script                  *
REM *        By Vern Graner SSE, Integrity Software Inc.          *
REM *************************************************************** 
 REM * This script is used to check for the availability of a     *
 REM * "Host" SSA and transfer the locally collected data up to it*
 REM *                                                            *
 REM * If you have any questions, or need assistance configuring  * 
 REM * /implementing /troubleshooting this script, please contact *
 REM * vgraner@softwaremetering.com or call our support line at   *
 REM * 512-372-8991 M-F 7:30a to 5:30p CT USA (GMT-6)             *
 REM **************************************************************
 REM *Rev Info: V1.0a (VLG) 09-26-2013 First Build                *
 REM *Rev Info: V1.0b (VLG) 10-15-2013 SSASync->SYSTEM32 4 Sched  *
 REM *Rev Info: V1.0c (VLG) 10-29-2013 use wks name as target path*
 REM *Rev Info: V1.0d (VLG) 11-05-2013 update error traps         *
 REM *          NOTE: Mod script version to last value!           *
 REM **************************************************************

 REM **********************************
 REM * Ideas/Improvements/notes       *
 REM * for internal use only          *
 REM ****************************************************************
 REM -use header files for more streamlined run look
 REM ****************************************************************

REM *****************************************
REM * Environment Setup                     *
REM *****************************************
   REM Set script version
     SET ScriptVersion=1.0c
     TITLE SSA Data Synchronizer v%ScriptVersion% by Vern Graner
   REM Set variables to NOT exist when script finishes
     SETLOCAL EnableDelayedExpansion
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM Set temporary Path to in case it has been altered from stock
     SET PATH=%SYSTEMROOT%;%SYSTEMROOT%\SYSTEM32;%SYSTEMROOT%\SYSTEM32\WBEM

   REM **************************************
   REM Set variables for log file
   REM **************************************
      SET InvCopy=N/A
      SET AppMerge=N/A
      SET AuditMerge=N/A
      SET LogonMerge=N/A
      SET TimekeepMerge=N/A
      SET QI_CHGMerge=N/A
	  SET LOGONLMerge=N/A
	  SET AlertEXEMerge=N/A
	  SET ScriptResult=PASS
	  
   REM ********************************************
   REM * Variables set by STConfig.CMD            *
   REM * DO NOT set these here! use STconfig.CMD  *
   REM * located in the Integrity SOftware Inc    *
   REM * folder!                                  *
   REM ********************************************
	  REM SSATarget=<name of server hosting SSA>
      REM SSATargetPath=<share where data is uploaded>
      REM SSASyncInterval=<minutes between sync attempts>
	  
   REM **********************************
   REM * Turn DEBUG on/off              *
   REM *************************************************************************
   REM * The >nul 2>&1 redirects output and error output to nul to make clean  *
   REM * runs. NOTE: The reserved characters are delimited with a "^" symbol to*
   REM * make them compatible with the "set" command, so ">nul 2>&1" becomes   *
   REM * "^>nul 2^>^&1" un-REM "SET DEBUG=" to have errors/output of commands  *
   REM * displayed. Only change if instructed to do so by Tech Support or if   *
   REM * you're just the curious sort that would like to see it work. :)       *
   REM *************************************************************************
     SET DEBUG=^>nul 2^>^&1
     rem SET DEBUG=

REM *****************************************
REM * Create/Display header                 *
REM *****************************************
  ECHO.
  ECHO SSASync (v%ScriptVersion%) by Vern Graner
  ECHO Uploads local STDATA store to primary SofTrack Server
  ECHO.
  ECHO System Check:
  ECHO --------------------------------------------------------------  

REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
  (echo.|set /p =*    Script Start Time: )

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%
   ECHO %MyTime% %MyDate%

  REM *****************************************
  REM * Determine 32/64 bit OS rev and        *
  REM * set appropriate target path           *
  REM *****************************************
   IF "%DEBUG%."=="." ECHO  -Checking for 64-bit system..
   REG QUERY HKLM\Hardware\Description\System\CentralProcessor\0 | FIND /i "x86" %DEBUG%
   If %ERRORLEVEL% == 0 (
        SET ISWPath=%SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1
        rem SET OS64="No"
   ) ELSE (
        SET ISWPath=%SystemDrive%\PROGRA~2\INTEGR~1\WORKST~1
        rem SET OS64="Yes"
   )
   
  REM *****************************************
  REM * Check/Read the STCONFIG.CMD           *
  REM *****************************************
  (echo.|set /p =*        STConfig File: )
    rem IF "%DEBUG%."=="." ECHO  -Locating "STCONFIG.CMD"..
    REM Check for STConfig.CMD in location from which batch file was launched
    IF EXIST "%~dp0STCONFIG.CMD" (
      SET STConfigPath=%~dp0
      ECHO Found [%~dp0] 
      GOTO FileFound
    )

   REM Check for STConfig.CMD in "Integrity Software Inc" folder
   IF EXIST "%ISWPath%\STCONFIG.CMD" (
     SET STConfigPath=%ISWpath%
     ECHO Found [%ISWpath%] 
     GOTO FileFound
   )

   REM Check for STConfig.CMD in AD SCRIPTS folder
   IF EXIST "\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\STCONFIG.CMD" (
     SET STConfigPath=\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\
     ECHO Found [\\%USERDNSDOMAIN%\SYSVOL\%USERDNSDOMAIN%\SCRIPTS\] 
     GOTO FileFound
   )

   ECHO  -FATAL ERROR: "STCONFIG.CMD" File NOT FOUND! Aborting..
   SET STConfigPath=Invalid
   SET ErrorMessage=%ErrorMessage%STCONFIG.CMD not found, 
   SET ScriptResult=FAIL
   ECHO NOT found!
   GOTO ScriptAbort

   :FileFound
   REM Gets here if we find the STConfig.CMD file
   CALL "%STConfigPath%\STCONFIG.CMD"
   
REM *****************************************
REM * Begin Ping test of target IP          *
REM *****************************************
  (echo.|set /p =*        SSA Host Ping: )
   PING -n 1 -w 1000 %SSATarget% %DEBUG%
   IF %ERRORLEVEL%==0 (
     SET PingTest=Passed
     ECHO Responded
   ) ELSE (
     SET PingTest=Failed
     SET ScriptResult=WARN
     Set ErrorMessage=PING of "%SSATarget%" Failed- Upload Aborted
     ECHO Timed out!
     GOTO ScriptAbort
   )
   
REM **********************************************
REM * Check SSA Host sync target for WRITE right *
REM **********************************************
  (echo.|set /p =*        SSA Host Path: )
  
   SET STLOGPath=\\%SSATarget%\%SSATargetPath%\%ComputerName%\

   REM Make sure computer name folder exists
   IF NOT EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%" (
     MD "\\%SSATarget%\%SSATargetPath%\%ComputerName%" %DEBUG%
   )

   rem Make sure no existing test file is present
   IF EXIST "%STLOGPath%\%COMPUTERNAME%-WriteTest.tmp" (
     DEL /q "%STLOGPath%\%COMPUTERNAME%-WriteTest.tmp" %DEBUG%
   )

   ECHO WriteTest >"%STLOGPath%\%COMPUTERNAME%-WriteTest.tmp"

   IF EXIST "%STLOGPath%\%COMPUTERNAME%-WriteTest.tmp" (
     ECHO Writable [%STLOGPath%] 
     SET TargetPath=Writable
	 rem Create a LOCK file to insure SSA host script doesn't process data during upload
	 ECHO Computer %ComputerName% locked at %FileStamp% by user "%UserName%">%STLOGPath%\SyncLock.txt
     DEL /q "%STLOGPath%\%COMPUTERNAME%-WriteTest.tmp" %DEBUG%
   ) ELSE (
     ECHO NOT Writable! [%STLOGPath%]
     SET TargetPath=NOT Writable
     Set ErrorMessage=Failed
     GOTO ScriptAbort
   )

REM *****************************************
REM * make sure target has folders          *
REM *****************************************
   IF NOT EXIST "%STLOGPath%\COMPUTERS" MD "%STLOGPath%\COMPUTERS" %DEBUG%
   IF NOT EXIST "%STLOGPath%\AUDIT" MD "%STLOGPath%\AUDIT" %DEBUG%
   IF NOT EXIST "%STLOGPath%\LOGON" MD "%STLOGPath%\LOGON" %DEBUG%
   
REM *****************************************
REM * MAIN: Copy local files to SSA Host    *
REM *****************************************
  ECHO.
  ECHO Sync files:
  ECHO --------------------------------------------------------------  

  REM **********************************
  REM * Copy up the inventory.new file
  REM **********************************
     (echo.|set /p =*       Inventory file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%" (
       SET OKtoDel=No
	   SET InvSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipInvSync
     )

     REM Copy up the inventory file
     COPY /V /Y "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\COMPUTERS\%COMPUTERNAME%.new" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET InvSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
          ) ELSE (
       SET InvSync=Copy Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Inventory Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
     )

     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local INVENTORY_CHG file
       DEL /Q "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%"
	 )
     :SkipInvSync

  REM **********************************
  REM * Sync the inventory .APP file
  REM **********************************
     (echo.|set /p =*  Inventory .APP file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%.app" (
       SET OKtoDel=No
	   SET AppSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAppSync
     )
	 
     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\COMPUTERS\%COMPUTERNAME%.app" GOTO DoAppMerge
     COPY /V /Y "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%.app" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\COMPUTERS\%COMPUTERNAME%.app" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AppSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipAppMerge
	 ) ELSE (
       SET AppSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% App Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAppMerge
     )		

     :DoAppMerge
	 REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\COMPUTERS\%COMPUTERNAME%.app"+"%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%.app" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\COMPUTERS\%COMPUTERNAME%.app" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AppSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
          ) ELSE (
       SET AppSync=Failed
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% App Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipAppMerge
     
	 IF "%OKtoDel%."=="Yes." (
	   rem ECHO  - Deleting local APP file
	   DEL /Q "%ISWPath%\STDATA\COMPUTERS\%COMPUTERNAME%.app"
     ) 
     :SkipAppSync

  REM **********************************
  REM * Cat the AlertEXE Trail (binary merge)
  REM **********************************
     (echo.|set /p =*        AlertEXE file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\AlertEXE" (
       SET OKtoDel=No
	   SET AlertEXESync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAlertEXESync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AlertEXE" GOTO DoAlertEXEMerge
     COPY /V /Y "%ISWPath%\STDATA\AlertEXE" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AlertEXE" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AlertEXESync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipAlertEXEMerge
     ) ELSE (
       SET AlertEXESync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% AlertEXE Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAlertEXEMerge
     )
	 
     :DoAlertEXEMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AlertEXE"+"%ISWPath%\STDATA\AlertEXE" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AlertEXE" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AlertEXESync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET AlertEXESync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% AlertEXE Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipAlertEXEMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local QI_CHG file
       DEL /Q "%ISWPath%\STDATA\AlertEXE"
     )
	 
     :SkipAlertEXESync

  REM **********************************
  REM * Sync QI_CHG Trail 
  REM **********************************
     (echo.|set /p =*          QI_CHG file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\QI_CHG.log" (
       SET OKtoDel=No
	   SET QI_CHGSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHG.LOG" GOTO DoQI_CHGMerge
     COPY /V /Y "%ISWPath%\STDATA\QI_CHG.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHG.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipQI_CHGMerge
     ) ELSE (
       SET QI_CHGSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHG Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGMerge
	 )
	 
     :DoQI_CHGMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHG.log"+"%ISWPath%\STDATA\QI_CHG.log" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHG.log" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET QI_CHGSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHG Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local QI_CHG file
       DEL /Q "%ISWPath%\STDATA\QI_CHG.log"
     )

     :SkipQI_CHGSync

 REM **********************************
  REM * Sync QI_CHGIP Trail 
  REM **********************************
     (echo.|set /p =*        QI_CHGIP file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\QI_CHGIP.log" (
       SET OKtoDel=No
	   SET QI_CHGIPSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGIPSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGIP.LOG" GOTO DoQI_CHGIPMerge
     COPY /V /Y "%ISWPath%\STDATA\QI_CHGIP.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGIP.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGIPSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipQI_CHGIPMerge
     ) ELSE (
       SET QI_CHGIPSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHGIP Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGIPMerge
	 )
	 
     :DoQI_CHGIPMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGIP.log"+"%ISWPath%\STDATA\QI_CHGIP.log" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGIP.log" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGIPSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET QI_CHGIPSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHGIP Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGIPMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local QI_CHGIP file
       DEL /Q "%ISWPath%\STDATA\QI_CHGIP.log"
     )

     :SkipQI_CHGIPSync

  REM **********************************
  REM * Sync QI_CHGPR Trail 
  REM **********************************
     (echo.|set /p =*        QI_CHGPR file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\QI_CHGPR.log" (
       SET OKtoDel=No
	   SET QI_CHGPRSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGPRSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGPR.LOG" GOTO DoQI_CHGPRMerge
     COPY /V /Y "%ISWPath%\STDATA\QI_CHGPR.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGPR.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGPRSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipQI_CHGPRMerge
     ) ELSE (
       SET QI_CHGPRSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHGPR Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGPRMerge
	 )
	 
     :DoQI_CHGPRMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGPR.log"+"%ISWPath%\STDATA\QI_CHGPR.log" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\QI_CHGPR.log" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET QI_CHGPRSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET QI_CHGPRSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHGPR Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGPRMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local QI_CHGPR file
       DEL /Q "%ISWPath%\STDATA\QI_CHGPR.log"
     )

     :SkipQI_CHGPRSync

	 
  REM **********************************
  REM * Sync the Audit Trail Log       *
  REM **********************************
     (echo.|set /p =*       Audit Log file:)
     REM Check to make sure there is a LOCAL Audit file to send
     IF NOT EXIST "%ISWPath%\STDATA\AUDIT\%COMPUTERNAME%" (
       SET OKtoDel=No
	   SET AuditSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAuditSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AUDIT\%COMPUTERNAME%" GOTO DoAuditMerge
     COPY /V /Y "%ISWPath%\STDATA\AUDIT\%COMPUTERNAME%" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AUDIT\%COMPUTERNAME%" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AuditSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipAuditMerge
     ) ELSE (
       SET AuditSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Audit Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAuditMerge
     )	   

     :DoAuditMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AUDIT\%COMPUTERNAME%"+"%ISWPath%\STDATA\AUDIT\%COMPUTERNAME%" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\AUDIT\%COMPUTERNAME%" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AuditSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
          ) ELSE (
       SET AuditSync=Failed
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Audit Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipAuditMerge
	 
     IF "%OKtoDel%."=="Yes." (
	   rem ECHO  - Deleting local Audit file
       DEL /Q "%ISWPath%\STDATA\AUDIT\%COMPUTERNAME%"
	 ) 
     :SkipAuditSync

  REM **********************************
  REM * Sync the Logon log
  REM **********************************
     (echo.|set /p =*           Logon file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\LOGON\%COMPUTERNAME%" (
	   SET LogonSync=Not Found
       SET OKtoDel=No
       ECHO  Skipped [Not Found]
       GOTO SkipLogonSync
     )
     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGON\%COMPUTERNAME%" GOTO DoLogonMerge
     COPY /V /Y "%ISWPath%\STDATA\LOGON\%COMPUTERNAME%" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGON\%COMPUTERNAME%" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET LogonSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipLogonMerge
     ) ELSE (
       SET LogonSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Logon Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipLogonMerge
	 )

	 :DoLogonMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Logon\%COMPUTERNAME%"+"%ISWPath%\STDATA\Logon\%COMPUTERNAME%" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Logon\%COMPUTERNAME%" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET LogonSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
          ) ELSE (
       SET LogonSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Logon Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipLogonMerge

     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting local Logon file
       DEL /Q "%ISWPath%\STDATA\Logon\%COMPUTERNAME%"
     )
     :SkipLogonSync

     REM **********************************
     REM * Cat the LOGONL Trail (binary merge)
     REM **********************************
     (echo.|set /p =*          LOGONL file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\LOGONL.log" (
	   SET LOGONLSync=Not Found
       SET OKtoDel=No
       ECHO  Skipped [Not Found]
       GOTO SkipLOGONLSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGONL.log" GOTO DoLOGONLMerge
     COPY /V /Y "%ISWPath%\STDATA\LOGONL.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGONL.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET LOGONLSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipLOGONLMerge
     ) ELSE (
       SET LOGONLSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% LOGONL Copy %ERRORLEVEL%, 
       ECHO  WARNING Copy failed
       GOTO SkipLOGONLMerge
     )

	 :DoLOGONLMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGONL.LOG"+"%ISWPath%\STDATA\LOGONL.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\LOGONL.log" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET LOGONLSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
          ) ELSE (
       SET LOGONLSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% LOGONL Merge %ERRORLEVEL%, 
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipLOGONLMerge
     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting local LOGONL file
       DEL /Q "%ISWPath%\STDATA\LOGONL.log"
     )

     :SkipLOGONLSync

  REM **********************************
  REM * Sync Timekeeper Trail 
  REM **********************************
     (echo.|set /p =*      Timekeeper file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\Timekeep.csv" (
	   SET TimekeepSync=Not Found
       SET OKtoDel=No
       ECHO  Skipped [Not Found]
       GOTO SkipTimekeepSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Timekeep.csv" GOTO DoTimekeepMerge
     COPY /V /Y "%ISWPath%\STDATA\Timekeep.csv" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Timekeep.csv" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET TimekeepSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipTimekeepMerge
	 ) ELSE (
       SET TimekeepSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Timekeep Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipTimekeepMerge
     )	   

	 :DoTimekeepMerge
     REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Timekeep.csv"+"%ISWPath%\STDATA\Timekeep.csv" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Timekeep.csv" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET TimekeepSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET TimekeepSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Timekeep Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipTimekeepMerge
     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting local Timekeeper file
       DEL /Q "%ISWPath%\STDATA\Timekeep.csv"
     )

     :SkipTimekeepSync

  REM ******************************************
  REM * Cat the Meter.log Trail (binary merge)
  REM ******************************************
     (echo.|set /p =*       METER.LOG file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\METER.LOG" (
       SET OKtoDel=No
	   SET MeterlogSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipMeterlogSync
     )

     REM Check to see if this is the FIRST app file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\METER.LOG" GOTO DoMeterlogMerge
       COPY /V /Y "%ISWPath%\STDATA\Meter.log" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Meter.LOG" %DEBUG%
       IF %ERRORLEVEL%==0 (
         SET MeterlogSync=Copied
         SET OKtoDel=Yes
         ECHO  Copied
         GOTO SkipMeterlogMerge
       ) ELSE (
         SET MeterlogSync=Copy Fail
         SET OKtoDel=No
         SET ErrorMessage=%ErrorMessage% Meterlog Copy %ERRORLEVEL%, 
         SET ScriptResult=WARN
         ECHO  WARNING Sync failed
         GOTO SkipMeterlogMerge
	   )
     )

     :DoMeterlogMerge
     REM if the target file is present, merge with it
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\METER.LOG"+"%ISWPath%\STDATA\METER.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\METER.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET MeterlogSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET MeterlogSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Meterlog Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipMeterlogMerge
	 IF "%OKtoDel%."=="Yes." (
        rem ECHO  - Deleting local METER.LOG file
        DEL /Q "%ISWPath%\STDATA\Meter.log"
     )
 
     :SkipMeterlogSync

  REM **********************************
  REM * Sync Alerts.LOG file
  REM **********************************
     (echo.|set /p =*    Token Alerts file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%ISWPath%\STDATA\Alerts.LOG" (
	   SET AlertsSync=Not Found
       SET OKtoDel=No
       ECHO  Skipped [Not Found]
       GOTO SkipAlertsSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Alerts.LOG" GOTO DoAlertsMerge
     COPY /V /Y "%ISWPath%\STDATA\Alerts.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Alerts.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AlertsSync=Copied
       SET OKtoDel=Yes
       ECHO  Copied
       GOTO SkipAlertsMerge
     ) ELSE (
       SET AlertsSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Alerts Copy %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAlertsMerge
     )	   

     :DoAlertsMerge
	 REM use MERGE if there is an existing file
     COPY /B "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Alerts.LOG"+"%ISWPath%\STDATA\Alerts.LOG" "\\%SSATarget%\%SSATargetPath%\%ComputerName%\Alerts.LOG" %DEBUG%
     IF %ERRORLEVEL%==0 (
       SET AlertsSync=Merged
       SET OKtoDel=Yes
       ECHO  Merged
     ) ELSE (
       SET AlertsSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Alerts Merge %ERRORLEVEL%, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipAlertsMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting local Alerts file
       DEL /Q "%ISWPath%\STDATA\Alerts.LOG"
     )

     :SkipAlertsSync

   REM *******************************
   REM * Sync process end
   REM *******************************
     :ScriptAbort
 
     ECHO.
     ECHO Update Log:
     ECHO --------------------------------------------------------------  
 
REM *****************************************
REM * Write log files                       *
REM *****************************************
    (echo.|set /p =* Log File Update:)

    REM Creates a N/A result if no errors have been produced during the script run
     IF "%ErrorMessage%."=="." SET ErrorMessage=N/A

    REM Write the log file to the local machine
	rem **************************************************
      REM Put a header on it if it doesn't exist
       IF NOT EXIST "%ISWPath%\STDATA\SSAHostSyncLog.CSV" (
         ECHO "Time Run","Script Version","Run By","Workstation Name","Script Result","Sync Target","Ping Test","Target Path","Inventory File","Inv .APP File","Audit Log","Logon Log","TimeKeeper Log","QI_CHG Log","QI_CHGIP Log","QI_CHGPR LOG","LOGONL Log","AlertEXE Log","Token Alerts","Errors">"%ISWPath%\STDATA\SSAHostSyncLog.CSV"
       )
       REM Append a log line
       ECHO "%TIMESTAMP%","%ScriptVersion%","%UserName%","%COMPUTERNAME%","%ScriptResult%","\\%SSATarget%\%SSATargetPath%\%ComputerName%\","%PingTest%","%TargetPath%","%InvSync%","%AppSync%","%AuditSync%","%LogonSync%","%TimekeepSync%","%QI_CHGSync%","%QI_CHGIPSync%","%QI_CHGPRSync%","%LOGONLSync%","%AlertEXESync%","%AlertsSync%","%ErrorMessage%">>"%ISWPath%\STDATA\SSAHostSyncLog.CSV"

    REM Write the log file to the Target Server machine
	rem **************************************************
     IF %ScriptResult%=="FAIL" GOTO NoMasterLogSync
       REM Put a header on it if it doesn't exist
       IF NOT EXIST "\\%SSATarget%\%SSATargetPath%\%ComputerName%\SSAHostSyncLog.CSV" (
         ECHO "Time Run","Script Version","Run By","Workstation Name","Script Result","Sync Target","Ping Test","Target Path","Inventory File","Inv .APP File","Audit Log","Logon Log","TimeKeeper Log","QI_CHG Log","QI_CHGIP Log","QI_CHGPR LOG","LOGONL Log","AlertEXE Log","Token Alerts","Errors">"\\%SSATarget%\%SSATargetPath%\%ComputerName%\SSAHostSyncLog.CSV"
       )
       REM Append a log line 
       ECHO "%TIMESTAMP%","%ScriptVersion%","%UserName%","%COMPUTERNAME%","%ScriptResult%","\\%SSATarget%\%SSATargetPath%\%ComputerName%\","%PingTest%","%TargetPath%","%InvSync%","%AppSync%","%AuditSync%","%LogonSync%","%TimekeepSync%","%QI_CHGSync%","%QI_CHGIPSync%","%QI_CHGPRSync%","%LOGONLSync%","%AlertEXESync%","%AlertsSync%","%ErrorMessage%">>"\\%SSATarget%\%SSATargetPath%\%ComputerName%\SSAHostSyncLog.CSV"
	
	:NoMasterLogSync
	
    ECHO  Complete 
    ECHO *   Log File Path: "%ISWPath%\STDATA\SSASync-%COMPUTERNAME%.CSV"

REM **********************************
REM * Echo end of script and set     *
REM * screen color to red/yel/grn    *
REM **********************************
   (echo.|set /p =*   Script Status: )
   REM Red background, white text
   IF %ScriptResult%==FAIL (
   COLOR 4F
     ECHO %ScriptResult%
   )

   REM yellow background, black text
   IF %ScriptResult%==WARN (
     COLOR E0
     ECHO %ScriptResult%
   )

   REM green background, white text
   IF %ScriptResult%==PASS (
     COLOR A0
     ECHO %ScriptResult%
   )

  ECHO *  Error Messages: %ErrorMessage%

   
REM *****************************************
REM * Closing comments and tasks
REM *****************************************
     REM Remove the lock to allow SSA to process uploaded data
	 DEL /Q %STLOGPath%\SyncLock.txt %DEBUG%
     REM Tell user we're done
     ECHO.
	 ECHO Script Complete:
     ECHO --------------------------------------------------------------  
     ECHO * Check log file ^(noted above^) for run details
   
REM *****************************************
REM * Done! Skynet uplink soon... ;)        *
REM *****************************************
   rem Return color scheme to white on black
   ECHO.
   COLOR 0F
   TITLE Command Prompt
   rem note: "endlocal" clears all the variables used in this script
   ENDLOCAL

