@ECHO OFF
REM ***************************************************************
REM *                       SSAMerge.BAT                          *
REM *                  SSA Data Merging script                    *
REM *        By Vern Graner SSE, Integrity Software Inc.          *
REM *************************************************************** 
 REM * This script is used to concatenate files that have been    *
 REM * uploaded to the SSA from off-line workstations             *
 REM *                                                            *
 REM * If you have any questions, or need assistance configuring  * 
 REM * /implementing /troubleshooting this script, please contact *
 REM * vgraner@softwaremetering.com or call our support line at   *
 REM * 512-372-8991 M-F 7:30a to 5:30p CT USA (GMT-6)             *
 REM **************************************************************
 REM *Rev Info: V1.0a (VLG) 11-01-2013 First Build                *
 REM *Rev Info: V1.0b (VLG) 11-01-2013 mod the SSASync to this :  *
 REM *          NOTE: Mod script version to last value!           *
 REM **************************************************************

 REM **********************************
 REM * Ideas/Improvements/notes       *
 REM * for internal use only          *
 REM ****************************************************************
  REM - as you cant GOTO from inside a FOR / DO loop
  REM - might have to do a loop for each file like All AUDITS
  rem - then all inventories etc. and check for the upload lock 
  rem - on each file. hrm. could complicate logging? duno. :P
  REM ****************************************************************

REM *****************************************
REM * Environment Setup                     *
REM *****************************************
   REM Set script version
     SET ScriptVersion=1.0b
	 SET ScriptName=SSAMerge
     TITLE %ScriptName% v%ScriptVersion% by Vern Graner
   REM Set variables to NOT exist when script finishes
     SETLOCAL EnableDelayedExpansion
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM Set temporary Path to in case it has been altered from stock
     SET PATH=%SYSTEMROOT%;%SYSTEMROOT%\SYSTEM32;%SYSTEMROOT%\SYSTEM32\WBEM

   REM **************************************
   REM Set variables for log file
   REM **************************************
	  SET ScriptResult=PASS
	  SET CreateFolderLogs=Yes
	  SET TotalLocks=0
	  SET FilesAdded=0
	  
   REM **********************************
   REM * Turn DEBUG on/off              *
   REM *************************************************************************
   REM * The >nul 2>&1 redirects output and error output to nul to make clean  *
   REM * runs. NOTE: The reserved characters are delimited with a "^" symbol to*
   REM * make them compatible with the "set" command, so ">nul 2>&1" becomes   *
   REM * "^>nul 2^>^&1" un-REM "SET DEBUG=" to have errors/output of commands  *
   REM * displayed. Only change if instructed to do so by Tech Support or if   *
   REM * you're just the curious sort that would like to see it work. :)       *
   REM *************************************************************************
     SET DEBUG=^>nul 2^>^&1
     rem SET DEBUG=

REM *****************************************
REM * Create/Display header                 *
REM *****************************************
  ECHO. >%TEMP%\%ScriptName%-Header.tmp
  ECHO %ScriptName% (v%ScriptVersion%) by Vern Graner >>%TEMP%\%ScriptName%-Header.tmp
  ECHO Merges Uploaded data from offline workstations to primary SofTrack Server >>%TEMP%\%ScriptName%-Header.tmp
  ECHO. >>%TEMP%\%ScriptName%-Header.tmp
  ECHO System Check: >>%TEMP%\%ScriptName%-Header.tmp
  ECHO -------------------------------------------------------------- >>%TEMP%\%ScriptName%-Header.tmp

REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************************************************
REM                                                                              \
    CLS
    TYPE %TEMP%\%ScriptName%-Header.tmp
    ECHO Script Start Time: Fetching..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%
   REM Update the header with the time  
   ECHO *    Script Start Time: %MyTime% %MyDate% >>%TEMP%\%ScriptName%-Header.tmp

REM                                                                              /
REM *****************************************************************************

REM *****************************************
REM * Create a list of all files in         *
REM * the directory                         *
REM *****************************************************************************
REM                                                                              \
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO * Upload Folders found: Compiling..

   REM Uses Regular Expressions to remove any files with extensions i.e. ".XXX"
   DIR /b | FINDSTR /V "\...." >%TEMP%\%ScriptName%-OnlyComputerLogs.txt

   REM Counts the files and sets variable
   DIR /b | FINDSTR /V "\...." | find "" /v /n /c >%TEMP%\%ScriptName%_logs.tmp
   set /p ActiveLogs= <%TEMP%\%ScriptName%_logs.tmp
   del /q %TEMP%\%ScriptName%_logs.tmp %DEBUG%

   Set /a TotalLogs=ActiveLogs+ArchiveLogs
   ECHO * Upload Folders found: %TotalLogs%  >>%TEMP%\%ScriptName%-Header.tmp

   Rem Trap for NO audit logs found
   IF "%TotalLogs%"=="0" (
     SET ScriptResult=FAIL
     SET Errors=No Audit Logs Found
	 SET BackupLogFileName=N/A
	 SET OutputFileName=N/A
	 GOTO WriteLogExit
   )
REM                                                                              /
REM *****************************************************************************
   
REM ***************************
REM * Loop through folders    *
REM *****************************************************************************
REM                                                                              \
    FOR /F "delims=; eol=#" %%I IN (%TEMP%\%ScriptName%-OnlyComputerLogs.txt) DO (
      SET /a CurrentLog=CurrentLog+1
      CLS
      TYPE %TEMP%\%ScriptName%-Header.tmp
      ECHO.
	  ECHO Processing: Folder !CurrentLog! of %TotalLogs% [%%I]:
	  ECHO --------------------------------------------------------------
	  SET TargetFolder=%%I
      REM Use CALL since GOTO fails if inside a FOR/DO loop
	  CALL :ProcessFolder
    )
    CLS
    TYPE %TEMP%\%ScriptName%-Header.tmp
    ECHO *           Processing: Complete. >>%TEMP%\%ScriptName%-Header.tmp
REM                                                                              /
REM *****************************************************************************

REM ***************************
REM * Write Log File          *
REM *****************************************************************************
REM                                                                              \
     REM Put a header on it if it doesn't exist
     IF NOT EXIST "SSAMergeLog.CSV" (
       ECHO "Time Run","Script Version","Run By","On Server","Folders Found","Folders Skipped","Files Added","Script Result","Errors">"SSAMergeLog.CSV"
     )
     REM Append a log line 
     ECHO "%TIMESTAMP%","%ScriptVersion%","%UserName%","%COMPUTERNAME%","%TotalLogs%","%TotalLocks%","%FilesAdded%","%ScriptResult%","%MainErrorMessage%">>"SSAMergeLog.CSV"
     ECHO *        Log File Path: "SSAMergeFolderLog.CSV"
REM                                                                              /
REM *****************************************************************************

REM **********************************
REM * Echo end of script and set     *
REM * screen color to red/yel/grn    *
REM *****************************************************************************
REM                                                                              \
   (echo.|set /p =*        Script Status: )
   REM Red background, white text
   IF %ScriptResult%==FAIL (
   COLOR 4F
     ECHO %ScriptResult%
   )

   REM yellow background, black text
   IF %ScriptResult%==WARN (
     COLOR E0
     ECHO %ScriptResult%
   )

   REM green background, white text
   IF %ScriptResult%==PASS (
     COLOR A0
     ECHO %ScriptResult%
   )

  ECHO *       Error Messages: %ErrorMessage%
REM                                                                              /
REM *****************************************************************************
   
REM *****************************************
REM * Closing comments and tasks
REM *****************************************************************************
REM                                                                              \
   REM Tell user we're done
   ECHO.
   ECHO Script Complete:
   ECHO --------------------------------------------------------------  
   ECHO * Check log file ^(noted above^) for run details

   REM Return color scheme to white on black
   ECHO.
   COLOR 0F
   TITLE Command Prompt
   REM note: "endlocal" clears all the variables used in this script
   ENDLOCAL
REM                                                                              /
REM *****************************************************************************
   
   
REM ******************************************************************************
REM ******************************************************************************
REM ******************************************************************************
   REM Subroutines below this section
   REM PRevent Drop-through with EOF directive
   GOTO EOF 
REM ******************************************************************************
REM ******************************************************************************
REM ******************************************************************************
   
REM **********************
REM * Main Subroutine    *
REM ******************************************************************************
REM                                                                               \
:ProcessFolder    

    REM **********************
    REM Clear VARS           *
    REM *********************************************************************
	REM                                                                      \
	SET InvSync=N/A
	SET AppSync=N/A
	SET AuditSync=N/A
	SET LogonSync=N/A
	SET TimekeepSync=N/A
	SET QI_CHGSync=N/A
	SET QI_CHGIPSync=N/A
	SET QI_CHGPRSync=N/A
	SET LOGONLSync=N/A
	SET AlertEXESync=N/A
	SET AlertsSync=N/A
	SET ErrorMessage=
	REM                                                                      /
    REM *********************************************************************
	
    REM **********************
    REM * Check Folder Lock  *
    REM *********************************************************************
	REM                                                                      \
    IF EXIST "%TargetFolder%\SyncLock.txt" (
      SET UploadFolder=Locked
      SET ErrorMessage=%ErrorMessage%Upload Folder Locked, 
      SET MainErrorMessage=%MainErrorMessage% %TargetFolder% Locked, 
      SET ScriptResult=WARN
      ECHO *  Upload Folder Ready: No [Locked]
      Set /a TotalLocks=TotalLocks+1
	  GOTO UpdateLog
    ) ELSE (
      SET UploadFolder=Unlocked
      ECHO *  Upload Folder Ready: Yes [unlocked]
    )
	REM                                                                      /
    REM *********************************************************************

REM *******************************
REM * Sync process Begin
REM *******************************

    REM **********************************
    REM * Copy the inventory.new file
    REM *********************************************************************
	REM                                                                      \
    (echo.|set /p =*       Inventory file:)
    REM Check to make sure there is a file to send
    IF NOT EXIST "%TargetFolder%\COMPUTERS\%TargetFolder%.new" (
      SET OKtoDel=No
      SET InvSync=Not Found
      ECHO  Skipped [Not Found]
    ) ELSE (
      REM Copy up the inventory file
      COPY /V /Y "%TargetFolder%\COMPUTERS\%TargetFolder%.new" "..\COMPUTERS\%TargetFolder%.new" %DEBUG%
      IF !ERRORLEVEL!==0 (
        SET InvSync=Copied
        SET OKtoDel=Yes
		SET /A FilesAdded=FilesAdded+1
        ECHO  Copied
      ) ELSE (
        SET InvSync=Copy Fail
        SET OKtoDel=No
        SET ErrorMessage=%ErrorMessage% Inventory Copy !ERRORLEVEL!, 
        SET ScriptResult=WARN
        SET OKtoDel=No
        ECHO  WARNING Copy failed
      )
    )
    IF "%OKtoDel%."=="Yes." (
      rem ECHO  - Deleting uploaded INVENTORY file
    DEL /Q "%TargetFolder%\COMPUTERS\%TargetFolder%.new"
    )
	REM                                                                      /
    REM *********************************************************************
	
    REM **********************************
    REM * Sync the inventory .APP file
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*  Inventory .APP file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\COMPUTERS\%TargetFolder%.app" (
       SET OKtoDel=No
	   SET AppSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAppSync
     )
	 
     REM use COPY if this is the FIRST file
     IF EXIST "..\COMPUTERS\%TargetFolder%.app" GOTO DoAppMerge
     COPY /V /Y "%TargetFolder%\COMPUTERS\%TargetFolder%.app" "..\COMPUTERS\%TargetFolder%.app" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AppSync=Copied
       SET OKtoDel=Yes
       SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipAppMerge
	 ) ELSE (
       SET AppSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% App Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAppMerge
     )		

     :DoAppMerge
	 REM use MERGE if there is an existing file
     COPY /B "..\COMPUTERS\%TargetFolder%.app"+"%TargetFolder%\COMPUTERS\%TargetFolder%.app" "..\COMPUTERS\%TargetFolder%.app" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AppSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
          ) ELSE (
       SET AppSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% App Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipAppMerge
     
	 IF "%OKtoDel%."=="Yes." (
      rem ECHO  - Deleting uploaded APP file
      DEL /Q %TargetFolder%\COMPUTERS\%TargetFolder%.app"
     ) 
     :SkipAppSync
	REM                                                                      /
    REM *********************************************************************
	 
    REM **********************************
    REM * Cat the AlertEXE Trail (binary merge)
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*        AlertEXE file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\AlertEXE" (
       SET OKtoDel=No
	   SET AlertEXESync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAlertEXESync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\AlertEXE" GOTO DoAlertEXEMerge
     COPY /V /Y "%TargetFolder%\AlertEXE" "..\AlertEXE" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AlertEXESync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipAlertEXEMerge
     ) ELSE (
       SET AlertEXESync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% AlertEXE Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAlertEXEMerge
     )
	 
     :DoAlertEXEMerge
     REM use MERGE if there is an existing file
     COPY /B "..\AlertEXE"+"%TargetFolder%\AlertEXE" "..\AlertEXE" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AlertEXESync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET AlertEXESync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% AlertEXE Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipAlertEXEMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded AlertEXE file
       DEL /Q "%TargetFolder%\AlertEXE"
     )
	 
     :SkipAlertEXESync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync QI_CHG Trail 
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*          QI_CHG file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\QI_CHG.log" (
       SET OKtoDel=No
	   SET QI_CHGSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\QI_CHG.LOG" GOTO DoQI_CHGMerge
     COPY /V /Y "%TargetFolder%\QI_CHG.log" "..\QI_CHG.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipQI_CHGMerge
     ) ELSE (
       SET QI_CHGSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHG Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGMerge
	 )
	 
     :DoQI_CHGMerge
     REM use MERGE if there is an existing file
     COPY /B "..\QI_CHG.log"+"%TargetFolder%\QI_CHG.log" "..\QI_CHG.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET QI_CHGSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHG Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded QI_CHG file
       DEL /Q "%TargetFolder%\QI_CHG.log"
     )

     :SkipQI_CHGSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync QI_CHGIP Trail 
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*        QI_CHGIP file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\QI_CHGIP.log" (
       SET OKtoDel=No
	   SET QI_CHGIPSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGIPSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\QI_CHGIP.LOG" GOTO DoQI_CHGIPMerge
     COPY /V /Y "%TargetFolder%\QI_CHGIP.log" "..\QI_CHGIP.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGIPSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipQI_CHGIPMerge
     ) ELSE (
       SET QI_CHGIPSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHGIP Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGIPMerge
	 )
	 
     :DoQI_CHGIPMerge
     REM use MERGE if there is an existing file
     COPY /B "..\QI_CHGIP.log"+"%TargetFolder%\QI_CHGIP.log" "..\QI_CHGIP.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGIPSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET QI_CHGIPSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHGIP Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGIPMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded QI_CHGIP file
     DEL /Q "%TargetFolder%\QI_CHGIP.log"
     )

     :SkipQI_CHGIPSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync QI_CHGPR Trail 
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*        QI_CHGPR file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\QI_CHGPR.log" (
       SET OKtoDel=No
	   SET QI_CHGPRSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipQI_CHGPRSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\QI_CHGPR.LOG" GOTO DoQI_CHGPRMerge
     COPY /V /Y "%TargetFolder%\QI_CHGPR.log" "..\QI_CHGPR.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGPRSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipQI_CHGPRMerge
     ) ELSE (
       SET QI_CHGPRSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% QI_CHGPR Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipQI_CHGPRMerge
	 )
	 
     :DoQI_CHGPRMerge
     REM use MERGE if there is an existing file
     COPY /B "..\QI_CHGPR.log"+"%TargetFolder%\QI_CHGPR.log" "..\QI_CHGPR.log" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET QI_CHGPRSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET QI_CHGPRSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% QI_CHGPR Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipQI_CHGPRMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded QI_CHGPR file
     DEL /Q "%TargetFolder%\QI_CHGPR.log"
     )

     :SkipQI_CHGPRSync
	REM                                                                      /
    REM *********************************************************************
	 
    REM **********************************
    REM * Sync the Audit Trail Log       *
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*       Audit Log file:)
     REM Check to make sure there is a LOCAL Audit file to send
     IF NOT EXIST "%TargetFolder%\AUDIT\%TargetFolder%" (
       SET OKtoDel=No
	   SET AuditSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAuditSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\AUDIT\%TargetFolder%" GOTO DoAuditMerge
     COPY /V /Y "%TargetFolder%\AUDIT\%TargetFolder%" "..\AUDIT\%TargetFolder%" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AuditSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipAuditMerge
     ) ELSE (
       SET AuditSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Audit Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAuditMerge
     )	   

     :DoAuditMerge
     REM use MERGE if there is an existing file
     COPY /B "..\AUDIT\%TargetFolder%"+"%TargetFolder%\AUDIT\%TargetFolder%" "..\AUDIT\%TargetFolder%" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AuditSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
          ) ELSE (
       SET AuditSync=Failed
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Audit Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipAuditMerge
	 
     IF "%OKtoDel%."=="Yes." (
	   rem ECHO  - Deleting uploaded Audit file
       DEL /Q "%TargetFolder%\AUDIT\%TargetFolder%"
	 ) 
     :SkipAuditSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync the Logon log
    REM *********************************************************************
	REM                                                                      \
     (echo.|set /p =*           Logon file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\LOGON\%TargetFolder%" (
       SET OKtoDel=No
	   SET LogonSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipLogonSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\LOGON\%TargetFolder%" GOTO DoLogonMerge
     COPY /V /Y "%TargetFolder%\LOGON\%TargetFolder%" "..\LOGON\%TargetFolder%" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET LogonSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipLogonMerge
     ) ELSE (
       SET LogonSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Logon Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipLogonMerge
	 )

	 :DoLogonMerge
     REM use MERGE if there is an existing file
     COPY /B "..\LOGON\%TargetFolder%"+"%TargetFolder%\LOGON\%TargetFolder%" "..\LOGON\%TargetFolder%" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET LogonSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
          ) ELSE (
       SET LogonSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Logon Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )
     :SkipLogonMerge

     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded Logon file
     DEL /Q "%TargetFolder%\Logon\%TargetFolder%"
     )
     :SkipLogonSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Cat the LOGONL Trail (binary merge)
    REM *********************************************************************
    REM                                                                      \
     (echo.|set /p =*          LOGONL file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\LOGONL.log" (
       SET OKtoDel=No
	   SET LOGONLSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipLOGONLSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\LOGONL.LOG" GOTO DoLOGONLMerge
     COPY /V /Y "%TargetFolder%\LOGONL.log" "..\LOGONL.LOG" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET LOGONLSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipLOGONLMerge
     ) ELSE (
       SET LOGONLSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% LOGONL Copy !ERRORLEVEL!, 
       ECHO  WARNING Copy failed
       GOTO SkipLOGONLMerge
     )

	 :DoLOGONLMerge
     REM use MERGE if there is an existing file
     COPY /B "..\LOGONL.LOG"+"%TargetFolder%\LOGONL.LOG" "..\LOGONL.LOG" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET LOGONLSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
          ) ELSE (
       SET LOGONLSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% LOGONL Merge !ERRORLEVEL!, 
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipLOGONLMerge
     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded LOGONL file
     DEL /Q "%TargetFolder%\LOGONL.log"
     )

     :SkipLOGONLSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync Timekeeper Trail 
    REM *********************************************************************
    REM                                                                      \
     (echo.|set /p =*      Timekeeper file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\Timekeep.csv" (
       SET OKtoDel=No
	   SET TimekeepSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipTimekeepSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\Timekeep.csv" GOTO DoTimekeepMerge
     COPY /V /Y "%TargetFolder%\Timekeep.csv" "..\Timekeep.csv" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET TimekeepSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipTimekeepMerge
	 ) ELSE (
       SET TimekeepSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Timekeep Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipTimekeepMerge
     )	   

	 :DoTimekeepMerge
     REM use MERGE if there is an existing file
     COPY /B "..\Timekeep.csv"+"%TargetFolder%\Timekeep.csv" "..\Timekeep.csv" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET TimekeepSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET TimekeepSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Timekeep Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipTimekeepMerge
     IF "%OktoDel%."=="Yes." (
       rem ECHO  - Deleting local Timekeeper file
     DEL /Q "%TargetFolder%\Timekeep.csv"
     )

     :SkipTimekeepSync
	REM                                                                      /
    REM *********************************************************************

    REM ******************************************
    REM * Cat the Meter.log Trail (binary merge)
    REM *********************************************************************
    REM                                                                      \
     (echo.|set /p =*       METER.LOG file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\METER.LOG" (
       SET OKtoDel=No
	   SET MeterlogSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipMeterlogSync
     )

     REM Check to see if this is the FIRST file
     IF EXIST "..\METER.LOG" GOTO DoMeterlogMerge
       COPY /V /Y "%TargetFolder%\Meter.log" "..\Meter.LOG" %DEBUG%
       IF !ERRORLEVEL!==0 (
         SET MeterlogSync=Copied
         SET OKtoDel=Yes
		 SET /A FilesAdded=FilesAdded+1
         ECHO  Copied
         GOTO SkipMeterlogMerge
       ) ELSE (
         SET MeterlogSync=Copy Fail
         SET OKtoDel=No
         SET ErrorMessage=%ErrorMessage% Meterlog Copy !ERRORLEVEL!, 
         SET ScriptResult=WARN
         ECHO  WARNING Sync failed
         GOTO SkipMeterlogMerge
	     )
     )

     :DoMeterlogMerge
     REM if the target file is present, merge with it
     COPY /B "..\METER.LOG"+"%TargetFolder%\METER.LOG" "..\METER.LOG" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET MeterlogSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET MeterlogSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Meterlog Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
     :SkipMeterlogMerge
	   IF "%OKtoDel%."=="Yes." (
        rem ECHO  - Deleting local METER.LOG file
      DEL /Q "%TargetFolder%\Meter.log"
     )
 
     :SkipMeterlogSync
	REM                                                                      /
    REM *********************************************************************

    REM **********************************
    REM * Sync Alerts.LOG file
    REM *********************************************************************
    REM                                                                      \
     (echo.|set /p =*    Token Alerts file:)

     REM Check to make sure there is a file to send
     IF NOT EXIST "%TargetFolder%\Alerts.LOG" (
       SET OKtoDel=No
	   SET AlertsSync=Not Found
       ECHO  Skipped [Not Found]
       GOTO SkipAlertsSync
     )

     REM use COPY if this is the FIRST file
     IF EXIST "..\AlertsUpload.LOG" GOTO DoAlertsMerge
     ECHO Alerts For %TargetFolder%: >>..\AlertsUpload.LOG
     COPY /V /Y "%TargetFolder%\Alerts.LOG" "..\AlertsUpload.LOG" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AlertsSync=Copied
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Copied
       GOTO SkipAlertsMerge
     ) ELSE (
       SET AlertsSync=Copy Fail
       SET OKtoDel=No
       SET ErrorMessage=%ErrorMessage% Alerts Copy !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Copy failed
       GOTO SkipAlertsMerge
     )	   

     :DoAlertsMerge
	 REM use MERGE if there is an existing file
     ECHO Alerts For %TargetFolder%: >>..\AlertsUpload.LOG
     COPY /B "..\AlertsUpload.LOG"+"%TargetFolder%\Alerts.LOG" "..\AlertsUpload.LOG" %DEBUG%
     IF !ERRORLEVEL!==0 (
       SET AlertsSync=Merged
       SET OKtoDel=Yes
	   SET /A FilesAdded=FilesAdded+1
       ECHO  Merged
     ) ELSE (
       SET AlertsSync=Merge Fail
       SET OKtoDel=No
	   SET ErrorMessage=%ErrorMessage% Alerts Merge !ERRORLEVEL!, 
       SET ScriptResult=WARN
       ECHO  WARNING Merge failed
     )

     REM If merge or copy was successful- delete the source file
	 :SkipAlertsMerge
     IF "%OKtoDel%."=="Yes." (
       rem ECHO  - Deleting uploaded Alerts file
       DEL /Q "%TargetFolder%\Alerts.LOG"
     )

     :SkipAlertsSync
	REM                                                                      /
    REM *********************************************************************

REM *******************************
REM * Sync process end
REM *******************************
 
 
   REM *****************************************
   REM * Write log files                       *
   REM *****************************************
     :UpdateLog
     IF "%CreateFolderLogs%."=="No." GOTO NoFolderLog
     ECHO.
     ECHO Update Log:
     ECHO --------------------------------------------------------------  
    (echo.|set /p =* Log File Update:)

    REM Creates a N/A result if no errors have been produced during the script run
     IF "%ErrorMessage%."=="." SET ErrorMessage=N/A

    REM Write the log file to the local machine
	rem **************************************************
    REM Put a header on it if it doesn't exist
    IF NOT EXIST "%TargetFolder%\SSAMergeFolderLog.CSV" (
      ECHO "Time Run","Script Version","Run By","Upload From","Script Result","Inventory File","Inv .APP File","Audit Log","Logon Log","TimeKeeper Log","QI_CHG Log","QI_CHGIP Log","QI_CHGPR LOG","LOGONL Log","AlertEXE Log","Token Alerts","Errors">"%TargetFolder%\SSAMergeFolderLog.CSV"
    )
    REM Append a log line
    ECHO "%TIMESTAMP%","%ScriptVersion%","%UserName%","%TargetFolder%","%ScriptResult%","%InvSync%","%AppSync%","%AuditSync%","%LogonSync%","%TimekeepSync%","%QI_CHGSync%","%QI_CHGIPSync%","%QI_CHGPRSync%","%LOGONLSync%","%AlertEXESync%","%AlertsSync%","%ErrorMessage%">>"%TargetFolder%\SSAMergeFolderLog.CSV"
    ECHO  Complete. "%TargetFolder%\SSAMergeFolderLog.CSV"
    :NoFolderLog
REM                                                                              /
REM ******************************************************************************
REM * Main Subroutine End*
REM **********************
EXIT /B
:EOF
   