@ECHO OFF
REM *********************************************************
REM *                   PushMSI  Script                     *
REM *      (c) Vern Graner SSE Integrity Software Inc.      *
REM *********************************************************
REM *      Can be used to install LWA & QIA on a target     *
REM *      IP address or from a passed list of targets      *
REM *********************************************************
REM * v1.0a Created 06/11/13 - VLG  First Build             *
REM * v1.0b Updated 06/11/13 - VLG Add alternate MSI calls  *
REM * v1.0c Updated 06/19/13 - VLG Add PSEXEC host/name     *
REM *********************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set varibales to NOT exist when script finishes
     SetLocal EnableDelayedExpansion
   REM Set color to white text on black background
     COLOR 0F
     CLS
   
REM **********************************
REM * Script Name and version        *
REM **********************************
      REM Set script name and version
      SET ScriptVersion=1.0c
      SET ScriptName=PushMSI
   
REM **********************************
REM * Turn DEBUG on/off              *
REM *************************************************************************
REM * The >nul 2>&1 redirects output and error output to nul to make clean  *
REM * runs. NOTE: The reserved characters are delimted with a "^" symbol to *
REM * make them compatible with the "set" command, so ">nul 2>&1" becomes   *
REM * "^>nul 2^>^&1" un-REM "SET DEBUG=" to have errors/output of commands  *
REM * dispayed. Only change if instructed to do so by Tech Support or if    *
REM * you're just the curious sort that would like to see it work. :)       *
REM *************************************************************************
   SET DEBUG=^>nul 2^>^&1
   rem SET DEBUG=

   REM **************************************
   REM * Script Variables                   *
   REM **************************************
   TITLE %ScriptName% script v%ScriptVersion%
   SET LogName=%ScriptName%
   SET MSIName=LWA-QIA-EQ-INTEGRITY-2K.MSI
   Set UseWMI=Yes
   SET WaitForKey=Yes
   SET LogPath=Local
   Set PingWait=200
   SET EndResult=No Errors
   SET ScriptResult=PASS

   REM **************************************
   REM Clean up temp files
   REM **************************************
   DEL /q %TEMP%\Header1.tmp %DEBUG%
   DEL /q %TEMP%\Header2.tmp %DEBUG%
   DEL /q TempWmicBatchFile.bat %DEBUG%
   
   REM **************************************
   REM Clean up temp vars
   REM **************************************
   SET TotalLines=
   SET CurrentLine=
   SET Pingable=N/A
   SET DNSName=N/A
   SET CDollar=N/A
   SET TargetHostName=N/A
   SET TargetUserName=N/A
   
REM *****************************************
REM * Create Header Part 1                  *
REM *****************************************
   ECHO. >%TEMP%\Header1.tmp
   ECHO. >>%TEMP%\Header1.tmp
   ECHO      %ScriptName% script %ScriptVersion% >>%TEMP%\Header1.tmp
   ECHO      by Vern Graner SSE, Integrity Software Inc. >>%TEMP%\Header1.tmp
   ECHO =========================================================================== >>%TEMP%\Header1.tmp
   
REM *****************************************
REM * Fetch and Format Date/Time            *
REM *****************************************
   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO Script Start: Fetching Time and Date info..
   CALL :UpdateTime

   SET TimeStamp=%MyDate% %MyTime%
   SET FileStampStart=%FileDate%-%FileTime%

REM *****************************************
REM * Create Header Part 2                  *
REM *****************************************
   ECHO Script Start: %TimeStamp% >>%TEMP%\Header1.tmp
   ECHO     Run From: %ComputerName% >>%TEMP%\Header1.tmp
   
REM **********************************
REM * Check LogPath for WRITE right  *
REM **********************************
   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO     Log Path: Checking..
   rem Jump to local log if logpath value is "local"
   IF "%LogPath%."=="Local." GOTO CheckLocal

   REM Check the LogFiles Path if provided
   rem -----------------------------------------

   REM Remove trailing slash if present
   IF %LogPath:~-1%==\ SET LogPath=%LogPath:~0,-1%
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
    )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp" 

   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
	 SET LogStatus=Writable
   ECHO     Log Path: %LogPath%>>%TEMP%\Header1.tmp
     GOTO EndLogTest
   )
    
   REM Check the Current Working Directory
   rem -----------------------------------------
   :CheckLocal
   SET LogPath=%~dp0
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
    )

   ECHO WriteTest >"%LogPath%\%COMPUTERNAME%-Test.tmp"
   
   IF EXIST "%LogPath%\%COMPUTERNAME%-Test.tmp" (
     DEL /q "%LogPath%\%COMPUTERNAME%-Test.tmp" %DEBUG%
     SET LogStatus=Writable
   ECHO     Log Path: %LogPath%>>%TEMP%\Header1.tmp
     GOTO EndLogTest
   )
   
   REM Nothing writable, dang it! :P
   rem -----------------------------------------
     SET LogStatus="Log path %LogPath% Invalid - defaulting to %TEMP%"
     SET "ErrorMessage=%ErrorMessage%Log path %LogPath% Invalid - defaulting to %TEMP%, "
     SET LogPath=%temp%
   ECHO     Log Path: "%LogPath%" (failover default)
   )

   :EndLogTest
   ECHO     Log File: %LogName%_%FileStampStart%>>%TEMP%\Header1.tmp

REM ************************************
REM * Pre-Flight Check
REM ************************************
   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO  File Checks: PsExec..
   PsExec -? %DEBUG%
   If %ERRORLEVEL% == 9009 (
     ECHO  File Checks: PSEXEC NOT FOUND >>%TEMP%\Header1.tmp
     SET FileCheck=%FileCheck%,PSEXEC
     SET ErrorMessage=Missing Required File: PSEXEC.EXE
     SET ScriptResult=FAIL
     GOTO Done
   ) ELSE (
     SET FileCheck=PASS
   )

   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO  File Checks: PsLoggedOn..
   PsLoggedOn -? %DEBUG%
   If %ERRORLEVEL% == 9009 (
     ECHO  File Checks: PSLOGGEDON NOT FOUND >>%TEMP%\Header1.tmp
     SET FileCheck=%FileCheck%,PSLOGGEDON
     SET ErrorMessage=Missing Required File: PSLOGGEDON.EXE
     SET ScriptResult=FAIL
     GOTO Done
   ) ELSE (
     SET FileCheck=PASS
   )
   ECHO  File Checks: %FileCHeck% >>%TEMP%\Header1.tmp
   
   REM **************************************
   rem Validate 1st passed parameter
   REM **************************************
   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO  Parameter 1: Checking..   
  
    IF "%1." == "." (
      SET EndResult=No parameter supplied
      ECHO  Parameter 1: None Passed >>%TEMP%\Header1.tmp
      ECHO              * No text file or IP address passed on command line >>%TEMP%\Header1.tmp
      SET ErrorMessage=%ErrorMessage%No parameter specified, 
      Set ScriptResult=FAIL
      GOTO DONE
    ) 

    IF EXIST "%1" (
      ECHO  Parameter 1: Passed List [%1] >>%TEMP%\Header1.tmp
      SET PassedParameter=File
    ) ELSE (
      ECHO  Parameter 1: Passed Single [%1] >>%TEMP%\Header1.tmp
      SET PassedParameter=Value
    )

   REM **************************************
   REM * Validate 2nd passed parameter
   REM **************************************
   CLS
   TYPE %TEMP%\Header1.tmp
   ECHO  Parameter 2: Checking..   
   IF "%2."=="." (
     SET MSIName=LWA-QIA-EQ-INTEGRITY-2K.MSI
	 SET MSIType=Preset File
   ) ELSE (
     SET MSIName=%2
	 SET MSIType=Passed File
   )

   IF NOT EXIST %MSIName% (
     ECHO  Parameter 2: %MSIType% [%MSIName%] NOT FOUND >>%TEMP%\Header1.tmp
     SET ErrorMessage=Missing MSI File
     SET ScriptResult=FAIL
     GOTO Done
   ) ELSE (
     ECHO  Parameter 2: %MSIType% [%MSIname%] >>%TEMP%\Header1.tmp
   )
	
   REM **************************************
   REM * If "value" go to single target     *
   REM **************************************
   IF %PassedParameter% == Value goto SkipFile
    
   REM **************************************
   REM * Perform on each in list of targets
   REM **********************************************************************************

   REM Count the number of lines in the passed file
   set "cmd=findstr /R /N "^^" %1 | find /C ":""
   for /f %%a in ('!cmd!') do set TotalLines=%%a
   
   rem Begin looping through the file and calling routines
   FOR /F "delims=; eol=#" %%A IN (%1) DO (
     SET Pingable=N/A
     SET DNSName=N/A
     SET CDollar=N/A
     SET TargetHostName=N/A
     SET TargetUserName=N/A
	 SET MSICopy=N/A
	 SET MSIRun=N/A
     SET TargetName=%%A
     SET /a CurrentLine=CurrentLine+1

 	 CALL :Header2Clear
	 
	 CLS
     TYPE %TEMP%\Header1.tmp
     ECHO --------------------------------------------------------------------------- >>%TEMP%\Header2.tmp
     ECHO        Current Target: !TargetName! [!CurrentLine! of !TotalLines!] >>%TEMP%\Header2.tmp

	 CALL :PingTargetMachine
	 IF !PingReply! == Reply (
       CALL :FindDNSname
	   CALL :FindHostName
	   CALL :FindUserName
	   CALL :TestCDollar
	 rem  CALL :MSIPush1

       REM Set delay amount then call subroutine
      rem  SET WaitSeconds=10
      rem CALL :DelayCounter 

	 rem  CALL :MSIPush2
	 )	
     REM Update Time Stamp
      CLS
      TYPE %TEMP%\Header1.tmp
      TYPE %TEMP%\Header2.tmp
	  CALL :UpdateTime
      SET TimeStamp=%MyDate% %MyTime%

     REM Update Log file per iteration
      CALL :UpdateLogFile
	  rem PAUSE
   )
 GOTO DONE

:SkipFile
   REM **************************************
   REM * perform on a single target
   REM **********************************************************************************

   CLS
   TYPE %TEMP%\Header1.tmp
     SET Pingable=N/A
     SET DNSName=N/A
     SET CDollar=N/A
     SET TargetHostName=N/A
     SET TargetUserName=N/A
	 SET MSICopy=N/A
	 SET MSIRun=N/A
     SET TargetName=%1
     SET /a CurrentLine=CurrentLine+1

 	 CALL :Header2Clear
	 
	 CLS
     TYPE %TEMP%\Header1.tmp
     ECHO --------------------------------------------------------------------------- >>%TEMP%\Header2.tmp
     ECHO        Current Target: !TargetName! [Passed Single] >>%TEMP%\Header2.tmp

	 CALL :PingTargetMachine
	 IF !PingReply! == Reply (
       CALL :FindDNSname
	   CALL :FindHostName
  	   CALL :FindUserName
	   CALL :TestCDollar
	   rem CALL :MSIPush1

       REM Set delay amount then call subroutine
      rem  SET WaitSeconds=10
      rem CALL :DelayCounter 

	   rem CALL :MSIPush2
	 )	
     REM Update Time Stamp
      CLS
      TYPE %TEMP%\Header1.tmp
      TYPE %TEMP%\Header2.tmp
	  CALL :UpdateTime
      SET TimeStamp=%MyDate% %MyTime%

     REM Update Log file per iteration
      CALL :UpdateLogFile
   )
 GOTO DONE

REM **********************************
REM * Script is complete             *
REM **********************************
   :Done
   CLS
   TYPE %TEMP%\Header1.tmp
   TYPE %TEMP%\Header2.tmp

REM **********************************
REM * Echo end of script and Set     *
REM * screen color to red/yel/grn    *
REM **********************************
   ECHO ---------------------------------------------------------------------------
   REM Red background, white text
   IF %ScriptResult%==FAIL COLOR 4F

   REM yellow background, black text
   IF %ScriptResult%==WARN (
     COLOR E0
     ECHO.
     ECHO WARNING- ERRORS DETECTED! Check Log File ^(noted above^) for details.
     ECHO.
   )

   REM green background, white text
   IF %ScriptResult%==PASS COLOR A0

   ECHO END RESULT: %ScriptResult%
   ECHO.

REM **********************************
REM * Check to see if we pause at    *
REM * to show install result to user *
REM **********************************
   IF "%WaitForKey%."=="Yes." (
     PAUSE
   )

REM **********************************
REM * Done! Skynet uplink soon... ;) *
REM **********************************
   REM Kill off temp files
   DEL /q TempWmicBatchFile.bat %DEBUG%
   DEL /q %TEMP%\Header1.tmp %DEBUG%
   DEL /q %TEMP%\Header2.tmp %DEBUG%
   DEL /Q %TEMP%\HOSTOUT.TXT %DEBUG%
   rem Return color scheme to white on black
   COLOR 0F
   rem note: "endlocal" clears all the variables used in this script
   ENDLOCAL

REM *****************************************************************
REM *****************************************************************
REM !!!!!!!  EVERYTHING BELOW THIS SECTION IS A SUBROUTINE    !!!!!!!
REM *****************************************************************
REM *****************************************************************
   GOTO EOF

   REM ****************************
   REM * MSIpush1                 *
   REM **********************************************
   :MSIPush1
   CLS
   TYPE %TEMP%\Header1.tmp
   TYPE %TEMP%\Header2.tmp
   ECHO              Copy MSI: Processing..
   XCOPY /V /Y %MsiName% \\!TargetName!\C$\WINDOWS\SYSTEM32 %DEBUG%
   rem   PSExec \\!TargetName! -s -c -f -d %MsiName%
   IF %ERRORLEVEL%==0 (
     SET MSICopy=Worked
     ECHO              Copy MSI: Worked
     ECHO              Copy MSI: Worked >>%TEMP%\Header2.tmp
   ) ELSE (
     SET MSICopy=Failed
     ECHO              Copy MSI: Failed
     ECHO              Copy MSI: Failed >>%TEMP%\Header2.tmp
   )
   EXIT /b
   REM **********************************************
   
   REM ****************************
   REM * MSIpush2                 *
   REM **********************************************
   :MSIPush2
   CLS
   TYPE %TEMP%\Header1.tmp
   TYPE %TEMP%\Header2.tmp
   ECHO               Run MSI: Processing..

   PSExec /accepteula \\!TargetName! -s MSIEXEC.EXE /I %MsiName% /qn
   IF %ERRORLEVEL%==0 (
     SET MSIRun=Worked
     ECHO               Run MSI: Worked >>%TEMP%\Header2.tmp
   ) ELSE (
     SET MSIRun=Failed
     ECHO               Run MSI: Failed >>%TEMP%\Header2.tmp
   )
   EXIT /b
   REM **********************************************


   REM **********************************
   REM * Clear Header2                  *
   REM **********************************************
   :Header2Clear
   If Exist %Temp%\Header2.tmp (
     DEL /q %Temp%\Header2.tmp
   )
   EXIT /b
   REM **********************************************
   
   REM **********************************
   REM * Write log file                 *
   REM **********************************************
   :UpdateLogFile
   CLS
   TYPE %TEMP%\Header1.tmp
   TYPE %TEMP%\Header2.tmp
   ECHO     Updating Log File: "%LogName%.CSV"..

  REM Put a header on it if it doesn't exist
   IF NOT EXIST "%LogPath%\%LogName%-LOG_%FileStampStart%.CSV" (
     ECHO "Time Run","Script Version","Script Result","Run By","From Machine","Target Name","Ping","DNS Name","C$","Host Name","Logged On","MSI Copy","MSI Run","Errors" >"%LogPath%\%LogName%-LOG_%FileStampStart%.CSV"
   )
   REM Creates a N/A result if no errors have been produced during the script run
   IF "%ErrorMessage%."=="." SET ErrorMessage=N/A
   ECHO "%TIMESTAMP%","%ScriptVersion%","%EndResult%","%USERNAME%","%COMPUTERNAME%","%TargetName%","%Pingable%","%DNSName%","%CDollar%","%TargetHostName%","%TargetUserName%","%MSICopy%","%MSIRun%","%ErrorMessage%" >>"%LogPath%\%LogName%-LOG_%FileStampStart%.CSV"
   ECHO     Updating Log File: Done >>%TEMP%\Header2.tmp
   EXIT /b
   REM **********************************************
   
   REM ****************************
   REM * PING target machine      *
   REM **********************************************
    :PingTargetMachine
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
	ECHO               Pinging: !TargetName!..
    Set PingReply=
    FOR /F "tokens=1 delims= " %%j in ('PING -n 1 -w %PingWait% !TargetName! ^| FIND "Reply"') do (
        SET PingReply=%%j
    )

    IF !PingReply! == Reply (
        SET Pingable=Yes
    	ECHO               Pinging: Replied >>%TEMP%\Header2.tmp
    ) ELSE (
        SET Pingable=No
	    ECHO               Pinging: Timeout >>%TEMP%\Header2.tmp
    )
    EXIT /b
    REM **********************************************
    
    REM ****************************
    REM * Reverse DNS target name  *
    REM **********************************************
    :FindDNSname
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    SET DNSname=N/A
    ECHO         DNS Host Name: Checking..
	FOR /F "tokens=1-2 delims= " %%I IN ('PING -a -n 1 -w 100 !TargetName!') DO IF "%%I"=="Pinging" SET DNSname=%%J
     IF "%DNSname%."=="N/A." (
	     ECHO         DNS Host Name: no response >>%TEMP%\Header2.tmp
     ) ELSE (
         SET DNSname=%DNSname%
    	 ECHO         DNS Host Name: %DNSname% >>%TEMP%\Header2.tmp
     )
	eXIT /b
	REM **********************************************
    
    REM **************************************
    REM * Pause Countdown                    *
    REM **********************************************
    :DelayCounter	
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    
	:PauseLoop
      SET /a WaitSeconds=WaitSeconds-1
      IF %WaitSeconds% == 0 GOTO DoneCount
        CLS
        TYPE %TEMP%\Header1.tmp
        TYPE %TEMP%\Header2.tmp
        ECHO    Script Pausing for: %WaitSeconds% seconds
        PING 1.1.1.1 -n 1 -w 1000 %DEBUG%
        GOTO PauseLoop
	  :DoneCount
    EXIT /b 
    REM **********************************************
    
	REM *****************************************
    REM * Begin C$ directory tests              *
    REM **********************************************
    :TestCdollar
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    ECHO      C$ Default Share: Testing..
   	DIR \\!TargetName!\c$ %DEBUG%
	   IF %ERRORLEVEL%==1 (
         SET CDollar=Access Denied
         ECHO      C$ Default Share: Access Denied >>%TEMP%\Header2.tmp
         GOTO SkipWriteTest
       ) ELSE (
	     SET CDollar=Accessible
       )

       ECHO Test File >\\!TargetName!\c$\testfile.txt
       IF %ERRORLEVEL%==1 (
	     SET PushReady=NO
         SET CDOLLAR=Write Failed
         ECHO      C$ Default Share: Write test Failed >>%TEMP%\Header2.tmp
       ) ELSE (
         DEL /q \\!TargetName!\c$\testfile.txt %DEBUG%
	     SET CDOLLAR=%CDOLLAR%/Writeable
         ECHO      C$ Default Share: %CDOLLAR%/Writeable >>%TEMP%\Header2.tmp
       )
    :SkipWriteTest
    EXIT /b 
	   
    REM *****************************************
    REM * Check for target host name            *
    REM *****************************************
    :FindHostName
    SET CheckHostName=N/A
	IF %UseWMI% == No GOTO SkipWMIHost

    rem --[ WMI query target for machine name ]--
	CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    ECHO      Target Host name: WMI Querying..
	FOR /F "tokens=2 delims=," %%A IN ('WMIC /NODE:"!TargetName!" /FAILFAST:ON COMPUTERSYSTEM GET NAME /FORMAT:CSV 2^>NUL ^< NUL ^|FINDSTR /I /V "node"') DO SET TargetHostName=%%A
    rem ECHO                Result: %TargetHostName% 
	rem PAUSE
    IF "%TargetHostName%"=="N/A" (
      SET Error=%Error%WMI Host Query Failed, 
    ) ELSE (
      GOTO EndFindHostName
	)
    :SkipWMIHost
	
    rem --[ PSEXEC/HOSTNAME query target for machine name ]--
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    ECHO      Target Host name: PSExec/HOSTNAME Querying..
	PSExec /accepteula \\!TargetName! hostname>%TEMP%\HOSTOUT.TXT 2>%TEMP%\PSERR.TXT
	SET /P TargetHostName=<%TEMP%\HOSTOUT.TXT
    rem ECHO                Result: %TargetHostName% 
	rem PAUSE
    IF "%TargetHostName%"=="N/A" (
      SET /P PSError=<%TEMP%\PSERR.TXT
      SET Error=%Error%%PSError%, 
    )

	:EndFindHostName
    ECHO      Target Host name: %TargetHostName% >>%TEMP%\Header2.tmp
    EXIT /b
	
    REM *****************************************
    REM * Check for target current user         *
    REM *****************************************
	:FindUserName
    SET TargetUserName=N/A
    
	IF %UseWMI% == No GOTO SkipWMIname
	rem --[ WMI query target for user name ]--
    CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    ECHO      Target User name: WMIC Querying..
	FOR /F "tokens=2 delims=\" %%A IN ('WMIC /NODE:"!TargetName!" /FAILFAST:ON COMPUTERSYSTEM GET USERNAME /FORMAT:CSV 2^>NUL ^< NUL ^|FINDSTR /I /V "node"') DO SET TargetUserName=%%A
    rem ECHO                Result: %TargetUserName%
	rem PAUSE
    IF "%TargetUserName%"=="N/A" (
      SET Error=%Error%WMIC User Query Failed, 
    ) ELSE (
      GOTO EndFindUserName
    )
    :SkipWMIName

    rem --[ PSLOGGEDON query target for user name ]--
	CLS
	TYPE %TEMP%\Header1.tmp
	TYPE %TEMP%\Header2.tmp
    ECHO      Target User name: PSLOGGEDON Querying..
	PSLoggedOn -l -x \\!TargetName!>%TEMP%\USEROUT.TXT 2>%TEMP%\PSERR.TXT
	rem Extract the name from the temp file note the delim is a TAB character!
	FOR /F "tokens=2 delims=	" %%i IN ('TYPE %TEMP%\USEROUT.TXT') DO SET TargetUserName=%%i
    rem ECHO                Result: %TargetUserName%
	rem PAUSE

    IF "%TargetUserName%"=="N/A" (
      SET /P PSError=<%TEMP%\PSERR.TXT
      SET Error=%Error%%PSError%, 
      SET Error=%Error%PSLOGGEDON User Query Failed, 
    )

   :EndFindUserName
   ECHO      Target User name: "%TargetUserName%" >>%TEMP%\Header2.tmp
   rem ECHO      Target User name: "%TargetUserName%"
   rem ECHO                 Error: "%Error%"
   rem PAUSE
	
   EXIT /b
   REM **********************************************

   REM *****************************************
   REM * Fetch and Format Date/Time            *
   REM *****************************************
   :UpdateTime
   ECHO     Script Start Time: Fetching Time and Date info..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   EXIT /b
   REM ***************************************
   
:EOF
   
  
  







