@ECHO OFF
REM ***************************************************
REM *             Audit Log Report                    *
REM *           (c) Vern Graner SSE                   *
REM ***************************************************
REM * Recursive Workstation Audit File                *
REM * report generator                                *
REM ***************************************************
REM * Created 10/21/10 - VLG                          *
REM * Updated 01/22/14 - 1.0b Added new search filter *
REM ***************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set variables to NOT exist when script finishes
   REM and enable delayed variable expansion
     SetLocal EnableDelayedExpansion
   REM Set script version
     SET ScriptVersion=1.0b
	 SET ScriptName=Internet-Use-Report
     TITLE %ScriptName% v%ScriptVersion% by Vern Graner
   REM Set color to white text on black background
     COLOR 0F
     CLS

REM **********************************
REM * Turn DEBUG on/off              *
REM *****************************************************************************
rem * The >nul 2>&1 redirects output and error output to nul to make clean runs *
rem * NOTE: The reserved characters are delimted with a "^" symbol to make them *
rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"  *
rem * un-REM "SET DEBUG=" to have errors/output of commands dispayed            *
REM *****************************************************************************
   SET DEBUG=^>nul 2^>^&1
 rem SET DEBUG=

REM *****************************************
REM * Print Header                          *
REM *****************************************
   ECHO. >%TEMP%\%ScriptName%-Header.tmp
   ECHO      _%ScriptName%.BAT script version %Scriptversion% by Vern Graner>>%TEMP%\%ScriptName%-Header.tmp
   ECHO +--------------------------------------------------------->>%TEMP%\%ScriptName%-Header.tmp
   rem ECHO. >>%TEMP%\%ScriptName%-Header.tmp
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
 
REM *****************************************
REM * Format Date/Time "MM/DD/YYYY HH:MM AP"*
REM *****************************************
   ECHO ^|  Script Start Time: Fetching..
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%
   SET FileStamp=%FileDate%_%FileTime%

   ECHO ^|  Script Start Time: %TimeStamp% >>%TEMP%\%ScriptName%-Header.tmp
   
  
REM *****************************************
REM * Create a list of all files in         *
REM * the directory                         *
REM *****************************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO ^|   Audit Logs found: Compiling..
 
   REM Uses Regular Expressions to remove any files with extensions i.e. ".XXX"
   DIR /b /A-d | FINDSTR /V "\...." >%TEMP%\%ScriptName%-OnlyComputerLogs.txt

   REM Counts the files and sets variable
   REM =========================================================
   dir /b /A-d | FINDSTR /V "\...." | find "" /v /n /c >%TEMP%\%ScriptName%_logs.tmp
   set /p ActiveLogs= <%TEMP%\%ScriptName%_logs.tmp
   del /q %TEMP%\%ScriptName%_logs.tmp %DEBUG%

   Set /a TotalLogs=ActiveLogs
   ECHO ^|   Audit Logs found: %TotalLogs% >>%TEMP%\%ScriptName%-Header.tmp

rem ***************************
rem * Create Derivative file  *
rem *******************************************************************
   CLS
   TYPE %TEMP%\%ScriptName%-Header.tmp
   ECHO -Creating derivative file of records that match _SiteList.txt entries..
   FOR /F "delims=; eol=#" %%I IN (%TEMP%\%ScriptName%-OnlyComputerLogs.txt) DO (
     CLS
     TYPE %TEMP%\%ScriptName%-Header.tmp
	 SET /a CurrentLog=CurrentLog+1
     ECHO ^|         Processing: Machine !CurrentLog! of %TotalLogs% [%%I]:
     FINDSTR /L /I /G:_Internet-Use-Report_Sitelist.txt "%%I">>"_%ScriptName%-%FileStamp%.csv"
   )
   ECHO ^|         Processing: Complete >>%TEMP%\%ScriptName%-Header.tmp

REM *****************************************
REm * Remove temporary file                 *
REM *****************************************
   DEL /Q "%temp%\%ScriptName%-Header.tmp" %DEBUG%
   DEL /Q "%temp%\%ScriptName%-OnlyComputerLogs.txt" %DEBUG%
   ECHO ^|    Temporary Files: Cleared

   ECHO +---------------------------------------------------------
   ECHO Report Created: "_%ScriptName%-%FileStamp%.csv"
   ECHO.

REM *****************************************
REM * Pause may be remarked out if this     *
REM * script is to run automated            *
REM *****************************************
PAUSE
