@ECHO OFF
REM **************************************************************
REM *           STInstall report collector script                *
REM *       By Vern Graner SSE, Integrity Software Inc.          *
REM **************************************************************
REM * This script "walks" through a range of IP addresses,       *
REM * running a sequence on each IP address                      *
REM *                                                            *
REM * NOTE: The IP address range to be tested MUST be entered    *
REM * BEFORE this script is run! Check the comments in the body  *
REM * of the script for details.                                 *
REM *                                                            *
REM * If you have any questions, or need assistance configuring  *
REM * /implementing /troubleshooting this script, please contact *
REM * vgraner@softwaremetering.com or call our support line at   *
REM * 512-372-8991 M-F 7:30a to 5:30p CT USA (GMT-6)             *
REM **************************************************************
REM * Revision: V1.0a  (VLG:) 07-07-2010 First Build             *
REM *  Updated: V1.0b  (VLG:) 10-23-2013 add CAT of files        *
REM **************************************************************

REM **********************************
REM * Environment Setup              *
REM **********************************
   REM Set variables to NOT exist when script finishes
   REM and enable delayed variable expansion
     SetLocal EnableDelayedExpansion
   REM Set script version
     SET ScriptName=STInstall-Log-Collector
     SET ScriptVersion=1.0b
     TITLE %ScriptName% v%ScriptVersion% by Vern Graner
   REM Set color to white text on black background
     COLOR 0F
     CLS
   REM Set temporary Path to in case it has been altered from stock
     SET PATH=%SYSTEMROOT%;%SYSTEMROOT%\SYSTEM32;%SYSTEMROOT%\SYSTEM32\WBEM;%PATH%

REM **********************************
REM * Script settings                *
REM **********************************
  rem Use or not use WMI queries
    SET UseWMI=Yes
  rem skip the IP if it wont reply to a ping
    SET QuickScan=Yes
  rem location to copy found logs
    SET CollectedLogsPath=CollectedLogs
  rem Remove files from ISW path -before workstation agents folder path
    SET CleanUp=Yes
 	 
REM **********************************
REM * Mandatory Variable definitions *
REM *************************************************************************
REM * WARNING! The following variables MUST be changed BEFORE this script   *
REM * is run. The default variables will NOT work for your environment and  *
REM * the script will abort if they are not changed!                        *
REM * ----------------------------------------------------------------------*
REM * The following are the variables and their uses in the script:         *
REM *                                                                       *
REM * OCT1-------- (Octet 1) the first octet in the IP address              *
REM *                        i.e. 10.x.x.x                                  *
REM *                                                                       *
REM * OCT2_START-- (Octet 2) the first IP in the second octet of the IP     *
REM *                        address range (i.e. x.1.x.x)                   *
REM *                                                                       *
REM * OCT2_END---- (Octet 2) the last IP in the second octet of the IP      *
REM *                        address range (i.e. x.10.x.x)                  *
REM *                                                                       *
REM * OCT3_START-- (Octet 3) the first IP in the third octet of the IP      *
REM *                        address range (i.e. x.x.1.x)                   *
REM *                                                                       *
REM * OCT3_END---- (Octet 3) the last IP in the third octet of the IP       *
REM *                        address range (i.e. x.x.10.x)                  *
REM *                                                                       *
REM * OCT4_START-- (Octet 4) the first IP in the fourth octet of the IP     *
REM *                        address range (i.e. x.x.x.1)                   *
REM *                                                                       *
REM * OCT4_END---- (Octet 4) the last IP in the fourth octet of the IP      *
REM *                        address range (i.e. x.x.x.10)                  *
REM *                                                                       *
REM *  Example: To have this script test the first 100 machines in the      *
REM *           two subnets 192.168.100.x and 192.168.101.x, you would      *
REM *           use the following values:                                   *
REM *                                                                       *
REM *           set oct1=192                                                *
REM *                                                                       *
REM *           set oct2_start=168                                          *
REM *           set oct2_end=168                                            *
REM *                                                                       *
REM *           set oct3_start=100                                          *
REM *           set oct3_end=101                                            *
REM *                                                                       *
REM *           set oct4_start=1                                            *
REM *           set oct4_end=100                                            *
REM *                                                                       *
REM *************************************************************************

REM **********************************
REM * Set IP address Octets Here     *
REM * Mount Saint Vincent University *
REM **********************************
   set oct1=140
 
   set oct2_start=230
   set oct2_end=230

   set oct3_start=1
   set oct3_end=11

   set oct4_start=1
   set oct4_end=254

REM **********************************
REM * Turn DEBUG on/off              *
REM *****************************************************************************
rem * The >nul 2>&1 redirects output and error output to nul to make clean runs *
rem * NOTE: The reserved characters are delimited with a "^" symbol to make them*
rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"  *
rem * un-REM "SET DEBUG=" to have errors/output of commands displayed           *
REM *****************************************************************************
  SET DEBUG=^>nul 2^>^&1
  rem SET DEBUG=
  
REM **********************************
REM * Pre-Flight Check: Was script   *
REM * properly modified before use?  *
REM **********************************
  IF %OCT1%==0 GOTO FAILMOD
  REM Remove leftover temp file
  DEL /q TempWmicBatchFile.bat %DEBUG%
  REM Make sure the log location exists
  IF NOT EXIST %CollectedLogsPath% MD %CollectedLogsPath%

REM *****************************************
REM * Print Header                          *
REM *****************************************
   ECHO. >%TEMP%\AllCln-Header.tmp
   ECHO  %ScriptName% version %Scriptversion% by Vern Graner>>%TEMP%\AllCln-Header.tmp
   ECHO ===========================================================>>%TEMP%\AllCln-Header.tmp
   ECHO. >>%TEMP%\AllCln-Header.tmp
   CLS
   TYPE %TEMP%\AllCln-Header.tmp

REM *****************************************
REM * Format Date/Time "MM/DD/YYYY HH:MM AP"*
REM *****************************************
   ECHO  - Script Start Time: Fetching..
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%
   SET FileStamp=%FileDate%_%FileTime%
   SET TestStart=%MyDate% %MyTime%

REM *****************************************
REM * Show START time on header             *
REM *****************************************
   ECHO  - Script Start Time: %TimeStamp% >>%TEMP%\AllCln-Header.tmp
   CLS
   TYPE %TEMP%\AllCln-Header.tmp

REM **********************************
REM * Setup variables for use.       *
REM * NOTE: Should not be modified!  *
REM **********************************
  set /a OCT4_end=oct4_end+1
  set /a OCT3_end=oct3_end+1
  set /a OCT2_end=oct2_end+1
  set OCT4=%OCT4_START%
  set OCT3=%OCT3_START%
  set OCT2=%OCT2_START%

REM **********************************
REM * Everything here is done ONCE   *
REM * per IP address                 ***********************************
REM **********************************                                  \
:LBEG
   CLS
   TYPE %TEMP%\AllCln-Header.tmp

REM *****************************************
REM * reset values used in the log file     *
REM *****************************************
  SET FwdDNSIP=N/A
  SET RevDNSname=N/A
  SET WMIHostName=N/A
  SET ErasedFiles=N/A
  SET TargetName=N/A
  SET DNSFwdeqRev=N/A
  SET WMIeqDNS=N/A
  SET LogsCopied=0
  SET ErrorMessages=
  SET FoundName=0
   
REM *****************************************
REM * Format Date/Time "MM/DD/YYYY HH:MM AP"*
REM *****************************************
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TestStart=%MyDate% %MyTime%
   ECHO  -   Test Start Time: %TestStart%

REM *****************************************
REM * Echo status to the screen             *
REM *****************************************
   ECHO  -    Current Target: %oct1%.%oct2%.%oct3%.%oct4%

REM *****************************************
REM * Begin Ping test of target IP          *
REM ************************************************************
REM                                                             \
   <nul (set/p NOCRLF= -       Ping Target: )
  PING -n 1 -w 250 %oct1%.%oct2%.%oct3%.%oct4% %DEBUG%
  IF %ERRORLEVEL%==0 (
    SET Pingable=Yes
    ECHO Responded
  ) ELSE (
    SET Pingable=No
    ECHO Timed out
  )
  REM If QuickScan skip remaining tests
  If %QuickScan%==Yes (
    If %Pingable%==No (GOTO NextIP)
  )
REM                                                             /
REM ************************************************************

REM *****************************************
REM * Query: Reverse IP to DNS name         *
REM ************************************************************
REM                                                             \
  <nul (set/p NOCRLF= - Query Reverse DNS: )
  FOR /F "tokens=2,3 delims= " %%A IN ('PING -a -n 1 -w 10 %oct1%.%oct2%.%oct3%.%oct4%') DO IF "%%B"=="[%oct1%.%oct2%.%oct3%.%oct4%]" SET RevDNSname=%%A
  IF "%RevDNSname%"=="N/A" (
	ECHO No response
  ) ELSE (
	ECHO %RevDNSname%
  )
REM                                                             /
REM ************************************************************

REM *****************************************
REM * Query: Forward DNS name to IP         *
REM ************************************************************
REM                                                             \
  IF "%RevDNSname%"=="N/A" Goto SkipFwdDNSCheck
  <nul (set/p NOCRLF= - Query Forward DNS: )
  FOR /F "tokens=3 delims= " %%i in ('PING -n 1 -w 250 %RevDNSname% ^| FIND /i "Pinging"') do (SET FwdDNSIP=%%i)

  IF "%FwdDNSIP%"=="N/A" (
    ECHO No response
    SET FwdDNSIP=None
    GOTO SkipWMIHost
  ) ELSE (
    SET FwdDNSIP=!FwdDNSIP:]=!
    SET FwdDNSIP=!FwdDNSIP:[=!
	ECHO !FwdDNSIP!
  )
 :SkipFwdDNSCheck
REM                                                             /
REM ************************************************************

REM *****************************************
REM * WMI Check for target host name        *
REM ************************************************************
REM                                                             \
  SET WMIHostName=N/A
  IF %UseWMI% == No GOTO SkipWMIHost
  <nul (set/p NOCRLF= -     WMI host name: )

  FOR /F "tokens=2 delims=," %%A IN ('WMIC /NODE:"%oct1%.%oct2%.%oct3%.%oct4%" /FAILFAST:ON COMPUTERSYSTEM GET NAME /FORMAT:CSV 2^>NUL ^< NUL ^|FINDSTR /I /V "node"') DO SET WMIHostName=%%A

  IF "%WMIHostName%"=="N/A" (
    ECHO %WMIHostName%
    SET ErrorMessages=%ErrorMessages%WMI Host Query Failed, 
  ) ELSE (
    ECHO %WMIHostName%
  )	

  :SkipWMIHost
REM                                                             /
REM ************************************************************
   
REM *****************************************
REM * FWD REV DNS agreement check           *
REM ************************************************************
REM                                                             \
  IF "%RevDNSname%"=="N/A" Goto SkipAgreementCheck
  IF "%FwdDNSIP%"=="N/A" Goto SkipAgreementCheck

  <nul (set/p NOCRLF= -       FWD/REV DNS: )
  IF "%FwdDNSIP%."=="%oct1%.%oct2%.%oct3%.%oct4%." (
    ECHO Match 
    SET DNSFwdeqRev=Yes
  ) ELSE (
    ECHO DO NOT MATCH [%FwdDNSIP%=/=%oct1%.%oct2%.%oct3%.%oct4%]
    SET DNSFwdeqRev=No
  )
   :SkipAgreementCheck
   REM                                                             /
   REM ************************************************************
   
REM *****************************************
REM * DNS WMI name agreement check          *
REM ************************************************************
REM                                                             \
  IF "%WMIHostName%"=="N/A" Goto SkipWMIAgreeCheck
  IF "%RevDNSName%"=="N/A" Goto SkipWMIAgreeCheck

  <nul (set/p NOCRLF= -     WMI/DNS Names: )
  REM extract the first item in dotted name e.g. [host].domain.tld
  FOR /f "tokens=1 delims=." %%A IN ("%RevDNSname%") DO (SET DNSHostName=%%A)
  
  IF /I "%WMIHostName%."=="%DnsHostName%." (
    ECHO Match
    SET WMIeqDNS=Yes
  ) ELSE (
    ECHO DO NOT MATCH ["%WMIHostName%"=/="%DnsHostName%"]
    SET WMIeqDNS=No
  )
   :SkipWMIAgreeCheck
   REM                                                             /
   REM ************************************************************

REM *****************************************
REM * Gather log file from Target IP        *
REM *****************************************
  
  rem Reset Default state
  SET TargetPath=N/A

  <nul (set/p NOCRLF= -        ISW folder: )
  
  rem Check for 64 bit ISW path 
  IF EXIST \\%oct1%.%oct2%.%oct3%.%oct4%\c$\PROGRA~2\INTEGR~1 (
     SET TargetPath=\\%oct1%.%oct2%.%oct3%.%oct4%\c$\PROGRA~2\INTEGR~1
   )

  rem Check for 32 bit ISW path 
   IF EXIST \\%oct1%.%oct2%.%oct3%.%oct4%\c$\PROGRA~1\INTEGR~1 (
	 SET TargetPath=\\%oct1%.%oct2%.%oct3%.%oct4%\c$\PROGRA~1\INTEGR~1
   )

   rem If no "Integrity Software Inc" folder, move on..
   IF %TargetPath%==N/A (
     ECHO NOT FOUND
     GOTO NextIP
   ) ELSE (
     ECHO "%TargetPath%"
   )

   REM Reset logs copied count
   DEL /Q "%CollectedLogsPath%\STInstall-*.NEW" %DEBUG%
   DEL /Q "%CollectedLogsPath%\STInstall-*.OLD" %DEBUG%

   rem Check for log file in OLD location 
   IF EXIST "%TargetPath%\STInstall-*.csv" (
     COPY /V /Y "%TargetPath%\STInstall-*.csv" "%CollectedLogsPath%\STInstall-*.OLD" %DEBUG%
	 IF %ERRORLEVEL%==0 (
       ECHO  -   Install log ISW: Copied [old location]
	   SET /a LogsCopied=LogsCopied+1
	 ) ELSE (
       ECHO  -   Install log ISW: Copy failed [old location]
	 )
   )
   
   rem Check for log file in NEW location 
   IF EXIST "%TargetPath%\WORKST~1\STInstall-*.csv" (
     COPY /V /Y "%TargetPath%\WORKST~1\STInstall-*.csv" "%CollectedLogsPath%\STInstall-*.NEW" %DEBUG%
	 IF %ERRORLEVEL%==0 (
       ECHO  -   Install log ISW: Copied [new location]
	   SET /a LogsCopied=LogsCopied+1
       REM Fetch the workstation name
       REM extract the name before the DOT
       FOR /F "tokens=1-4 delims=." %%i in ('DIR /B %CollectedLogsPath%\STInstall-*.NEW') do (
         SET TargetName=%%i
       )
       REM Trim off the prefix
       SET TargetName=%TargetName:STInstall-=%
	 ) ELSE (
       ECHO  -   Install log ISW: Copy failed [new location]
	 )
   )

   rem If logs found is 0 then error out
   IF %LogsCopied%==0 (
     SET ErrorMessages=%ErrorMessages%No Logs Found, 
	 GOTO SkipLogCopy
   )
   
   REM Fetch the workstation name
   REM ************************************************************
   REM                                                             \
   IF NOT EXIST %CollectedLogsPath%\STInstall-*.OLD GOTO NoOldOne
   FOR /F "tokens=1-4 delims=." %%i in ('DIR /B %CollectedLogsPath%\STInstall-*.OLD') do (
     SET TargetName=%%i
   )
   REM Trim off the prefix
   SET TargetName=%TargetName:STInstall-=%
   :NoOldOne
   
   IF NOT EXIST %CollectedLogsPath%\STInstall-*.NEW GOTO NoNewOne
   FOR /F "tokens=1-4 delims=." %%i in ('DIR /B %CollectedLogsPath%\STInstall-*.NEW') do (
     SET TargetName=%%i
   )
   REM Trim off the prefix
   SET TargetName=%TargetName:STInstall-=%
   :NoNewOne
   IF %TargetName%==N/A (
     SET ErrorMessages=%ErrorMessages%Fetch Workstation Name Failed, 
	 GOTO NextIP
   )	 
   REM                                                             /
   REM ************************************************************
   
   REM remove existing log file [no redundant data.. most recent collected is most recent]
   DEL /Q "%CollectedLogsPath%\STInstall-%TargetName%.csv"

   IF %LogsCopied%==1 (
     REM Rename the one found file to .CSV
	 REM ************************************************************
	 REM                                                             \
	 IF EXIST "%CollectedLogsPath%\STInstall-%TargetName%.NEW" (
       REN "%CollectedLogsPath%\STInstall-%TargetName%.NEW" "STInstall-%TargetName%.csv"
     ) ELSE (
	   REN "%CollectedLogsPath%\STInstall-%TargetName%.OLD" "STInstall-%TargetName%.csv"
	 )  
	 REM                                                             /
	 REM ************************************************************
   ) ELSE (
     REM If more than one file found, merge them
	 REM ************************************************************
	 REM                                                             \
     REM Use this one if you want to remove the headers from concatenated files 
	 rem TYPE "%CollectedLogsPath%\STInstall-%TargetName%.OLD" | FIND /v "Time Run" >> "%CollectedLogsPath%\STInstall-%TargetName%.NEW"
     REM Use this one if you DO NOT want to remove the headers from concatenated files 
     TYPE "%CollectedLogsPath%\STInstall-%TargetName%.OLD" >> "%CollectedLogsPath%\STInstall-%TargetName%.NEW"
     REN "%CollectedLogsPath%\STInstall-%TargetName%.NEW" "STInstall-%TargetName%.csv"
	 REM                                                             /
	 REM ************************************************************
   )   
   ECHO  -    Logs Processed: %LogsCopied%

   REM remove the intermediate files
   DEL /Q "%CollectedLogsPath%\STInstall-%TargetName%.NEW" %DEBUG%
   DEL /Q "%CollectedLogsPath%\STInstall-%TargetName%.OLD" %DEBUG%

   :SkipLogCopy
rem PAUSE

REM *****************************************
REM * Clean up leftover files               *
REM *****************************************
  IF %CleanUp%==No (
    SET ErasedFiles=N/A
    GOTO NoErase
  )
     <nul (set/p NOCRLF= -Cleaned temp files: )     
     REM Reset erased files count    
	 Set ErasedFiles=0
	 
     IF EXIST %TargetPath%\AGENTRM.TXT (
        DEL /Q %TargetPath%\AGENTRM.TXT %DEBUG%
        Set /a ErasedFiles=ErasedFiles+1
        <nul (set/p NOCRLF=*)
     )

    IF EXIST %TargetPath%\BARCODE.EXE (
       DEL /Q %TargetPath%\BARCODE.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %TargetPath%\BUILD.TXT (
       DEL /Q %TargetPath%\BUILD.TXT %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %TargetPath%\CPTLWA32.DLL (  
       DEL /Q %TargetPath%\CPTLWA32.DLL %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %TargetPath%\CPTLWA64.DLL (  
       DEL /Q %TargetPath%\CPTLWA64.DLL %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    If EXIST %TargetPath%\CPT_X64A.EXE (  
       DEL /Q %TargetPath%\CPT_X64A.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %TargetPath%\EXEIgnore.dat ( 
       DEL /Q %TargetPath%\EXEIgnore.dat %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
     
    IF EXIST %TargetPath%\INVENTRY.EXE ( 
       DEL /Q %TargetPath%\INVENTRY.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\ISW.DAT (  
       DEL /Q %TargetPath%\ISW.DAT %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\launcher.vbs (      
       DEL /Q %TargetPath%\launcher.vbs %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\LWA-QIA-update.bat (  
       DEL /Q %TargetPath%\LWA-QIA-update.bat %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )   
    
    IF EXIST %TargetPath%\NWLWA32.EXE (
       DEL /Q %TargetPath%\NWLWA32.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
    
    IF EXIST %TargetPath%\QISVC0.EXE (
       DEL /Q %TargetPath%\QISVC0.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\README.TXT (
       DEL /Q %TargetPath%\README.TXT %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\stad0.dll (
       DEL /Q %TargetPath%\stad0.dll %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STBW_K32.SYS (
       DEL /Q %TargetPath%\STBW_K32.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STBW_K64.SYS (
       DEL /Q %TargetPath%\STBW_K64.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )
    
    IF EXIST %TargetPath%\STConfig.cmd (
       DEL /Q %TargetPath%\STConfig.cmd %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STLWA_64.SYS (
       DEL /Q %TargetPath%\STLWA_64.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STLWA_NT.EXE (
       DEL /Q %TargetPath%\STLWA_NT.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STLWMON.SYS (
       DEL /Q %TargetPath%\STLWMON.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STNW32.DLL (
       DEL /Q %TargetPath%\STNW32.DLL %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
      <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STSRVC.EXE (
       DEL /Q %TargetPath%\STSRVC.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STVIEW.SYS (
       DEL /Q %TargetPath%\STVIEW.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STVIEW2K.SYS (
       DEL /Q %TargetPath%\STVIEW2K.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\stview64.sys (
       DEL /Q %TargetPath%\stview64.sys %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\STVISTA.SYS (
       DEL /Q %TargetPath%\STVISTA.SYS %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\VERCHK.BAT (
       DEL /Q %TargetPath%\VERCHK.BAT %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\VerChk.TXT (
       DEL /Q %TargetPath%\VerChk.TXT %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    )

    IF EXIST %TargetPath%\_SMBIOS_.EXE (
       DEL /Q %TargetPath%\_SMBIOS_.EXE %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    ) 

    IF EXIST %TargetPath%\AGENTRM.CMD (
       DEL /Q %TargetPath%\AGENTRM.CMD %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    ) 

    IF EXIST %TargetPath%\QuietLaunch_pass.vbs (
       DEL /Q %TargetPath%\QuietLaunch_pass.vbs %DEBUG%
       Set /a ErasedFiles=ErasedFiles+1
       <nul (set/p NOCRLF=*)
    ) 

    ECHO [Total:%ErasedFiles%]
    :NoErase
  
:NextIP

REM **********************************
REM * Write log file                 *
REM **********************************
   ECHO  - Updating Log File: %FileStamp%-%ScriptName%-LOG.CSV"..

   REM Put a header on it if it doesn't exist
   IF NOT EXIST "%FileStamp%-%ScriptName%-LOG.CSV" (
     ECHO "Time Run","Test IP","PING reply","REV DNS Name","Fwd DNS IP","WMI Name","REV=FWD IP","WMI=DNS Name","Logs Collected","TMP Files Erased","Error Messages" >"%FileStamp%-%ScriptName%-LOG.CSV"
   )
   
   REM Creates a N/A result if no errors have been produced during the script run
   IF "%ErrorMessages%."=="." SET ErrorMessages=N/A

   ECHO "%TestStart%","%oct1%.%oct2%.%oct3%.%oct4%","%Pingable%","%RevDNSName%","%FwdDNSIP%","%WMIHostName%","%DNSFwdeqRev%","%WMIeqDNS%","%LogsCopied%","%ErasedFiles%","%ErrorMessages%">>"%FileStamp%-%ScriptName%-LOG.CSV"

REM **********************************     *
REM * END of Once per IP iteration   *******
REM **********************************


REM **********************************
REM * IP address increment loop      *
REM * BEGIN                          *
REM **********************************

rem OCT4 loop
  set /a oct4=oct4+1
  IF NOT %OCT4%==%OCT4_END% GOTO LBEG
SET OCT4=%OCT4_START%


rem OCT3 loop
  set /a oct3=oct3+1
  IF NOT %OCT3%==%OCT3_END% GOTO LBEG
SET OCT3=%OCT3_START%


rem OCT2 loop
  set /a oct2=oct2+1
  IF NOT %OCT2%==%OCT2_END% GOTO LBEG
SET OCT2=%OCT2_START%

REM **********************************
REM * IP address increment loop      *
REM * END                            *
REM **********************************
ECHO.
ECHO All IP's DONE!

REM *****************************************
REM * Remove temporary file                 *
REM *****************************************
  ECHO -Cleaning up temporary files..
  DEL /Q _OnlyInstallLogs.tmp %DEBUG%
    REM Remove leftover temp file
  DEL /q TempWmicBatchFile.bat %DEBUG%
  TITLE Command Prompt

  ECHO Collection Complete!
  ECHO All logs located here: "%CollectedLogsPath%"
  ECHO.
  GOTO EXIT

REM **********************************
REM * Loop Error trap section        *
REM * Handles known errors           *
REM **********************************
:FAILMOD
ECHO ERROR-- IP ADDRESS RANGE(S) NOT DEFINED!
ECHO.
ECHO ERROR-- THIS SCRIPT MUST BE MODIFIED BEFORE IT IS USED!
GOTO EXIT

REM **********************************
REM * Done                           *
REM **********************************
:EXIT
