@ECHO OFF
REM *************************************************************
REM *               FindOpenMachines.BAT                        *
REM *    By Vern Graner SSE, Integrity Software Inc             *
REM *************************************************************
REM * Use the logon/off log files to identify possibly unused   *
REM * machines and output data as HTML compatible for display   *
REM * via a web server.                                         *
REM * Requires Gnuwin32 appliction "TAIL" available online via  *
REM * GNU licensing)                                            *
REM *************************************************************
REM * Created 03/07/13 - 1.0a VLG First Build                   *
REM * Updated 06/07/13 - 1.0b add year checks                   *
REM * Updated 06/07/13 - 1.0c add PING check of targets         *
REM * Updated 02/19/13 - 1.0d add staging of HTML file          *
REM *************************************************************
REM * NOTE: This batch file MUST be run from the LOGON folder!  *
REM *************************************************************

REM **********************************
REM * Basic Environment Setup        *
REM **********************************
   REM Set script version
     SET ScriptVersion=1.0d
   REM Set varibales to NOT exist when script finishes
   REM and enable delayed variable expansion
     SetLocal EnableDelayedExpansion
   REM Set color to white text on black background
     COLOR 0F
     CLS
   
REM *****************************************
REM * Set script parameters / switches      *
REM *****************************************
   REM Place where log files will be kept
   SET LOG_PATH=FindOpen.logs
   REM turns logging on/off valid are Yes and No
   SET CreateLogs=Yes
   REM If target machine is not pingable, skip it
   SET UsePing=Yes
   REM Time (in MS) for ping to wait before timing out
   SET PingWait=10
   
REM *****************************************
REM * Set Web Page parameters               *
REM *****************************************
   REM Seconds between page meta refresh 
   SET RefreshSeconds=300
   REM The Support phone number displayed on the page
   Set SupportNumber=512-372-8991
   
REM *****************************************
REM * Set path for final report.            *
REM * NOTE: You MUST include a trailing     *
REM * SLASH!                                *
REM *****************************************
   rem Example of putting the report on a mapped drive
     rem SET REPORT_PATH=G:\Reports\Available\
   rem Example of sending the report to a web server UNC
     rem SET REPORT_PATH=\\MyWebServer\C$\inetpub\wwwroot\AvailRooms\
   rem example of putting the report in the Current Directoy from which the batch runs
   rem note that the "%~dp0" variable contains a trailing slash -no need to manually add one
     rem SET REPORT_PATH=%~dp0

   SET REPORT_PATH=\\Integrity-2k\C$\Inetpub\wwwroot\OpenStations\

REM *****************************************
REM * Set NAME for final report.            *
REM *****************************************
   REM Example of create a "root" level output html file
     rem SET REPORT_NAME=index.html
   REM Exmaple of using a descriptive name for the output HTML file
   SET REPORT_NAME=index.html
   
REM **********************************
REM * Turn DEBUG on/off              *
REM *****************************************************************************
rem * The >nul 2>&1 redirects output and error output to nul to make clean runs *
rem * NOTE: The reserved characters are delimted with a "^" symbol to make them *
rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"  *
rem * un-REM "SET DEBUG=" to have errors/output of commands dispayed            *
REM *****************************************************************************
   SET DEBUG=^>nul 2^>^&1
 rem  SET DEBUG=
   
REM **********************************
REM * Add paths for helper apps      *
REM **********************************
   SET PATH=%PATH%;%ProgramFiles%\GnuWin32\bin
   SET PATH=%PATH%;%ProgramFiles(x86)%\GnuWin32\bin
   
REM **********************************
REM * Fetch Time for Batch Elapsed   *
REM **********************************
rem Get start time:
for /F "tokens=1-4 delims=:.," %%a in ("%time%") do (
   set /A "start=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
)
   
REM *****************************************
REM * Print Header                          *
REM *****************************************
   ECHO. >%TEMP%\FindOpen-Header.tmp
   ECHO    FindOpenMachines.BAT script version %Scriptversion% by Vern Graner>>%TEMP%\FindOpen-Header.tmp
   ECHO =============================================================>>%TEMP%\FindOpen-Header.tmp
   ECHO. >>%TEMP%\FindOpen-Header.tmp
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   
REM **********************************
REM * Check for needed GNU utilities *
REM **********************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO        GNU TAIL command: Checking..
   
   TAIL --HELP %DEBUG%
   If %ERRORLEVEL% == 9009 (
      ECHO   * TAIL:  NOT FOUND
      Set EndResult=ABORTED! Missing TAIL command
	  GOTO WriteLogExit
   )

   ECHO        GNU TAIL command: Found >>%TEMP%\FindOpen-Header.tmp

REM **********************************
REM * Details of the run             *
REM **********************************
   ECHO        Destination Path: "%REPORT_PATH%">>%TEMP%\FindOpen-Header.tmp
   ECHO  Destionation File name: "%REPORT_NAME%">>%TEMP%\FindOpen-Header.tmp
   ECHO       HTML Page Refresh: %RefreshSeconds%ms>>%TEMP%\FindOpen-Header.tmp
   ECHO           Support Phone: %SupportNumber%>>%TEMP%\FindOpen-Header.tmp
   ECHO       Test PING targets: %UsePing%>>%TEMP%\FindOpen-Header.tmp
  
REM *****************************************
REM * Format Date/Time "MM/DD/YYYY HH:MM AP"*
REM *****************************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO       Script Start Time: Fetching..
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
	   Set CurrentDD=%Val1%
	   set CurrentMM=%Val2%
	   set CurrentYYYY=%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
	   Set CurrentMM=%Val1%
	   set CurrentDD=%Val2%
	   set CurrentYYYY=%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
	   Set CurrentMM=%Val3%
	   set CurrentDD=%Val2%
	   set CurrentYYYY=%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
	   Set CurrentMM=%Val2%
	   set CurrentDD=%Val3%
	   set CurrentYYYY=%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

  REM Set three-letter Month name using lookup table (brute force)
   IF %CurrentMM% == 01 SET CurrentMMM=Jan
   IF %CurrentMM% == 02 SET CurrentMMM=Feb
   IF %CurrentMM% == 03 SET CurrentMMM=Mar
   IF %CurrentMM% == 04 SET CurrentMMM=Apr
   IF %CurrentMM% == 05 SET CurrentMMM=May
   IF %CurrentMM% == 06 SET CurrentMMM=Jun
   IF %CurrentMM% == 07 SET CurrentMMM=Jul
   IF %CurrentMM% == 08 SET CurrentMMM=Aug
   IF %CurrentMM% == 09 SET CurrentMMM=Sep
   IF %CurrentMM% == 10 SET CurrentMMM=Oct
   IF %CurrentMM% == 11 SET CurrentMMM=Nov
   IF %CurrentMM% == 12 SET CurrentMMM=Dec
      
   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStampStart=%MyTime% %MyDate%
   SET NOW=%FileDate%
   
   ECHO       Script Start Time: %TimeStampStart% >>%TEMP%\FindOpen-Header.tmp

REM **********************************
REM * Check LOG_PATH for WRITE right *
REM **********************************
   IF %CreateLogs%==No GOTO NoChkLogPath
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO       Log Path Location: Testing..

   IF NOT EXIST %LOG_PATH% MD %LOG_PATH%

   ECHO Test File >"%LOG_PATH%\STTest.tmp"
   IF EXIST "%LOG_PATH%\STTest.tmp" (
     DEL /q "%LOG_PATH%\STTest.tmp"
   ) ELSE (
     SET LogPath="%LOG_PATH% Read Only!- default to TEMP"
     SET EndResult=ERROR: %LOG_PATH% not writable!
     ECHO        -Write failed on "%LOG_PATH%" -failover to "%temp%"
     SET LOG_PATH=%temp%
   )
   ECHO       Log Path Location: Test Complete >>%TEMP%\FindOpen-Header.tmp
   :NoChkLogPath

REM *****************************
REM * Create HTML report header *
REM *****************************
  ECHO ^<HTML^> >"%temp%\%REPORT_NAME%"
  ECHO ^<HEAD^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<TITLE^>Workstation Availability Report^</TITLE^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<META HTTP-EQUIV="Pragma" CONTENT="no-cache"^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<META HTTP-EQUIV="Cache-Control" CONTENT="no-cache"^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<meta http-equiv="refresh" content="%RefreshSeconds%"^> >>"%temp%\%REPORT_NAME%"
  ECHO ^</HEAD^> >>"%temp%\%REPORT_NAME%"
  ECHO. >>"%temp%\%REPORT_NAME%"
  ECHO ^<BODY TEXT="#000000" >>"%temp%\%REPORT_NAME%"
  ECHO    BGCOLOR="#ffffff" >>"%temp%\%REPORT_NAME%"
  ECHO       LINK="#0000AA" >>"%temp%\%REPORT_NAME%"
  ECHO      VLINK="#0000dd" >>"%temp%\%REPORT_NAME%"
  ECHO      ALINK="#FF0000"^> >>"%temp%\%REPORT_NAME%"
  ECHO. >>"%temp%\%REPORT_NAME%"
  ECHO ^<^^!-- Page Header Begin --^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<DIV ALIGN="CENTER"^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<TABLE BORDER="0" WIDTH="100%%" CELLPADDING="1" CELLSPACING="0" ^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<TR VALIGN="LEFT"^> >>"%temp%\%REPORT_NAME%"
  ECHO     ^<TD ALIGN="CENTER" VALIGN="CENTER"^> >>"%temp%\%REPORT_NAME%"
  ECHO     ^<FONT FACE="Arial, Helvetica" SIZE="6"^>^<b^>Workstation Availability Report^</b^>^</font^> >>"%temp%\%REPORT_NAME%"
  ECHO     ^<BR^> >>"%temp%\%REPORT_NAME%"
  ECHO     ^<FONT FACE="Arial, Helvetica" SIZE="2"^>^<I^>Created by ^<a href="http://www.softwaremetering.com"^>Integrity Software Inc^</a^> ^<b^>SofTrack^<sup^>^&#169;^</sup^>^</b^>^</I^>^</font^> >>"%temp%\%REPORT_NAME%"
  ECHO     ^<P^> >>"%temp%\%REPORT_NAME%"
  
  REM The following line populates the "Last Updated" field of the web page
  ECHO     ^<FONT FACE="Arial, Helvetica" SIZE="4"^>Last Updated: ^<I^>%TimeStampStart%^</I^>^</font^> >>"%temp%\%REPORT_NAME%"

  ECHO     ^</TR^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^</TD^> >>"%temp%\%REPORT_NAME%"
  ECHO ^</TABLE^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<^^!-- Page Header End --^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<P^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<TABLE BORDER="1" WIDTH="75%%" CELLPADDING="1" CELLSPACING="0" ^> >>"%temp%\%REPORT_NAME%"
  ECHO ^<TR^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<TD ALIGN="CENTER"^>^<B^>#^</B^>^</TD^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<TD ALIGN="LEFT"^>^<B^>Machine Name^</B^>^</TD^> >>"%temp%\%REPORT_NAME%"
  ECHO   ^<TD ALIGN="LEFT"^>^<B^>Date/Time reported Available^</B^>^</TD^> >>"%temp%\%REPORT_NAME%"
  ECHO ^</TR^> >>"%temp%\%REPORT_NAME%"
   
REM *****************************************
REM * Create a list of all files in         *
REM * the directory                         *
REM *****************************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO               File List: Compiling..

   REM Uses Regular Expressions to remove any files with extensions i.e. ".XXX"
   REM =========================================================
   DIR /b /A-d | FINDSTR /V "\...." >%TEMP%\FindOpen_OnlyComputerLogs.txt

   REM Counts the files and sets variable
   REM =========================================================
   dir /b /A-d | FINDSTR /V "\...." | find "" /v /n /c >%TEMP%\FindOpen_LogCount.tmp
   set /p ActiveLogs= <%TEMP%\FindOpen_LogCount.tmp
   del /q %TEMP%\FindOpen_LogCount.tmp %DEBUG%

   Set /a TotalLogs=ActiveLogs+ArchiveLogs

   ECHO               File List: Compiled. >>%TEMP%\FindOpen-Header.tmp
   
REM ***************************
REM * Process each log file   *
REM *******************************************************************
    SET TotalAvailable=0
	
REM **********************
REM * Main Loop Begin    *
REM ******************************************************************************
REM                                                                              *
    FOR /F "delims=; eol=#" %%I IN (%TEMP%\FindOpen_OnlyComputerLogs.txt) DO (
       SET /a CurrentLog=CurrentLog+1
       CLS
       TYPE %TEMP%\FindOpen-Header.tmp
       ECHO              Processing: Machine !CurrentLog! of %TotalLogs% ["%%I"]
	   SET CurrentMachine=%%I

       REM Call Target Ping Subroutine
	   IF !UsePing! == Yes (
	     CALL :PingTargetMachine
	   ) ELSE (
	     SET PingReply=Reply
	   )
	   
	  IF !PingReply! == Reply (
	     CALL :ExtractRecord
	  )

	)

    ECHO              Processing: Complete. >>%TEMP%\FindOpen-Header.tmp
REM                                                                              *
REM ******************************************************************************
REM * Main Loop End      *
REM **********************

REM *****************************
REM * Create HTML report footer *
REM *****************************
   SET /a UpdateInterval=RefreshSeconds/60

   ECHO ^</TABLE^> >>"%temp%\%REPORT_NAME%"
   ECHO ^<P^> >>"%temp%\%REPORT_NAME%"
   ECHO ^<TABLE BORDER="0" CELLPADDING="1" CELLSPACING="0" ^> >>"%temp%\%REPORT_NAME%"
   ECHO   ^<TR VALIGN="LEFT"^> >>"%temp%\%REPORT_NAME%"
   ECHO   ^<TD ALIGN="CENTER" VALIGN="CENTER"^> >>"%temp%\%REPORT_NAME%"
   
   ECHO   ^<FONT FACE="Arial, Helvetica" SIZE="3"^>^<b^>Total machines available now: %TotalAvailable%^</b^>^</font^> >>"%temp%\%REPORT_NAME%"
   ECHO   ^<P^> >>"%temp%\%REPORT_NAME%"
   ECHO   ^<FONT FACE="Arial, Helvetica" SIZE="2"^>This web page should update once every %UpdateInterval% minutes.^<BR^>If you have questions or need assistance please contact the help desk at %SupportNumber%^</font^> >>"%temp%\%REPORT_NAME%"

   ECHO   ^</TD^> >>"%temp%\%REPORT_NAME%"
   ECHO ^</TABLE^> >>"%temp%\%REPORT_NAME%"
   ECHO ^</BODY^> >>"%temp%\%REPORT_NAME%"
   ECHO ^</HTML^> >>"%temp%\%REPORT_NAME%"

REM *****************************************
REM * Set the end time                      *
REM *****************************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO         Script End Time: Fetching..
   
   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStampFinish=%MyTime% %MyDate%

   ECHO         Script End Time: %TimeStampFinish% >>%TEMP%\FindOpen-Header.tmp

REM **********************************
REM * Calc & display Elapsed Time    *
REM **********************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO          Total Run Time: Checking..

   rem Get end time:
   for /F "tokens=1-4 delims=:.," %%a in ("%time%") do (
     set /A "end=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
   )

   rem Get elapsed time:
   set /A elapsed=end-start

   rem Show elapsed time:
   set /A hh=elapsed/(60*60*100), rest=elapsed%%(60*60*100), mm=rest/(60*100), rest%%=60*100, ss=rest/100, cc=rest%%100
   if %mm% lss 10 set mm=0%mm%
   if %ss% lss 10 set ss=0%ss%
   if %cc% lss 10 set cc=0%cc%
   ECHO          Total Run Time: %hh%:%mm%:%ss% >>%TEMP%\FindOpen-Header.tmp

REM **********************************
REM * Write report file              *
REM **********************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   SET DestStatus=Updating..
   ECHO        Destination file: %DestStatus%
   COPY "%TEMP%\%REPORT_NAME%" "%Report_Path%%REPORT_NAME%"
   IF NOT %ERRORLEVEL%==0 (
     SET EndResult=%ENDRESULT%Report Update Failed, 
     SET DestStatus=Update FAILED
   ) ELSE (
     SET DestStatus=Updated.
   )
   ECHO        Destination file: %DestStatus%  >>%TEMP%\FindOpen-Header.tmp
   
REM **********************************
REM * Write log entry                *
REM **********************************
   :WriteLogExit
   If %CreateLogs%==No GOTO NoLog
   REM set default state for end result
   IF "%EndREsult%."=="." SET EndResult=No Errors

   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO                Log File: Updating "%LOG_PATH%\FindOpenLog.csv"..
   ECHO  -Updating Log File %LOG_PATH%\FindOpenLog.csv..
   rem Check for file, if not there make one with header
   IF NOT EXIST %LOG_PATH%\FindOpenLog.csv (
     ECHO "Script Ver","Start Time","Finish Time","Elapsed Time","Workstations Available","Logs Processed","Log Path","Report Path","Result">%LOG_PATH%\FindOpenLog.csv
   ) 
   ECHO "%ScriptVersion%","%TimeStampStart%","%TimeStampFinish%","%hh%:%mm%:%ss%","%TotalAvailable%","%TotalLogs%","%Log_Path%","%Report_Path%","%EndResult%">>%LOG_PATH%\FindOpenLog.csv
   ECHO                Log File: Updated "%LOG_PATH%\FindOpenLog.csv">>%TEMP%\FindOpen-Header.tmp
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   :NoLog

REM *****************************************
REM * Tell user we're done                  *
REM *****************************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO          Logs Processed: %TotalLogs% >>%TEMP%\FindOpen-Header.tmp
   ECHO           Script Result: %EndResult% >>%TEMP%\FindOpen-Header.tmp
   
REM *****************************************
REM * cleanup/Remove temporary files        *
REM *****************************************
   CLS
   TYPE %TEMP%\FindOpen-Header.tmp
   ECHO.
   
   DEL /Q %TEMP%\FindOpen_OnlyComputerLogs.txt %DEBUG%
   DEL /Q %TEMP%\FindOpen-Header.tmp %DEBUG%
   DEL /Q %TEMP%\%REPORT_NAME% %DEBUG%
   ENDLOCAL

REM *****************************************
REM * Pause may be remarked out if this     *
REM * script is to run automated            *
REM *****************************************
   PAUSE

  
  
REM *****************************************   
REM * SubRoutines go here                   *
REM **********************************************************************************   
REM **********************************************************************************   
REM **********************************************************************************   
REM **********************************************************************************   
REM **********************************************************************************   
   GOTO EOF

   REM ****************************
   REM * PING target machine      *
   REM ****************************
    :PingTargetMachine
	ECHO                          * Pinging..
      Set PingReply=
      FOR /F "tokens=1 delims= " %%j in ('PING -n 1 -w %PingWait% %CurrentMachine% ^| FIND "Reply"') do (
          SET PingReply=%%j
	  )
      IF !PingReply! == Reply (
         ECHO                          * Ping Replied.
      )
    exit /b

    REM ****************************
    REM * Search for LOGOFF event  *
    REM ****************************
    :ExtractRecord
      ECHO                          * Extracting last use data..
       FOR /F "tokens=3,6-9 delims=, " %%j in ('"TAIL -n 1 "%CurrentMachine%""') do (
         SET RecordType=%%j
	     rem remove leading and trailing quotes
		 SET RecordType=!RecordType:~1,-1!
		 
		 SET RecordMMM=%%k
	     rem remove leading quote
		 SET RecordMMM=!RecordMMM:~1!
		 
		 SET RecordDD=%%l
		 SET RecordYYYY=%%m
         SET RecordHHMMSS=%%n

         SET RecordDate=%%k %%l, %%m %%n
	     rem remove leading and trailing quotes
		 set RecordDate=!RecordDate:~1,-1!
	   )
	   
	   rem un-rem for debug purposes
	    GOTO NoShow
	    ECHO     RecordYYYY=!RecordYYYY!
	    ECHO    CurrentYYYY=!CurrentYYYY!
	    ECHO      RecordMMM=!RecordMMM!
	    ECHO     CurrentMMM=!CurrentMMM!
	    ECHO     RecordType=!RecordType!
		ECHO CurrentMachine=!CurrentMachine!
	    PAUSE
		:NoShow
	   
	   IF !RecordYYYY! == !CurrentYYYY! (
			IF !RecordMMM! == !CurrentMMM! (
				IF "!RecordType!" == "Logoff" (
					SET /a TotalAvailable=TotalAvailable+1
					ECHO ^<TR^> >>"%temp%\%REPORT_NAME%"
					ECHO   ^<TD ALIGN="CENTER"^>!TotalAvailable!^</TD^> >>"%temp%\%REPORT_NAME%"
					ECHO   ^<TD ALIGN="LEFT"^>!CurrentMachine!^</TD^> >>"%temp%\%REPORT_NAME%"
					ECHO   ^<TD ALIGN="LEFT"^>!RecordDate!^</TD^> >>"%temp%\%REPORT_NAME%"
					ECHO ^</TR^> >>"%temp%\%REPORT_NAME%"
				)
			)	   
       )

	   EXIT /b
	
:EOF
   
  
  
